/* http://adsabs.harvard.edu/abs_doc/journals1.html
 * download URL source then parse with
 * fgrep setfields journals1.html | awk -F ';' '{printf "%s\n",$2}'
 * | cut -c 7-12,24- | sed 's/"//g' | awk '{printf "\"%s\",\n",$0}'
 * | sort -k 2
 *
 */
static const char *journals[] = {
"TDR.. 3D Research",
"AASHS AAS Hist. Ser.",
"AASPB AAS Photo Bulletin",
"AAN.. AAVSO Alert Notice",
"AAVSC AAVSO Circular",
"AAVSN AAVSO Newsletter",
"AAVSB AAVSO Solar Bulletin",
"AbaOB Abastumanskaia Astrofizicheskaia Observatoriia Byulleten",
"AbbOO Abbadia Observatory Observations",
"AADDR Abhandlungen Akad. Wiss. DDR",
"AAGot Abhandlungen Akad. Wiss. Göttingen",
"ABWG. Abh. Braunschweigische Wissenschaftliche Ges.",
"AbhP. Abh. der Preuß. Akademie der Wissenschaften Jahrg",
"AbhKP Abh. Konigl. Preuss. Akad. Wissenschaften Jahre 1906,92, Berlin,1907",
"AbhBr Abh. naturwiss. Verein Bremen",
"AbApA Abstract and Applied Analysis",
"ASFAS Academia Scientiarum Fennica Annales Series Physica",
"AOIJ. Academic Open Internet Journal",
"CR2.. Academie des Sciences Comptes Rendus Serie Mecanique Physique Chimie Sciences de la Terre et de l Univers",
"CRAS. Academie des Sciences Paris Comptes Rendus",
"CRASB Academie des Sciences Paris Comptes Rendus Serie B Sciences Physiques",
"CRASG Academie des Sciences Paris Comptes Rendus Serie Generale La Vie des Sciences",
"CRASP Academie des Sciences Paris Comptes Rendus Serie Physique Astrophysique",
"CRASM Academie des Sciences Paris Comptes Rendus Serie Sciences Mathematiques",
"CRASA Academie des Sciences Paris Comptes Rendus Vie Academique Semester Supplement",
"MeARB Academie Royale de Belgique Classe des Sciences Memoires",
"ASSAB Academie Serbe des Sciences et des Arts Bulletin Classe des Sciences Techniques",
"ASLLR Accademia di Scienze e Lettere Istituto Lombardo Rendiconti Serie della Classe di Scienze Matematiche e Naturali Sezione Scienze Matematiche Fisiche Chimiche e Geologiche",
"ANLAM Accademia Nazionale dei Lincei Atti Rendiconti Classe di Matematica e Applicazioni",
"ANLAF Accademia Nazionale dei Lincei Atti Rendiconti Classe di Scienze Fisiche e Naturali",
"ANLAR Accademia Nazionale dei Lincei Atti Rendiconti Classe di Scienze Fisiche Matematiche e Naturali",
"AcChR Accounts Chem. Res.",
"AcBu. Acoust. Bull.",
"AIH.. Acoustical Imaging and Holography",
"APhy. Acoustical Physics",
"ASAJ. Acoustical Society of America Journal",
"AcouL Acoustics Letters",
"AcAcu Acta Acustica",
"AcAer Acta Aerodynamica Sinica",
"AcAAS Acta Aeronautica et Astronautica Sinica",
"AcAM. Acta Applicandae Mathematicae",
"AcAri Acta Arithmetica",
"AcArm Acta Armamentarii",
"AcAau Acta Astronautica",
"AcA.. Acta Astronomica",
"AcASn Acta Astronomica Sinica",
"AcAS. Acta Astronomica Supplementa",
"AcApS Acta Astrophysica Sinica",
"AcAuS Acta Automatica Sinica",
"AcBAS Acta Biochimica and Biophysica Academiae Scientarium Hungarica",
"AcBBH Acta Biochimica et Biophysica Hungarica",
"AcBBS Acta Biochimica et Biophysica Sinica",
"AcBio Acta Biotheoretica",
"AcCS. Acta Chemica Scandinavica Series A",
"ACIP. Acta Cienc. Indica Phys.",
"AcC.. Acta Cosmologica",
"AcCrA Acta Crystallographica Section A",
"AcCrB Acta Crystallographica Section B",
"AcCrC Acta Crystallographica Section C",
"AcCrD Acta Crystallographica Section D",
"AcElc Acta Electrochimica",
"AcEle Acta Electronica",
"AcElS Acta Electronica Sinica",
"AcESn Acta Electron. Sinica",
"AcFre Acta Frequenza",
"AcGG. Acta Geod. Geophys.",
"AcGeo Acta Geophysica",
"AcGeP Acta Geophysica Polonica",
"AcGSn Acta Geophys. Sinica",
"AcHA. Acta Historica Astronomiae",
"AcMCS Acta Materiae Compositae Sinica",
"AcMat Acta Materialia",
"AcMa. Acta Mathematica",
"AcMaH Acta Mathematica Hungarica",
"AcMaS Acta Mathematica Sinica",
"AcMSw Acta Mathematica Sweden",
"AcMec Acta Mechanica",
"AcMSn Acta Mechanica Sinica",
"AcMSS Acta Mechanica Solida Sinica",
"AcMet Acta Metallurgica",
"AcMMS Acta Metallurgica et Materialia Supplement",
"AcMeS Acta Meteorologica Sinica",
"AcNum Acta Numerica",
"AcOSi Acta Oceanica Sinica",
"AcOdS Acta Odontologica Scandinavica",
"AcO.. Acta Oecologica",
"AcOpS Acta Optica Sinica",
"AcOrS Acta Orthopaedica Scandinavica",
"AcPSi Acta Photonica Sinica",
"AcPhy Acta Physica",
"APASH Acta Physica Academiae Scientiarum Hungaricae",
"AcPhA Acta Physica Austriaca",
"AcPAS Acta Physica Austriaca Supplement",
"AcPhC Acta Physica et Chemica",
"AcPhH Acta Physica Hungarica",
"APHHI Acta Physica Hungarica Heavy Ion Physics",
"APHQE Acta Physica Hungarica Quantum Electronics",
"AcPP. Acta Physica Polonica",
"AcPPA Acta Physica Polonica A",
"AcPPB Acta Physica Polonica B",
"AcPSn Acta Physica Sinica",
"AcPSl Acta Physica Slovaca",
"AcPhS Acta Physiologica Scandinavica",
"AcPol Acta Polytechnica",
"AcPSc Acta Polytechnica Scandinavica Applied Physics Series",
"AcPSP Acta Polytechnica Scandinavica Physics",
"AcSSn Acta Seismologica Sinica",
"ASSF. Acta Societatis Scientarum Fennicae",
"ASSFA Acta Societatis Scientarum Fennicae Series A",
"AcTec Acta Technica",
"AcUni Acta Universitaria",
"AcMPh Acta Universitatis Caroliae. Mathematica et Physica",
"AcMPS Acta Universitatis Caroliae. Mathematica et Physica Supplement",
"APEC. Active and Passive Electronic Components",
"Acu.. Acustica",
"AdBeh Adaptive Behaviour",
"AdAs. Ad Astra",
"ARPM. Adgeziia Rasplavov i Paika Materialov",
"Adsor Adsorption",
"AdCM. Advanced Ceramic Materials",
"AdCoL Advanced Composites Letters",
"AMP.. Advanced Materials and Processes",
"APM.. Advanced Performance Materials",
"ASL.. Advanced Science Letters",
"AdSAC Advanced Series in Astrophysics and Cosmology",
"AdSMP Advanced Series in Mathematical Physics",
"ASDHE Advanced Series on Directions in High Energy Physics",
"AdTPh Advanced Texts in Physics",
"AdAeS Advances in Aeronautical Sciences",
"AdApM Advances in Applied Mathematics",
"AdAst Advances in Astronomy",
"AASP. Advances in Astronomy and Space Physics",
"AdAtS Advances in Atmospheric Sciences",
"AdAMP Advances in Atomic and Molecular Physics",
"AAMOP Advances in Atomic Molecular and Optical Physics",
"AdBMP Advances in Biological and Medical Physics",
"AdBio Advances in Biophysics",
"AdCP. Advances in Cardiovascular Physics",
"AdChP Advances in Chemical Physics",
"AdCIS Advances in Colloid and Interface Science",
"AdCoM Advances in Computational Mathematics",
"AdCMP Advances in Condensed Matter Physics",
"AdEPS Advances in Earth and Planetary Sciences",
"AdEOA Advances in Earth Oriented Applications and Space Technology",
"AEEP. Advances in Electronics and Electron Physics",
"AEEPS Advances in Electronics and Electron Physics Supplement",
"AdExG Advances in Exploration Geophysics",
"AdGDP Advances in Geophysical Data Processing",
"AdGR. Advances in Geophysical Research",
"AdGeo Advances in Geophysics",
"AdGeS Advances in Geophysics Supplement",
"AdG.. Advances in Geosciences",
"AdHEP Advances in High Energy Physics",
"ADIEP Advances in Imaging and Electron Physics",
"AdMRe Advances in Magnetic Resonance",
"AdMPC Advances in Materials Physics and Chemistry",
"AdMS. Advances in Materials Science",
"AdMSE Advances in Materials Science and Engineering",
"AdMaP Advances in Mathematical Physics",
"AdMat Advances in Mathematics",
"AdMPS Advances in Mechanics and Physics of Surfaces",
"AdMUM Advances in Mechanics Uspekhi Mekhaniki",
"AdMet Advances in Meteorology",
"AdNOp Advances in Nonlinear Optics",
"AdNuP Advances in Nuclear Physics",
"AdPhG Advances in Physical Geochemistry",
"AdPhy Advances in Physics",
"AdPlP Advances in Plasma Physics",
"AdPPR Advances in Plasma Physics Research",
"AdPoS Advances in Polymer Science",
"AdQC. Advances in Quantum Chemistry",
"AdRS. Advances in Radio Science",
"AdSR. Advances in Science and Research",
"AdSSP Advances in Solid State Physics",
"AdSpR Advances in Space Research",
"AdAnS Advances in the Astronautical Sciences",
"AdTAM Advances in Theoretical and Applied Mechanics",
"AdTMP Advances in Theoretical and Mathematical Physics",
"AdThP Advances in Theoretical Physics",
"AdWR. Advances in Water Resources",
"AAMS. Adv. Appl. Mech. Suppl.",
"ATTM. AEG Telefunken Technische Mitteilungen",
"AeoRe Aeolian Research",
"Aekv. Aerodinamika kanalov i ventiliatorov",
"AeRaG Aerodinamika Razrezhennykh Gazov",
"AerTe Aerojet Technology",
"AeIBu Aerokosmicheski Izsledvaniia B lgariia",
"AeJ.. Aeronautical Journal",
"AeQ.. Aeronautical Quarterly",
"AeSIJ Aeronautical Society India Journal",
"AerST Aerosol Science Technology",
"AeAm. Aerospace America",
"AeCh. Aerospace China",
"AeCM. Aerospace Composites and Materials",
"AeDy. Aerospace Dynamics",
"AeEn. Aerospace Engineering",
"AeMat Aerospace Materials",
"AeMed Aerospace Medicine",
"ARBl. Aerospace Research in Bulgaria",
"AeTJa Aerospace Technology Japan",
"Aero. Aerospace UK",
"AFGL. AFGL-TR-0208 Environemental Research papers",
"AfrSk African Skies",
"AGUFM AGU Fall Meeting Abstracts",
"AGUSM AGU Spring Meeting Abstracts",
"AIAAJ AIAA Journal",
"AIASJ AIAA Student Journal",
"AIChE AIChE Journal",
"EDAM. AI EDAM",
"AIHAJ AIHA Journal",
"AIPA. AIP Advances",
"AirSp Air and Space",
"AirE. Aircraft Engineering",
"AirCo Air et Cosmos",
"AFMa. Air Force Magazine",
"AiInt Air International",
"APCAJ Air Pollution Control Association Journal",
"AkAtP Akademia Athenon Praktika",
"DoArm Akademiia Nauk Armianskoi SSR Doklady",
"DoAze Akademiia Nauk Azerbaidzhanskoi SSR Doklady",
"IzAze Akademiia Nauk Azerbaidzhanskoi SSR Izvestiia Seriia Fiziko Tekhnicheskikh i Matematicheskikh Nauk",
"IFBel Akademiia Nauk Belorusskoi SSR Institut Fiziki Nauchnaia Sessiia Minsk Belorussian SSR Zhurnal Prikladnoi Spektroskopii",
"DoBel Akademiia Nauk BSSR Doklady",
"SoGru Akademiia Nauk Gruzii Soobshcheniia",
"VeKaz Akademiia Nauk Kazakhskoi SSR Vestnik",
"IzLat Akademiia Nauk Latviiskoi SSR Izvestiia Seriia Fizicheskikh i Tekhnicheskikh Nauk",
"IzMol Akademiia Nauk Moldavskoi SSR Izvestiia Seriia Fiziko Tekhnicheskikh i Matematicheskikh Nauk",
"DoSSR Akademiia Nauk SSSR Doklady",
"FizAO Akademiia Nauk SSSR Fizika Atmosfery i Okeana",
"InSSR Akademiia Nauk SSSR Investiia Mekhanika Zhidkosti i Gaza",
"IzFZ. Akademiia Nauk SSSR, Izvestiia, Fizika Zemli",
"IzSSR Akademiia Nauk SSSR Izvestiia Seriia Fizicheskaia",
"MeSSR Akademiia Nauk SSSR Mekhanika Zhidkosti i Gaza",
"FiMos Akademiia Nauk SSSR Otdelenie Obshchei Fiziki i Astronomii Nauchnaia Sessiia Moscow USSR Uspekhi Fizicheskikh Nauk",
"IzSib Akademiia Nauk SSSR Sibirskoe Otdelenie Izvestiia",
"SiSSR Akademiia Nauk SSSR Sibirskoe Otdelenie Izvestiia Seriia Tekhnicheskie Nauki",
"KzSib Akademiia Nauk SSSR Sibirskoi Otdelenie Izvestiia Seriia Tekhnicheskikh Nauk",
"VeSSR Akademiia Nauk SSSR Vestnik",
"DoTad Akademiia Nauk Tadzhikskoi SSR Doklady",
"FiSSR Akademiia Nauk Tadzhikskoi SSR Fiziko Tekhnicheskii Institut Dyushambe Tadzhik SSR Akademiia Nauk Tadzhikskoi SSR Doklady",
"ABTad Akademiia Nauk Tadzhikskoi SSR Institut Astrofiziki Biulleten",
"IzTur Akademiia Nauk Turkmenskoi SSR Izvestiia Seriia Fiziko Tekhnicheskikh Khimicheskikh i Geologicheskikh Nauk",
"IzUkr Akademiia Nauk Ukrainian SSSR Izvestiia Seriia Fizicheskaia",
"PrUkr Akademiia Nauk Ukrains koi RSR Dopovidi Matematika Prirodoznavstvo Tekhnichni Nauki",
"FiUkr Akademiia Nauk Ukrain skoi RSR Dopovidi Seriia Fiziko Matematichni ta Tekhnichni Nauki",
"DoUkr Akademiia Nauk Ukrains koi RSR Dopovidi Seriia Fiziko Matematichni ta Tekhnichni Nauki",
"ViUkr Akademiia Nauk Ukrains koi RSR Visnik",
"MGUkr Akademiia Nauk Ukrainskoi SSR Morskie Gidrofizicheskie Issledovaniia",
"DoUzb Akademiia Nauk Uzbekskoi SSR Doklady",
"IzUzb Akademiia Nauk Uzbekskoi SSR Izvestiia Seriia Fiziko Matematicheskikh Nauk",
"VeNav Akademiia Navuk BSSR Vestsi Seryia Fizika Tekhnichnykh Navuk",
"AkZh. Akusticheskii Zhurnal",
"AkTek Akustika i Ul trazvukovaia Tekhnika",
"AAIzN Alma Ata Izdatel Nauka",
"ALMAN ALMA Newsletter",
"AlFr. Alta Frequenza",
"AFRE. Alta Frequenza Rivista di Elettronica",
"Ambio Ambio",
"AVSOA American Association of Variable Stars Observers Abstracts",
"AVSOM American Association of Variable Stars Observers Monographs",
"AVSOQ American Association of Variable Stars Observers Quarterly Reports",
"AVSOR American Association of Variable Stars Observers Reports",
"ACSB. American Ceramic Society Bulletin",
"ACSC. American Ceramic Society Communications",
"ACSJ. American Ceramic Society Journal",
"AHSJ. American Helicopter Society Journal",
"AmJC. American Journal of Cardiology",
"AmJM. American Journal of Mathematics",
"AmJPh American Journal of Physics",
"AmJS. American Journal of Science",
"AmJSA American Journal of Science and Arts",
"AMSBu American Meteorological Society Bulletin",
"AmMin American Mineralogist",
"AmSci American Scientist",
"ASME. American Society of Mechanical Engineers",
"AnCoi Anais do Observatorio Astronomico da Universidade de Coimbra",
"AnFis Anales de Fisica",
"AICSP Analog Integrated Circuits and Signal Processing",
"AnMP. Analysis and Mathematical Physics",
"AnBio Analytical Biochemistry",
"AnaCh Analytical Chemistry",
"AnaIn Analytical Instrumentation",
"BSSR. AN BSSR Institut Teplo i Massoobmena Vsesoiuznaia Konferentsiia Teplomassoobmenu Minsk Belorussian SSR Preprint",
"AAONw Anglo-Australian Observatory Epping Newsletter",
"AAOPr Anglo-Australian Observatory Epping Preprint",
"ARIJ. An Interdisciplinary Journal of Physical and Engineering Sciences",
"CSMPA Ankara Universite Faculte des Sciences Communications Serie Mathematiques Physique et Astronomie",
"AASF. Ann. Acad. Sci. Fennicae",
"AnStr Annalen der Kaiserlichen Universitats-Sternwarte in Strassburg",
"AnWie Annalen der K.K. Sternwarte Wien",
"AnSWi Annalen der K.K. Universitaets-Sternwarte in Wien (Waehring)",
"AnMun Annalen der Koeniglichen Sternwarte bei Muenchen",
"AnP.. Annalen der Physik",
"AnWiD Annalen der Universitaets-Sternwarte Wien, Dritter Folge",
"AnMet Annalen Meteorologie",
"AnLei Annalen van de Sterrewacht te Leiden",
"AnAp. Annales d'Astrophysique",
"AnCPh Annales de Chimie et de Physique",
"AnG.. Annales de Geophysique",
"AFLB. Annales de la Fondation Louis de Broglie",
"ASSB. Annales de la Societe Scietifique de Bruxelles",
"AnIHP Annales de L'Institut Henri Poincare Section Physique Theorique",
"AnTou Annales de l'Observatoire Astron. et Meteo. de Toulouse",
"AnAIK Annales de l'Observatoire astronomique de l'Université imériale de Kharkow",
"AOTok Annales de l'Observatoire astronomique de Tokyo",
"AnZoC Annales de l'Observatoire astronomique de Zô-sè (Chine)",
"AnAPM Annales de l'Observatoire d'astronomie physique de Paris, Section d'astrophysique, à Meudon",
"AnBes Annales de l'Observatoire de Besancon",
"AnBor Annales de l'Observatoire de Bordeaux",
"AnNic Annales de l'Observatoire de Nice",
"AnPar Annales de l'Observatoire de Paris",
"AnPOb Annales de l'Observatoire de Paris. Observations",
"AnOSt Annales de l'Observatoire de Strasbourg",
"AnRio Annales de l'Observatoire Imperial de Rio de Janeiro",
"AnAth Annales de l'Observatoire national d'Athènes",
"AnOB. Annales de l'Observatoire Royal de Belgique",
"AnOBN Annales de l'Observatoire Royal de Belgique Nouvelle serie",
"AnBru Annales de l'Observatoire Royal de Bruxelles",
"AnPh. Annales de Physique",
"AnPBM Annales de Physique Biologique et Medicale",
"AnPCS Annales de Physique Colloque Supplement",
"AnTel Annales des Telecommunications",
"AnGVP Annales du Bureau des Longitudes, Gauthier-Villars, Paris",
"AFChr Annales Francaises de Chronometrie",
"AnGeo Annales Geophysicae",
"AnGeA Annales Geophysicae Series A Upper Atmosphere and Space Sciences",
"AnGeB Annales Geophysicae Series B Terrestrial and Planetary Physics",
"AnHP. Annales Henri Poincaré",
"AnTec Annales Tectonicae",
"AUGGM Annales UMCS, Geographia, Geologia, Mineralogia et Petrographia",
"AUSPh Annales UMCS, Sectio AAA: PHYSICA",
"AnApS Annals of Applied Statistics",
"AGp.. Annals of Geophysics",
"AnGla Annals of Glaciology",
"AnGAG Annals of Global Analysis Geometry",
"AnHar Annals of Harvard College Observatory",
"AnMat Annals of Mathematics",
"AnMAI Annals of Mathematics and Artificial Intelligence",
"AnOR. Annals of Operations Research",
"AnPhy Annals of Physics",
"AnREE Annals of Research on Engineering Education",
"AnCGH Annals of Royal Observatory, Cape of Good Hope",
"AnSci Annals of Science",
"AnSta Annals of Statistics",
"AnSAO Annals of the Astrophysical Observatory of the Smithsonian Institution",
"AnBos Annals of the Bosscha Observatory Lembang (Java) Indonesia",
"AnCap Annals of the Cape Observatory",
"AnDea Annals of the Dearborn Observatory",
"AnDud Annals of the Dudley Observatory",
"AnISM Annals of the Institute of Statistical Mathematics",
"AIQSY Annals of the IQSY",
"AnIPS Annals of the Israel Physical Society",
"AnLow Annals of the Lowell Observatory",
"NYASA Annals of the New York Academy of Sciences",
"AnLL. Annals of the Observatory of Lucien Libert",
"AnLun Annals of the Observatory of Lund",
"AnLuS Annals of the Observatory of Lund Supplement",
"AnOLL Annals of the Private Observatory of Lucien Libert",
"AnEdi Annals of the Royal Observatory, Edinburgh",
"AnSPC Annals of the Solar Physics Observatory Cambridge England",
"AnTok Annals of the Tokyo Astronomical Observatory",
"AnUCP Annals of the University of Craiova Physics AUC",
"AnRev Ann Rev",
"AnBSJ Annual Bulletin of the Societe Jersiaise",
"YalAR Annual Report of the Astronomer of the Winchester Observatory of Yale College",
"ARKod Annual Report of the Kodaikanal Observatory",
"MMAAR Annual Report of the Maria Mitchell Association",
"ARAOJ Annual Report of the National Astronomical Observatory of Japan",
"AnRSI Annual Report of the Smithsonian Institution",
"WinAR Annual Report of the Windsor Observatory, New South Wales",
"ARAC. Annual Review of Analytical Chemistry",
"ARCMP Annual Review of Condensed Matter Physics",
"AREPS Annual Review of Earth and Planetary Sciences",
"AnRE. Annual Review of Energy",
"AnRFM Annual Review of Fluid Mechanics",
"ARIST Annual Review of Information Science and Technology",
"ARMS. Annual Review of Marine Science",
"AnRMS Annual Review of Materials Science",
"ARNPS Annual Review of Nuclear and Particle Science",
"ARPC. Annual Review of Physical Chemistry",
"ARCP. Annual Reviews of Computational Physics",
"AnMN. Antarctic Meteorite Newsletter",
"AMR.. Antarctic Meteorite Research",
"Antk. Antarktika",
"Anten Antenny",
"AnCan Anticancer Research",
"IORA. Anuario publicado pelo Imperial Observatorio do Rio de Janeiro",
"IORAS Anuario publicado pelo Imperial Observatorio do Rio de Janeiro Suplemento",
"ApAN. Apatity Akademiia Nauk SSSR",
"ApKF. Apatity Kol skii Filial AN SSSR",
"Apei. Apeiron",
"ApMat Aplikace Matematiky, Applied Mathematics",
"AppAn Applicable Analysis",
"ApMa. Applications of Mathematics",
"ApAc. Applied Acoustics",
"ApAI. Applied Artificial Intelligence",
"ApCM. Applied Composite Materials",
"ACESJ Applied Computational Electromagnetics Society Journal",
"ApEn. Applied Energy",
"ApEnM Applied Environmental Microbiology",
"ApGeo Applied Geophysics",
"ApMF. Applied Mathematical Finance",
"AMat. Applied Mathematics",
"ApMM. Applied Mathematics and Mechanics",
"ApMaC Applied Mathematics Computation",
"ApMaL Applied Mathematics Letters",
"ApMaM Applied Mathematics Mechanics English Edition",
"ApMaO Applied Mathematics Optimization",
"AMM.. Applied Mechanics and Materials",
"ApMRv Applied Mechanics Reviews",
"ApMic Applied Microbiology",
"ApMT. Applied Microgravity Technology",
"ApNan Applied Nanoscience",
"ApNM. Applied Numerical Mathematics",
"ApOpt Applied Optics",
"ApPhy Applied Physics",
"ApPhA Applied Physics A: Materials Science &amp",
"ApPhB Applied Physics B: Lasers and Optics",
"ApPPL Applied Physics B Photophysics Laser Chemistry",
"ApPhC Applied Physics Communications",
"APExp Applied Physics Express",
"ApPhL Applied Physics Letters",
"ApPhR Applied Physics Research",
"ApScR Applied Scientific Research",
"ApSRA Applied Scientific Research Section A",
"ApSRB Applied Scientific Research Section B",
"ApSpe Applied Spectroscopy",
"ApSRv Applied Spectroscopy Reviews",
"ApSup Applied Superconductivity",
"ApSS. Applied Surface Science",
"ApWS. Applied Water Science",
"APS.. APS Meeting Abstracts",
"ACMFE Aquatic Conservation: Marine and Freshwater Ecosystems",
"AJSE. Arabian Journal of Science Engineering",
"Arch. Archaeoastronomy",
"ArchS Archaeoastronomy Supplement",
"Archa Archaeometry",
"ASBTV Archenhold-Sternwarte Berlin-Treptow, Vortrage Schr.",
"ArApM Archive Applied Mechanics",
"AHES. Archive for History of Exact Sciences",
"ArRMA Archive for Rational Mechanics and Analysis",
"ArElU Archiv Elektronik und Uebertragungstechnik",
"AAM.. Archive of Applied Mechanics",
"ArApM Archive of Applied Mechanics",
"ArBB. Archive of Biochemistry and Biophysics",
"ArAco Archives Acoustics",
"ArS.. Archives des Sciences",
"ArSPN Archives des Sciences Physiques et Naturelles",
"AMGBA Archives for Meteorology Geophysics and Bioclimatology Series A Meteorology and Atmopsheric Physics",
"AMGBB Archives for Meteorology Geophysics and Bioclimatology Series B Theoretical and Applied Climatology",
"AIPBB Archives Internationales de Physiologie de Biochimie et de Biophysique",
"ArNSc Archives Neerlandaises des Sciences Exactes et Naturelles",
"ArMaN Archiv for Mathematik og Naturvidenskab",
"AMGBK Archiv Meteorologie Geophysik und Bioklimatologie Serie B Klimatologie und Umweltmeteorologie Strahlungsforschung",
"AMGBS Archiv Meteorologie Geophysik und Bioklimatologie Serie Meteorologie und Geophysik",
"ArMeS Archiv of Mechanics, Archiwum Mechaniki Stosowanej",
"ArCom Archivum Combustionis",
"ArAku Archiwum Akustyki",
"ArAuT Archiwum Automatyki i Telemechaniki",
"ArBuM Archiwum Budowy Maszyn",
"ArEle Archiwum Elektrotechniki",
"ArMeS Archiwum Mechaniki Stosowanej",
"ArPSp Archiwum Procesow Spalania",
"ArTSp Archiwum Termodynamiki i Spalania",
"AAAR. Arctic, Antarctic and Alpine Research",
"ArA.. Arkiv for Astronomi",
"ArM.. Arkiv for Matematik",
"ArMAF Arkiv for Matematik, Astronomi och Fysik",
"ArmOL Armagh Observatory Leaflet",
"ArJPh Armenian Journal of Physics",
"ArtSa Artificial Satellites",
"astro ArXiv Astrophysics e-prints",
"cs... ArXiv Computer Science e-prints",
"arXiv ArXiv e-prints",
"gr.qc ArXiv General Relativity and Quantum Cosmology eprints",
"hepex ArXiv High Energy Physics - Experiment e-prints",
"hepla ArXiv High Energy Physics - Lattice e-prints",
"hepph ArXiv High Energy Physics - Phenomenology e-prints",
"hepth ArXiv High Energy Physics - Theory e-prints",
"mathp ArXiv Mathematical Physics e-prints",
"math. ArXiv Mathematics e-prints",
"nlin. ArXiv Nonlinear Sciences e-prints",
"nucle ArXiv Nuclear Experiment e-prints",
"nuclt ArXiv Nuclear Theory e-prints",
"physicArXiv Physics e-prints",
"ASHRA ASHRAE Journal",
"AsJPh Asian Journal of Physics",
"Aslib Aslib Proceedings: new information perspectives",
"ATJEM ASME Transactions Journal Engineering Materials and Technology",
"ATJDS ASME Transactions Journal of Dynamic Systems and Measurement Control B",
"ATJEl ASME Transactions Journal of Electronic Packaging",
"ATJEG ASME Transactions Journal of Engineering Gas Turbines and Power",
"ATJEP ASME Transactions Journal of Engineering Power",
"ATJFE ASME Transactions Journal of Fluids Engineering",
"ATJHT ASME Transactions Journal of Heat Transfer",
"ATJLT ASME Transactions Journal of Lubrication Technology",
"ATJSE ASME Transactions Journal of Solar Energy and Engineering",
"ATJTr ASME Transactions Journal of Tribology",
"ATJTu ASME Transactions Journal of Turbomachinery",
"ATJVA ASME Transactions Journal of Vibration Acoustics",
"ATJAM ASME Transactions Series E Journal of Applied Mechanics",
"ATJEP ASME Transactions Series Journal of Engineering Power",
"AsAut Assembly Automation",
"ATMAB Association Technique Maritime et Aeronautique Bulletin",
"ATMAS Association Technique Maritime et Aeronautique Session Paris France ONERA TP",
"AVSVB Associazione Veneta Osservatori di Stelle Variabili Bulletin",
"Aster Aster",
"StNws ASTM Standardization News",
"AsBio Astrobiology",
"AISAO Astrofizicheskie Issledovaniia Izvestiya Spetsial'noj Astrofizicheskoj Observatorii",
"AISof Astrofizicheskie Issledovaniya Sofia",
"Afz.. Astrofizika",
"AAfz. Astrometriia i Astrofizika",
"AsAc. Astronautica Acta",
"AsAcS Astronautica Acta Supplement",
"AsAer Astronautics Aeronautics",
"Asnau Astronautik",
"AUBas Astron. Inst. Univ. Basel",
"Anews ASTRON Newsletter",
"AsUAI Astronomia. La rivista dell' Unione Astrofili Italiani",
"Astnm Astronomia UAI",
"USNOM Astronomical and Meteorological Observations made at the U.S. Naval Observatory",
"ACiCh Astronomical Circular",
"ACMan Astronomical Contributions from the University of Manchester",
"TamCo Astronomical Contributions from the University of South Florida Tampa",
"adass Astronomical Data Analysis Software and Systems",
"ADCBu Astronomical Data Center Bulletin",
"AstHe Astronomical Herald",
"AstLt Astronomical Letters",
"ANote Astronomical Notes University of Gothenburg Sweden Section of Astronomy",
"USNOA Astronomical Observations made at the U.S. Naval Observatory",
"UCLAP Astronomical Papers University of California Los Angeles",
"AReg. Astronomical Register",
"ASSA. Astronomical Society of South Africa, Cape Centre",
"AVest Astronomicheskii Vestnik",
"AVISS Astronomicheskii Vestnik Issledovaniia Solnechnoi Sistemy",
"AZh.. Astronomicheskii Zhurnal",
"ATsir Astronomicheskij Tsirkulyar",
"KazOB Astronomicheskoj Observatorii Kazan Byulleten",
"AsSch Astronomie in der Schule",
"AAAN. Astronomische Abhandlungen als Erganzungshefte zu den Astronomische Nachrichten",
"AAHam Astronomische Abhandlungen der Hamburger Sternwarte",
"ABMun Astronomische Beobachtungen angestellt auf der K. Sternwarte zu Bogenhausen bei Muenchen",
"ABSBe Astronomische Beobachtungen auf der Koniglichen Sternwarte zu Berlin",
"ABKie Astronomische Beobachtungen auf der Sternwarte der Koeniglichen Christian-Albrechts-Universitaet zu Kiel",
"MiZur Astronomische Mitteilungen der Eidgenössischen Sternwarte Zurich",
"MiBre Astronomische Mitteilungen der Koeniglichen Universitaets-Sternwarte zu Breslau",
"MiGoe Astronomische Mitteilungen der Universitaets-Sternwarte zu Goettingen",
"AN... Astronomische Nachrichten",
"ANS.. Astronomische Nachrichten Supplement",
"MitSZ Astronomischen Mitteilungen Eidgen. Sternwarte Zurich",
"AJB.. Astronomischer Jahresbericht",
"MiARI Astronomisches Rechen-Institut Heidelberg Mitteilungen Serie A",
"MiARB Astronomisches Rechen-Institut Heidelberg Mitteilungen Serie B",
"ATi.. Astronomisk Tidsskrift",
"Ast.. Astronomy",
"Astro Astronomy",
"AstAp Astronomy and Astro-Physics (formerly The Sidereal Messenger)",
"ADIL. Astronomy Data Image Library",
"AEdRv Astronomy Education Review",
"AExpr Astronomy Express",
"AstL. Astronomy Letters",
"AsNow Astronomy Now",
"AstQ. Astronomy Quarterly",
"ARep. Astronomy Reports",
"AASPP Astrononomy and Astrophysics Series",
"APh.. Astroparticle Physics",
"AstBu Astrophysical Bulletin",
"ApInv Astrophysical Investigations",
"ApL.. Astrophysical Letters",
"ApNr. Astrophysica Norvegica",
"Ap... Astrophysics",
"ASPRv Astrophysics and Space Physics Reviews",
"ApSSP Astrophysics and Space Science Proceedings",
"ASTRA Astrophysics and Space Sciences Transactions",
"ApSSS Astrophysics and Space Science Supplement",
"MKAtl Astrophysics monographs University of Chicago Press",
"ArBei Astrophysics Reports Publications of the Beijing Astronomical Observatory",
"ApT.. Astrophysics Today",
"AstPo Astropolitics",
"AsAna Asymptotic Analysis",
"BLabR AT&amp",
"AJSEd Atlas Journal of Science Education",
"AtlVS Atlas Poiskovykh Kart Peremennykh Zvezd",
"Atmos Atmosphere",
"AtO.. Atmosphere Ocean",
"AtOpt Atmosphere Optics",
"ACP.. Atmospheric Chemistry &amp",
"ACPD. Atmospheric Chemistry &amp",
"AtmEn Atmospheric Environment",
"AMT.. Atmospheric Measurement Techniques",
"AMTD. Atmospheric Measurement Techniques Discussions",
"AtmRe Atmospheric Research",
"AtSc. Atmospheric Science",
"AtScL Atmospheric Science Letters",
"AtmTe Atmospheric Technology",
"atnfp ATNF Proposal",
"Atom. Atom",
"AD... Atomic Data",
"ADNDT Atomic Data and Nuclear Data Tables",
"AtERv Atomic Energy Review",
"AMOP. Atomic Molecular and Optical Physics",
"AtPhy Atomic Physics",
"AtST. Atomisation Spray Technology",
"AtKe. Atomkernenergie",
"AtEn. Atomnaia Energiia",
"AVET. Atomno Vodorodnaia Energetika i Tekhnologiia",
"ATR.. ATR Australian Telecommunication Research",
"AALST Atti Accad. Ligure Sci. Lett.",
"AAPon Atti Accad. Pontaniana",
"AAST. Atti Accad. Sco. Torino I",
"ATTTJ AT T Technical Journal",
"AurPh Auroral physics",
"AuJAR Australian Journal of Agricultural Research",
"AuJA. Australian Journal of Astronomy",
"AuJCE Australian Journal of Chemical Education",
"AJCh. Australian Journal of Chemistry",
"AuJES Australian Journal of Earth Sciences",
"AuJPh Australian Journal of Physics",
"AuJPA Australian Journal of Physics Astrophysical Supplement",
"AuSRA Australian Journal of Scientific Research A Physical Sciences",
"AJSR. Australian Journal of Soil Research",
"AuMSJ Australian Mathematical Society Journal Series B -- Applied Mathematics",
"AuMM. Australian Meteorological Magazine",
"Autom Automatica",
"ACTAp Automatic Control Theory Applications",
"AuRob Autonomous Robots",
"AvSeM Aviation Space and Environmental Medicine",
"AvWST Aviation Week Space Technology",
"AvKos Aviatsiia i Kosmonavtika",
"AvTek Aviatsionnaia Tekhnika",
"AvTel Avtomatika i Telemekhanika",
"AvPE. Avtomatizatsiia Proektirovaniia Elektronike",
"Avtme Avtometriia",
"BBUSS Babes Bolyai Universitas Studia Series Mathematica",
"BBUSM Babes Bolyai Universitas Studia Series Physica",
"BaPhL Balkan Physics Letters",
"BaltA Baltic Astronomy",
"BamKV Bamberg Kleine Veroeffentlichungen der Remeis-Sternwarte",
"BAVRu BAV Rundbrief",
"BAVSR BAV Rundbrief - Mitteilungsblatt der Berliner Arbeits-gemeinschaft fuer Veraenderliche Sterne",
"BAWMN Bayerische Akademie Wissenschaften mathematisch naturwissenschaftliche Klasse Sitzungsberichte",
"BayAn Bayesian Analysis",
"BBCEn BBC Engineering",
"BRMIC Behavior Research Methods Instruments and Computers",
"BIT.. Behaviour &amp",
"BUAAJ Beijing University Aeronautics and Astronautics Journal",
"BePl. Beitraege Plasmaphysik",
"BeiGe Beitraege zur Geophysik",
"BeiMP Beitraege zur Mineralogie und Petrographie",
"BROGS Belgian Royal Observatory Communications Series Geophysics Series",
"BKAD. Beobachtungen der Kaiserlichen Universitaets-Sternwarte Dorpat",
"BKUJ. Beobachtungen der Kaiserlichen Universitaets-Sternwarte Jurjew",
"BESBe Beobachtungs-Ergebnisse der Koniglichen Sternwarte zu Berlin",
"ANZi. Beobachtungs-Zirkular der Astronomischen Nachrichten",
"BBGPC Berichte der Bunsen-Gesellschaft Physical Chemistry Chemical Physics Berichte",
"BADPG Berlin East Germany Akademie Verlag GmbH Ergebnisse Plasmaphysik und Gaselektronik",
"BAVMM Berlin East Germany Akademie Verlag GmbH Shriftenreihe des Zentralinstituts Mathematik und Mechanik",
"BAVSM Berliner Arbeitsgemeinschaft fuer Veraenderliche Sterne - Mitteilungen",
"BGBGM Berlin Gebrueder Borntraeger Geoexploration Monographs Series",
"Bern. Bernoulli",
"BeElM Beskontaktnye Elektricheskie Mashiny",
"BeSN. Be Star Newsletter",
"BGIBI BGI Bulletin d'Information",
"AstBa Biblioteca Astrei Basarabene",
"BEPM. Bielefeld Encounters in Physics and Mathematics",
"BiLuf Bildmessung und Luftbildwessen",
"BBRC. Biochemical and Biophysical Research Communications",
"BioJ. Biochemical Journal",
"BCB.. Biochemistry and Cell Biology",
"AcBB. Biochimica et Biophysica Acta",
"BioFa Biofabrication",
"BGeo. Biogeosciences",
"BGD.. Biogeosciences Discussions",
"BMNAS Biographical Memoirs National Academy of Sciences",
"BMFRS Biographical Memoirs of Fellows of the Royal Society",
"BiBi. Bioinspiration and Biomimetics",
"BMP.. Biological and Medical Physics",
"BPS.. Biological Physics Series",
"BRCPS Biological Reviews of the Cambridge Philosophical Society",
"BioMa Biomedical Materials",
"BioMi Biomedical Microdevices",
"Biome Biometrika",
"Bion. Bionika",
"BioCh Biophysical Chemistry",
"BpJ.. Biophysical Journal",
"BpBeS Biophysics and Bioengineering Series",
"BioSM Biophysics of Structure and Mechanism",
"Bioph Biophysics USSR",
"Biopk Biophysik",
"Biorh Biorheology",
"BioSc BioScience",
"BiotL Biotechnology Letters",
"BOTor Biuletyn Obserwatoium Astronomicznego Uniwersytetu M. Kopernika w Toruniu",
"BITad Biulletini of the Astronomical Institute Akademiia Nauk Tadzhikskoi",
"BIAst Bjull. Inst. Astrofizikii",
"BlazD BLAZAR Data",
"BAAA. Boletin de la Asociacion Argentina de Astronomia La Plata Argentina",
"BAOM. Boletin de la Astronomico Observatorio de Madrid",
"BIMAF Boletin del Instituto de Matematica Astronomica y Fisica Universidad Nacional de Cordoba Argentina",
"BITon Boletin del Instituto de Tonantzintla",
"BOTT. Boletin de los Observatorios Tonantzintla y Tacubaya",
"BMOE. Boletin mensual del Observatorio del Ebro",
"BlDok Bolgarska Akademiia Nauk Doklady",
"BSVit Bolletino della Societa dei Variabilisti Italiani",
"BoSAI Bollettino della Societa Astronomica Italiana",
"BGSA. Bollettino Geod. Scienzi Affini",
"BonD. Bonner Durchmusterung",
"BoLMe Boundary-Layer Meteorology",
"Brain Brain",
"BVVSA Bratislava Veda Vydavatelstvo Slovenskej Akademie Vied",
"BFWSG Braunschweig Friedr Vieweg und Sohn GmbH",
"BTUM. Braunschweig Technische Universitaet Mitteilungen",
"BrJPh Brazilian Journal of Physics",
"BrWK. Brennstoff Waerme Kraft",
"BJAP. British Journal of Applied Physics",
"BJET. British Journal of Educational Technology",
"BJMSP British Journal of Mathematical and Statistical Psychology",
"BJP.. British Journal of Psychology",
"BTE.. British Telecommunications Engineering",
"BIRM. Brussels Institute Royal Meteorologique de Belgique",
"BuAkK Budapest Akademiai Kiado",
"BlgAJ Bulgarian Astronomical Journal",
"BlGJ. Bulgarian Geophysical Journal",
"BlJMH Bulgarian Journal of Meteorology and Hydrology",
"BlJPh Bulgarian Journal of Physics",
"BlJPS Bulgarian Journal of Physics Supplement",
"BlGeo Bulgarska Akademiia Naukite Geofizichni Institut Izvestiia",
"BlTek Bulgarska Akademiia Naukite Institut Tekhnicheska Kibernetika Izvestiia",
"BlMat Bulgarska Akademiia Naukite Matematicheski Institut Izvestiia",
"BlSpi Bulgarska Akademiia Naukite Spisanie",
"BlTse Bulgarska Akademiia Naukite Tsentralna Laboratoriia Geodeziia Izvestiia",
"BlGSp Bulgarsko Geofizichno Spisanie",
"BAFOE Bulletin Association Fran. Obs. Etoiles Variables",
"BuAst Bulletin Astronomique",
"BABel Bulletin Astronomique de Belgrade",
"BuAsR Bulletin Astronomique, Revue Generale des Travaux Astronomiques",
"BuAsI Bulletin Astronomique, Serie I",
"BuChr Bulletin Chronometrique (Besancon)",
"BCSAB Bulletin Cl. Science Academy Royal de Belgique",
"BCrAO Bulletin Crimean Astrophysical Observatory",
"BAPSS Bulletin de l'Academie Polonaise des Sciences Series des Sciences Mathematiques Astronomiques et Physiques",
"BARB. Bulletin de l'Academie Royale de Belgique",
"BSAF. Bulletin de la Societe Astronomique de France",
"BSAFR Bulletin de la Societe Astronomique de France et Revue Mensuelle d'Astronomie, de Meteorologie et de Physique du Globe",
"BSAL. Bulletin de la Societe Astronomique de Liege",
"BSBA. Bulletin de la Societe Belge d'Astronomie",
"BSRSL Bulletin de la Societe Royale des Sciences de Liege",
"AFOEV Bulletin de l'Association Francaise d'Observateurs d'Etoiles Variables",
"BMai. Bulletin de la Station Astrophotographique de Mainterne",
"BOBeo Bulletin de l'Observatoire Astronomique de Belgrade",
"BuLyo Bulletin de l'Observatoire de Lyon",
"BBSAG Bulletin der Bedeckungsveraenderlichen-Beobachter der Schweizerischen Astronomischen Gesellschaft",
"BIEBe Bulletin d'Information d'Etoiles Be",
"BIM.. Bulletin d'Information des Marees Terrestres",
"BIBGI Bulletin d'Information du Bureau Gravimetrique International",
"BICDS Bulletin d'Information du Centre de Donnees Stellaires",
"BCFHT Bulletin d'information du telescope Canada-France-Hawaii",
"BGeod Bulletin Geodesique",
"BGNS. Bulletin Geodesique, Nouvelle Series",
"BuBIH Bulletin Horaire du Bureau International de l'Heure",
"BOPul Bulletin (Izvestiya) de l'Observatoire Central a Poulkovo",
"BuMat Bulletin Mathematique",
"BKoAS Bulletin of Korean Astronomical Society",
"BMBio Bulletin of Mathematical Biology",
"BMBp. Bulletin of Mathematical Biophysics",
"BPAS. Bulletin of Pure and Applied Science (Physics)",
"BAAPG Bulletin of the American Association of Petroleum Geologists",
"BAVSO Bulletin of the American Association of Variable Stars Observers",
"BAAS. Bulletin of the American Astronomical Society",
"BAMaS Bulletin of the American Mathematical Society",
"BAMS. Bulletin of the American Meteorological Society",
"BAPS. Bulletin of the American Physical Society",
"BAICz Bulletin of the Astronomical Institutes of Czechoslovakia",
"BAN.. Bulletin of the Astronomical Institutes of the Netherlands",
"BANS. Bulletin of the Astronomical Institutes of the Netherlands Supplement Series",
"BAORB Bulletin of the Astronomical Observatoire Royale de Belgique",
"IllOB Bulletin of the Astronomical Observatory of the University of Illinois",
"BASBr Bulletin of the Astronomical Society of Brazil",
"BASI. Bulletin of the Astronomical Society of India",
"BCAIC Bulletin of the Central Astronomical Institute of Czechoslovakia",
"BuGSA Bulletin of the Geological Society of America",
"BIMIA Bulletin of the Institute of Mathematics and Its Applications",
"BuIPS Bulletin of the Israel Physical Society",
"BKobO Bulletin of the Kobe Marine Observatory Kobe Japan",
"BLPI. Bulletin of the Lebedev Physics Institute",
"BuLMS Bulletin of the London Mathematical Society",
"BRASP Bulletin of the Russian Academy of Science, Phys.",
"BSAst Bulletin of the Section of Astronomy",
"BSAE. Bulletin of the Soviet Antarctic Expedition",
"BuONC Bulletin of the Special Astrophysical Observatory, Northern Caucasus",
"BSAO. Bulletin of the Special Astrophysics Observatory",
"BTasO Bulletin of the Tashkent Observatory",
"BTok. Bulletin of the Tokyo Astronomical Observatory",
"BToIT Bulletin of the Tokyo Institute of Technology",
"BUBes Bulletin of the University of Besancon Observatory",
"BYam. Bulletin of the Yamagata University Yamagata Japan",
"YerOB Bulletin of the Yerkes Observatory of the University of Chicago",
"BVol. Bulletin of Volcanology",
"BCNRS Bulletin Signaletique - Centre National de la Recherche Scientifique",
"BSAO. Bull. Special Astrophys. Obs.",
"BIHCD Bureau Internationale Heure, Paris, Circulaire",
"BDus. Byulleten' Instituta Astrofiziki Dushanbe Akademiya Nauk Tadzhikskoj SSR",
"BITA. Byulleten' Instituta Teoreticheskoj Astronomii (Leningrad)",
"BStaO Byulleten' Stalinabadskoj Astronomicheskoj Observatorii Akademiya Nauk Tadzhikskoj SSR",
"ByuRe Byurakan Astrophysical Observatory Armenia USSR Reprints",
"ByuPr Byurakanskaya Astrofizicheskaya Observatoriya Preprint",
"CahPh Cahiers de Physique",
"CAS.. Cambridge Astrophysics Series",
"CCA.. Cambridge Contemporary Astrophysics",
"CamRe Cambridge Observatories Reprints",
"CMPNC Cambridge Monographs on Particle Physics, Nuclear Physics and Cosmology",
"CMPPh Cambridge Monographs on Plasma Physics",
"CSLPT Cambridge Studies in Low Temperature Physics",
"CTMPC Cambridge Topics in Mineral Physics and Chemistry",
"BCNRC Canada National Research Council Division Mechanical Engineering National Aeronautical Establishment Quarterly Bulletin",
"CASJ. Canadian Aeronautics and Space Journal",
"CASJQ Canadian Aeronautics and Space Journal Quarter",
"CEEJ. Canadian Electrical Engineering Journal",
"CaGeJ Canadian Geotechnical Journal",
"CIPSG Canadian Information Processing Society Graphics Interface",
"CJChE Canadian Journal of Chemical Engineering",
"CaJCh Canadian Journal of Chemistry",
"CaJCE Canadian Journal of Civil Engineering",
"CaJES Canadian Journal of Earth Sciences",
"CJECE Canadian Journal of Electrical Computer Engineering",
"CJMat Canadian Journal of Mathematics",
"CaJPh Canadian Journal of Physics",
"CaJPS Canadian Journal of Physics Supplement",
"CaJRS Canadian Journal of Remote Sensing",
"CJRA. Canadian Journal of Research Section A",
"CJSMT Canadian Journal of Science Mathematics and Technology Education",
"CaJSS Canadian Journal of Soil Science",
"CaRes Cancer Research",
"CPhD. Cape Photographic Durchmusterung",
"CarR. Caries Research",
"GCRV. Carnegie Institute Washington D.C. Publication",
"CarOB Carter Observatory Wellington New Zealand Astronomical Bulletins",
"CarRe Carter Observatory Wellington New Zealand Reprints",
"CasRe Case Western Reserve University Warner and Swasey Observatory Cleveland Ohio Reprints",
"CASI. CASI Transactions",
"CSVS. Catalogue of suspected variable stars. Acad. of Sciences USSR Shternberg.",
"CatL. Catalysis Letters",
"CarRv Catalysis Reviews",
"Catt. CATTECH",
"CCDA. CCD Astronomy",
"CEGB. CEGB Research",
"CeMec Celestial Mechanics",
"CeMDA Celestial Mechanics and Dynamical Astronomy",
"Cell. Cell",
"Cellu Cellulose",
"Cent. Centaurus",
"CfAPr Center for Astrophysics Cambridge Mass Preprint Series",
"CBET. Central Bureau Electronic Telegrams",
"CEAB. Central European Astrophysical Bulletin",
"CEJE. Central European Journal of Engineering",
"CEJG. Central European Journal of Geosciences",
"CEJPh Central European Journal of Physics",
"CPH.. Centre de Physique des Houches",
"CCpFS Ceskoslovensky Casopis pro Fyziku Sekce",
"CFDAA CFD Advances Applications",
"CKH.. Chagyo Kenkyu Hokoku (Tea Research Journal)",
"ChNew Chandra News",
"Chaos Chaos",
"CSF.. Chaos Solitons and Fractals",
"ChCom Chemical Communications",
"ChEdu Chemical Educator",
"ChEnC Chemical Engineering Communications",
"ChEnN Chemical Engineering News",
"CERDA Chemical Engineering Research &amp",
"ChEnS Chemical Engineering Science",
"ChGeo Chemical Geology",
"CP... Chemical Physics",
"CPL.. Chemical Physics Letters",
"CPSS. Chemical Physics of Solid Surfaces",
"CPSSH Chemical Physics of Solid Surfaces and Heterogeneous Catalysis",
"CPR.. Chemical Physics Reports",
"ChSRv Chemical Society Reviews",
"ChEG. Chemie der Erde / Geochemistry",
"CEJ.. Chemistry A European Journal",
"CPCar Chemistry and Physics of Carbon",
"CPLip Chemistry and Physics of Lipids",
"ChUDA Chile Universidad Departamento de Astronomia Publicaciones",
"ChOE. China Ocean Engineering",
"ChRST China Rept Sci Technol JPRS CST",
"ChA.. Chinese Astronomy",
"ChIEJ Chinese Institute of Engineers Journal",
"ChJA. Chinese Journal of Aeronautics",
"ChJAA Chinese Journal of Astronomy and Astrophysics",
"ChJAS Chinese Journal of Astronomy and Astrophysics Supplement",
"ChJCP Chinese Journal of Chemical Physics",
"ChJG. Chinese Journal of Geophysics",
"ChJIR Chinese Journal of Infrared Research",
"ChJL. Chinese Journal of Lasers",
"ChJLB Chinese Journal of Lasers B",
"CJLTP Chinese Journal of Low Temperature Physics",
"ChJME Chinese Journal of Mechanical Engineering",
"ChJNP Chinese Journal of Nuclear Physics",
"ChJOL Chinese Journal of Oceanology and Limnology",
"ChJPh Chinese Journal of Physics",
"ChJPR Chinese Journal of Polar Research",
"ChJS. Chinese Journal of Semiconductors",
"ChJSS Chinese Journal of Space Science",
"ChOpL Chinese Optics Letters",
"ChPhy Chinese Physics",
"ChPhB Chinese Physics B",
"ChPhC Chinese Physics C",
"ChPhL Chinese Physics Letters",
"ChSBu Chinese Science Bulletin",
"ChSAJ Chinese Society of Astronautics Journal",
"ChSMJ Chinese Society of Mechanical Engineers Journal",
"ChSST Chinese Space Science Technology",
"CMDRG Chislennye Metody Dinamike Razrezhennykh Gazov",
"CHOCS CHOCS",
"CITM. Chubu Institute Technology Memoirs",
"CIDA. CIDA",
"CTE.. Ciencias de la Tierra y del Espacio",
"CiInf Circ. Inf.",
"CiSSV Circolare Interna della Sezione Stelle Variabili dell'Unione Astrofili Italiani",
"CSSP. Circuits Systems and Signal Processing",
"CirW. Circuit World",
"CAFOE Circulaire de l'Association Francaise d'Observateurs d'Etoiles Variables",
"CiBAA Circular of the British Astronomical Association",
"CiUO. Circular of the Union Observatory Johannesburg",
"CiPoJ Circumpolar Journal",
"CQGra Classical and Quantum Gravity",
"CQGrS Classical and Quantum Gravity Supplement",
"CRMMP Classical Reviews in Mathematics and Mathematical Physics",
"CTPhy Classical Theoretical Physics",
"CCM.. Clays and Clay Minerals",
"ClDy. Climate Dynamics",
"CliPa Climate of the Past",
"CliPD Climate of the Past Discussions",
"ClCh. Climatic Change",
"COIR. Clinical Oral Implants Research",
"CPPM. Clinical Physics and Physiological Measurement",
"CNRAe CNR Aeritalia S",
"CODAB CODATA Bulletin",
"Coel. Coelum Periodico Bimestrale per la Divulgazione dell'Astronomia",
"AeSc. Collection of Papers on Aerospace Science",
"ColJ. Colloid Journal",
"ColSu Colloids and Surfaces",
"CPC.. Combinatorics, Probability and Computing",
"CoFl. Combustion and Flame",
"CST.. Combustion Science and Technology",
"CTM.. Combustion Theory Modelling",
"CNSMP Comet News Service, McDonnell Planetarium",
"CPMCM Commentationes Physico-Mathematicae et Chemico-Medicae",
"ComMP Comments in Modern Physics",
"ComAp Comments on Astrophysics",
"CoASP Comments on Astrophysics and Space Physics",
"CoAMP Comments on Atomic and Molecular Physics",
"CoCMP Comments on Condensed Matter Physics",
"CoNPP Comments on Nuclear and Particle Physics",
"CoPPC Comments on Plasma Physics and Controlled Fusion",
"ComSp Commercial Space",
"CoKon Commmunications of the Konkoly Observatory Hungary",
"CAPJ. Communication Astronomy with the Public Journal",
"ComBr Communication Broadcasting",
"CoSSC Communication in Statistics - Simulation and Computation",
"CoSTM Communication in Statistics - Theory and Methods",
"Commu Communications",
"CoORB Communications de l'Observatoire Royal de Belgique",
"MonAP Communications du Departement d'Astrophysique de la Faculte des Sciences de Mons Mons Astrophysical Papers",
"CoDDO Communications from the David Dunlap Observatory",
"CoMtW Communications from the Mount Wilson Solar Observatory to the National Academy of Sciences",
"CoRad Communications from the Radcliffe Observatory Pretoria South Africa",
"CoROE Communications from the Royal Observatory Edinburgh",
"CoOxf Communications from the University Observatory Oxford",
"CoStA Communications from the University Observatory St Andrews Scotland",
"CEST. Communications Gillies Inc Electronic Systems in Transportation",
"CoAlg Communications in Algebra",
"CANM. Communications in Applied Numerical Methods",
"CoAst Communications in Asteroseismology",
"CCoPh Communications in Computational Physics",
"CMaPh Communications in Mathematical Physics",
"CNSNS Communications in Nonlinear Science and Numerical Simulations",
"CNME. Communications in Numerical Methods in Engineering",
"CoPDE Communications in Partial Differential Equations",
"CPAM. Communications in Pure Applied Mathematics",
"CoTPh Communications in Theoretical Physics",
"CoAnk Communications of the Department of Astronomy of Ankara University",
"CoLPL Communications of the Lunar and Planetary Laboratory",
"CoLon Communications of the University of London Observatory",
"CPhy. Communications on Physics",
"CRLJ. Communications Research Laboratory Journal",
"CRLRv Communications Research Laboratory Review",
"ComSo Communications Society",
"Compe COMPEL: The International Journal for Computation and Mathematics in Electrical and Electronic Engineering",
"CoVar Complex Variables",
"Compo Composites",
"CmpEn Composites Engineering",
"CmpMa Composites Manufacturing",
"ComST Composites Science Technology",
"CmpSt Composite Structures",
"CoMat Compositio Mathematica",
"CRSPH Compte Rendu des Seances de la Societe de Physique et d'Histoire Naturelle de Genere",
"CR... Comptes Rendus Academie des Sciences (serie non specifiee)",
"CRABS Comptes Rendus de l'Academie Bulgare des Sciences",
"CRASE Comptes Rendus de l'Académie des Sciences - Series IIA - Earth and Planetary Science",
"CRGeo Comptes Rendus Geoscience",
"CRMat Comptes Rendus Mathematique",
"CRMec Comptes Rendus Mecanique",
"CRPhy Comptes Rendus Physique",
"CAMP. Computational and Applied Mathematical Physics",
"ComMS Computational Materials Science",
"CMMPh Computational Mathematics and Mathematical Physics",
"CompM Computational Mechanics",
"COA.. Computational Optimization and Applications",
"CSMA. Computational Structural Mechanics and Applications",
"Compr Computer",
"CAD.. Computer-Aided Design",
"CGIP. Computer Graphics Image Processing",
"CMAME Computer Methods in Applied Mechanics and Engineering",
"CoPhC Computer Physics Communications",
"CoPhR Computer Physics Reports",
"CBR.. Computers and Biomedical Research",
"CEE.. Computers and Electrical Engineering",
"CF... Computers and Fluids",
"CG... Computers and Geosciences",
"CMwA. Computers and Mathematics with Applications",
"CoStr Computers and Structures",
"CSEd. Computer Science Education",
"ComPh Computers in Physics",
"CVIU. Computer Vision and Image Understanding",
"CVGIP Computer Vision Graphics and Image Processing",
"Compu Computing",
"CSE.. Computing in Science and Engineering",
"ComSE Computing Systems in Engineering",
"COMTR COMSAT Technical Review",
"CoCoi Comunicacoes do Observatonio Astronomico da Universidade de Coimbra",
"CoMRA Concepts in Magnetic Resonances A",
"CoMRB Concepts in Magnetic Resonances B",
"CMPhy Condensed Matter Physics",
"CGDAM Conformal Geometry and Dynamics of the American Mathematical Society",
"CDT.. Connaissance des Temps",
"ConSc Connection Science",
"CoFra Consiglio Nazionale delle Ricerche Italia. Laboratorio di Astrofisica Frascati Roma Contributi",
"ConCP Contemporary Concepts in Physics",
"ConFP Contemporary Fundamental Physics",
"ConPh Contemporary Physics",
"CSR.. Continental Shelf Research",
"CMT.. Continuum Mechanics and Thermodynamics",
"CoIAP Contributions de l'Institut d'Astrophysique de Paris Serie A",
"CoIAB Contributions de l'Institut d'Astrophysique de Paris Serie B",
"CoAsi Contributions dell'Osservatorio Astrofisica dell'Universita di Padova in Asiago",
"CoMil Contributions dell'Osservatorio Astrononia di Milano-Merate",
"CoArm Contributions from the Armagh Observatory",
"CoThe Contributions from the Astronomical Department of the University of Thessaloniki",
"CoBos Contributions from the Bosscha Observervatory",
"CoCam Contributions from the Cambridge Observatory England",
"CoTol Contributions from the Cerro Tololo Inter-American Observatory",
"CoTok Contributions from the Department of Astronomy University of Tokyo",
"CoDAO Contributions from the Dominion Astrophysical Observatory in Victoria",
"CoDun Contributions from the Dunsink Observatory Dublin Ireland",
"CoKyo Contributions from the Institute of Astrophysics and Kwasan Observatory Kyoto",
"CoKit Contributions from the Kitt Peak National Observatory",
"CoKwa Contributions from the Kwasan and Hida Observatories University of Kyoto",
"CoIoa Contributions from the Laboratory of Astronomy - University of Ioannina Greece",
"CoMcD Contributions from the McDonald Observatory University of Texas Fort Davis",
"CMWCI Contributions from the Mount Wilson Observatory / Carnegie Institution of Washington",
"CoPri Contributions from the Princeton University Observatory",
"CoRut Contributions from the Rutherford Observatory of Columbia University New York",
"CoWas Contributions from the Washburn Observatory of the University of Wisconsin",
"CoAth Contributions from the Wroclaw Astronomical Observatory",
"CoLic Contributions of Lick Observatory",
"CLic2 Contributions of Lick Observatory, Series II",
"CoPer Contributions of Perkins Observatory",
"CoSka Contributions of the Astronomical Observatory Skalnate Pleso",
"CoSkL Contributions of the Astronomical Observatory Skalnate Pleso Letters",
"CoSkS Contributions of the Astronomical Observatory Skalnate Pleso Supplement",
"CoLou Contributions of the Louisiana State University Observatory Baton Rouge Louisiana",
"CoNMx Contributions of the Observatory of New Mexico State University Las Cruces New Mexico",
"CoBrn Contributions of the Public Observatory and Planetarium in Brno",
"CSASG Contributions of the Slovak Academy Sciences Geophysical Institute",
"CoWat Contributions of the University of Waterloo Observatory",
"CoVVO Contributions of the Van Vleck Observatory",
"ConAP Contributions to Atmospheric Physics/Beitraege zur Physik Atmosphaere",
"CoGG. Contributions to Geophysics and Geodesy",
"CoMP. Contributions to Mineralogy and Petrology",
"CoPP. Contributions to Plasma Physics",
"CoUCL Contributions Universite Catholique de Louvain",
"CoSte Contributions University of Arizona Steward Observatory Tucson Arizona",
"CoRHO Contributions University of Florida Rosemary Hill Observatory Gainesville",
"CoCom Control and Computers",
"CopRe Copenhagen University Observatory Reprints",
"CorRe Coral Reefs",
"CorD. Cordoba Durchmusterung",
"CAGHS Correspondance Astronomique, Geographique, Hydrographique et statistique",
"CosEl Cosmic Electrodynamics",
"CosRe Cosmic Research",
"CosSe Cosmic Search",
"CTP.. Course of Theoretical Physics",
"CRB.. C.R. Acad. Sci. Ser. B1",
"CraRe Cracow Observatory Reprints",
"CRSSM Critical Reviews in Solid State &amp",
"Cryo. Cryogenics",
"CryRp Crystallography Reports",
"CSSE. Cultural Studies of Science Education",
"CuCo. Culture and Cosmos",
"CAP.. Current Applied Physics",
"CCPCE Current Contents Physical Chemical and Earth Sciences",
"CEyeR Current Eye Research",
"CNan. Current Nanoscience",
"COSSM Current Opinion in Solid State and Materials Science",
"CSci. Current Science",
"CySys Cybernetics and Systems",
"CzJPh Czechoslovak Journal of Physics",
"CzJPB Czechoslovak Journal of Physics B",
"CzJPS Czechoslovak Journal of Physics Supplement",
"CzMJ. Czechoslovak Mathematical Journal",
"DTr.. Dalton Transactions",
"DMKD. Data Mining and Knowledge Discovery",
"DatSJ Data Science Journal",
"DDORe David Dunlap Observatory Richmond Hill Reprints",
"DeaCo Dearborn Observatory Contributions",
"DSR.. Deep Sea Research Part II: Topical Studies in Oceanography",
"DSRI. Deep Sea Research Part I: Oceanographic Research",
"DSNPR Deep Space Network Progress Report",
"Defek Defektoskopiia",
"DefEl Defense Electronics",
"DMJ.. Defense Management Journal",
"DeScE Defense Science Electronics",
"DSJ.. Defense Science Journal",
"DSRMC Defense Systems Review Military Communications",
"DSSN. Delta Scuti Star Newsletter",
"Sterb Der Sternenbote Monatsschrift fuer Oesterreichs Amateur-astronomen",
"DGKBA Deutsche Geodaetische Kommission Bayer. Akad. Wiss.",
"DGKBB Deutsche Geodaetische Kommission Bayer. Akad. Wiss. B",
"DGKGN Deutsche Geodaetische Kommission Gravity Network West Germany DSGN Data Adjustment",
"DeHyZ Deutsche Hydrographische Zeitschrift",
"DPhyG Deutsche Physikalische Gesellschaft",
"DSEG. Developments in Solid Earth Geophysics",
"DFVLR DFVLR",
"DRM.. Diamond and Related Materials",
"Stern Die Sterne",
"Welt. Die Weltall",
"DnU.. Differentsial nye Uravneniia",
"DSP.. Digital Signal Processing",
"Dimen Dimensions",
"DiSis Dinamicheskie Sistemy",
"DPM.. Dinamika i Prochnost Mashin",
"DiRaG Dinamika razrezhennykh gazov",
"DIO.. DIO",
"DCMP. Directions in Condensed Matter Physics",
"DISA. DISA Information",
"Disc. Discover",
"DImTe Display Imaging Technology",
"Displ Displays",
"DSE.. Distributed Systems Engineering",
"DLGRM DLGR Magnetofluiddyn",
"Dlib. D-Lib Magazine",
"DLRNa DLR Nachrichten",
"DOCi. Documentation des Observateurs Circulaire",
"DOIAP Documentation des Observateurs Institut d'Astrophysique de Paris",
"DoANT Doklady Akademiia Nauk TadzhSSR",
"DokAN Doklady Akad Nauk Minerologia USSR",
"DoBan Doklady Bolgarskoi Akademiia Nauk",
"DokES Doklady Earth Sciences",
"DokPC Doklady Physical Chemistry",
"DAOAR Dominion Astrophysical Observatory Annual Report",
"DorPo Dornier Post",
"DSO.. Double Star Observer",
"DSSC. Double Star Section Circulars",
"DudOR Dudley Observatory Reports",
"PODE. Dun Echt Observatory Publications",
"DunOP Dunsink Observatory Publications",
"DunRe Dunsink Observatory Reprints",
"DurOO Durham Observatory Observations",
"IzDus Dushanbe Izdatel Donish",
"DyeRe Dyer Observatory Reprints",
"DySys Dynamical Systems: An International Journal",
"DynCo Dynamics and Control",
"DSSys Dynamics and Stability of Systems",
"DyAtO Dynamics of Atmospheres and Oceans",
"EESC. Earth and Environmental Science Conference Series",
"EaEvS Earth and Evolution Sciences",
"EExSc Earth and Extraterrestrial Sciences",
"EaInt Earth Interactions",
"EOAST Earth-Oriented Applications and Space Technology",
"EEEV. Earthquake Engineering and Engineering Vibration",
"EaSci Earthquake Science",
"ESRv. Earth Science Reviews",
"ESPL. Earth Surface Processes and Landforms",
"ESD.. Earth System Dynamics",
"ESDD. Earth System Dynamics Discussion",
"ESSD. Earth System Science Data",
"ESSDD Earth System Science Data Discussions",
"EERST East European Rept Sci. Technol. JPRS ESA",
"EERSA East Europe Rept Sci Affairs JPRS",
"EBCi. Eclipsing Binaries Circulars",
"EcGH. Eclogae geologae Helvetii",
"Ecogr Ecography",
"EcGou Ecole de Goutelas",
"Earth eEarth",
"EartD eEarth Discussions",
"ETATF Eesti NSV Teaduste Akadeemia Toimetised Fuusika Matemaatika",
"IzmP. Ege University Izmir Publications of the Department of Astronomy",
"EJSM. e-Journal of Soft Materials",
"Elast Elastic",
"ECLRv Electrical Communication Laboratories Review",
"JElEn Electrical Engineering of Japan",
"EMPS. Electric Machines and Power Systems",
"Elecm Electromagnetics",
"EJSEd Electronic Journal of Science Education",
"EJSta Electronic Journal of Statistics",
"EJTP. Electronic Journal of Theoretical Physics",
"EML.. Electronic Materials Letters",
"ElPro Electronic Progress",
"JElCo Electronics Communications of Japan",
"ElL.. Electronics Letters",
"ElP.. Electronics Power",
"EOSD. Electro Optical Systems Design",
"ElLC. Electrotechnical Laboratory Circulars",
"ElLR. Electrotechnical Laboratory Researches",
"ElW.. Electrowaerme International",
"ElBah Elektrische Bahnen",
"Elem. Elektromekhanika",
"Elek. Elektronika",
"ElTA. Elektronnaia Tekhnika Avtomatike",
"ElMod Elektronnoe Modelirovanie",
"ETRE. Elektrosviaz Telecommunications Radio Engineering Telecommunications",
"EVest Elektrotehniski Vestnik",
"OED.. El Observador de Estrellas Dobles",
"ElUn. El Universo",
"EMCT. EMC Technology",
"EBBT. Emerging Biochemical and Biophysical Techniques",
"EAA.. Encyclopedia of Astronomy and Astrophysics",
"Endvr Endeavour",
"Energ Energetika",
"EnAt. Energia es Atomtechnika",
"EnUK. Energy",
"EnC.. Energy Conversion",
"ECM.. Energy Conversion Management",
"EnS.. Energy Sources",
"EnTR. Energy Technology Review",
"EnUK. Energy UK",
"EngAn Engineering Analysis",
"EnSci Engineering and Science",
"EngCo Engineering Computations",
"EnFM. Engineering Fracture Mechanics",
"EnOp. Engineering Optimization",
"CEnTp Engineering Thermophysics China",
"Entro Entropie",
"Entrp Entropy",
"EnAPC Environmental Analytical and Physical Chemistry Series",
"EES.. Environmental Earth Sciences",
"EnEng Environmental Engineering",
"EFM.. Environmental Fluid Mechanics",
"EnGeo Environmental Geology",
"EnMan Environmental Management",
"EnP.. Environmental Pollution Series B Chemical and Physical",
"ER... Environmental Research",
"ERL.. Environmental Research Letters",
"EnST. Environmental Science Technology",
"EnTox Environmental Toxicology",
"ETWQ. Environmental Toxicology and Water Quality",
"Env.. Environmentrics",
"EOSTr EOS Transactions",
"EL... EPL (Europhysics Letters)",
"EPRIJ EPRI Journal",
"AnErg Ergaenzungshefte zu den Astronomischen Nachrichten",
"ErNW. Ergebnisse der exakten Naturwissenschaften",
"ETDS. Ergodic Theory and Dynamical Systems",
"Ergo. Ergonomics",
"ESABu ESA Bulletin",
"ESAHR ESA History Study Reports",
"EIUEN ESA IUE Newsletter",
"ESAJ. ESA Journal",
"ESASM ESA Scientific &amp",
"ESAST ESA Scientific Technical Review",
"ESATM ESA Training Manual",
"EssPh Essays in Physics",
"ECSS. Estuarine Coastal and Shelf Science",
"EUCAS EUCASS Proceedings Series",
"EurSS Eurasian Soil Science",
"EJASP EURASIP Journal on Applied Signal Processing",
"EBioJ European Biophysics Journal",
"EJAM. European Journal of Applied Mathematics",
"EJBio European Journal of Biochemistry",
"EJC.. European Journal of Combinatorics",
"EJEE. European Journal of Engineering Education",
"EJMF. European Journal of Mechanics B Fluids",
"EJMS. European Journal of Mechanics Solids",
"EJPh. European Journal of Physics",
"EPJA. European Physical Journal A",
"EPJAP European Physical Journal Applied Physics",
"EPJAS European Physical Journal A Supplement",
"EPJB. European Physical Journal B",
"EPJC. European Physical Journal C",
"EPJCS European Physical Journal C Supplement",
"EPJD. European Physical Journal D",
"EPJE. European Physical Journal E",
"EPJH. European Physical Journal H",
"EPJP. European Physical Journal Plus",
"EPJST European Physical Journal Special Topics",
"EuRv. European Review",
"ESN.. European Science Notes",
"ESOAR European Southern Observatory Annual Reports",
"ESOB. European Southern Observatory ESO Bulletin",
"ESOSP European Southern Observatory Scientific Preprints",
"ESOSR European Southern Observatory Scientific Report",
"ETTRT European Transactions Telecommunications Related Technologies",
"ERST. Europe Report Science Technology",
"EL... Europhysics Letters",
"ENews Europhysics News",
"EXOSA EXOSAT Express",
"ExA.. Experimental Astronomy",
"EEyeR Experimental Eye Research",
"ExHT. Experimental Heat Transfer",
"ExM.. Experimental Mechanics",
"ExMPS Experimental Methods in the Physical Sciences",
"ExT.. Experimental Techniques",
"ExTFS Experimental Thermal Fluid Science",
"ExFl. Experiments in Fluids",
"ExG.. Exploration Geophysics",
"Extr. Extraction",
"PMtv. Facultad de Humanidades y Ciencias Universidad de la Republica Montevideo",
"FaDi. Faraday Discussions",
"FaTr. Faraday Transactions",
"FFEMS Fatigue and Fracture of Engineering Materials and Structures",
"FerNo Fermilab Note",
"Fer.. Ferroelectrics",
"FerLS Ferroelectrics Letters Section",
"FBS.. Few-Body Systems",
"FiIO. Fiber and Integrated Optics",
"Filom Filomat",
"FeMik Finommechanika Mikrotechnika",
"FiBr. First Break",
"FizEl Fizicheskaia Elektronika",
"FiMek Fizicheskaia Mekhanika",
"Fiz.. Fizika",
"FizA. Fizika A",
"FizAS Fizika Aerodispersnykh Sistem",
"FizB. Fizika B",
"FizGV Fizika Goreniia i Vzryva",
"FizKO Fizika i Khimiia Obrabotki Materialov",
"FizTV Fizika i Tekhnika Vysokikh Davlenii",
"FizMM Fizika Metallov i Metallovedenie",
"FizMS Fizika Mnogochastichnykh Sistem",
"FizNT Fizika Nizkikh Temperatur",
"FizPl Fizika Plazmy",
"FizSz Fizika Sz.",
"FizTT Fizika Tverdogo Tela",
"FizZS Fizika Zhidkogo Sostoianiia",
"FizAt Fiziki Atmosfery",
"FizKM Fiziko Khimicheskaia Mekhanika Materialov",
"FizCh Fizyki i Chemii Seria Fizyka",
"FliIn Flight International",
"FNL.. Fluctuation and Noise Letters",
"FRFI. Flug Revue Flugwelt International",
"FlDy. Fluid Dynamics",
"FlDyR Fluid Dynamics Research",
"FlDyT Fluid Dynamics Transactions",
"Fluid Fluidika",
"FMAG. Fluid Mechanics of Astrophysics and Geophysics",
"FlMSR Fluid Mechanics Soviet Research",
"FluQ. Fluids Quarterly",
"FBP.. Food and Bioproducts Processing. Part C, Transactions of the Institution of Chemical Engineers",
"ForPh Fortschritte der Physik",
"FoGeo Fotointerpretacja w Geografii",
"FoPh. Foundations of Physics",
"FoPhL Foundations of Physics Letters",
"Fract Fractals",
"Freq. Frequenz",
"FrES. Frontiers of Earth Science",
"FrMS. Frontiers of Materials Science",
"FrME. Frontiers of Mechanical Engineering",
"FrPhy Frontiers of Physics",
"FrPhC Frontiers of Physics in China",
"IzFru Frunze Izdatel Ilim",
"FSTJ. Fujitsu Scientific Technical Journal",
"FST.. Fullerene Science and Technology",
"FAAp. Functional Analysis and Its Applications",
"FML.. Functional Materials Letters",
"FACM. Functiones et Approximatio Commentarii Mathematici",
"FInfo Fundamenta Informaticae",
"FANP. Fundamental and Applied Nuclear Physics Series",
"OOPS. Fundamental nye Osnovy Opticheskoi Pamiati i Sredy",
"FCPh. Fundamentals of Cosmic Physics",
"FTP.. Fundamental Theories of Physics",
"Futur Future Spring",
"GCNew Galactic Center Newsletter",
"galxp GALEX Proposal",
"GalEl Galilean Electrodynamics",
"GEB.. Games and Economic Behavior",
"GGMit Gauss-Gesellschaft e.V. Göttingen, Mitteilungen",
"GVPOO Gauthier-Villars Paris Observatory Observations",
"GazA. Gazette Astronomique",
"GazAM Gazette Astronomique Memoires",
"GazT. Gazodinamika i Teploobmen",
"GCNR. GCN Report",
"GECJR GEC Journal Research",
"Gelio Geliotekhnika",
"Gemin GEMINI Newsletter Royal Greenwich Observatory",
"GHA.. General History of Astronomy",
"GPB.. General Physiology and Biophysics",
"GReGr General Relativity and Gravitation",
"Gen.. Genetica",
"GeoIn Geocarto International",
"GeocJ Geochemical Journal",
"Geoch Geochemistry",
"GGG.. Geochemistry, Geophysics, Geosystems",
"GeocI Geochemistry International",
"GeCoA Geochimica et Cosmochimica Acta",
"GeCAS Geochimica et Cosmochimica Acta Supplement",
"GeCar Geodesy and Cartography",
"GeAer Geodeziia i Aerofotos",
"GeKar Geodeziia i Kartografiia",
"GKA.. Geodeziia i Kartografiia Aehrofotosemka, L'vov",
"GeKaA Geodeziia Kartografiia i Aerofotos",
"GeoK. Geodezja i Kartografia",
"GeoAc Geodinamica Acta",
"GeofI Geofisica Internacional",
"GeoPA Geofisica Pura e Applicata",
"GeoSb Geofizicheskii Sbornik",
"GeoZh Geofizicheskii Zhurnal",
"GeoAA Geografiska Annaler, Series A: Physical Geography",
"GeoAB Geografiska Annaler, Series B: Human Geography",
"GeIss Geoinformation Issues",
"Geokh Geokhimiia",
"GCarp Geologica Carpathica",
"GeolJ Geological Journal",
"GeoM. Geological Magazine",
"GeoSJ Geological Society Journal",
"GSAMB Geological Society of America Bulletin",
"GSAMm Geological Society of America Memoir",
"GSASP Geological Society of America Special Papers",
"GSLSP Geological Society of London Special Publications",
"Geolo Geologija",
"GeoRu Geologische Rundschau",
"Geolg Geologos",
"Geo.. Geology",
"GeoOD Geology of Ore Deposits",
"GeoIs Geomagnitnye Issledovaniia",
"GML.. Geo-Marine Letters",
"GeoD. Geometriae Dedicata",
"GeomJ Geomicrobiology Journal",
"Geomo Geomorphology",
"Geoph Geophysica",
"GeGe. Geophysica et Geodaetica",
"GApFD Geophysical and Astrophysical Fluid Dynamics",
"GDS.. Geophysical Developments Series",
"GeoJ. Geophysical Journal",
"GeoJI Geophysical Journal International",
"GeopP Geophysical Prospecting",
"GeopR Geophysical References",
"GeoRL Geophysical Research Letters",
"GeoSu Geophysical Surveys",
"GeoNr Geophysica Norvegica",
"Geop. Geophysics",
"GAM.. Geophysics and Astrophysics Monographs",
"GeoOM Georgetown Observatory Monogram",
"GeoRe Georgetown Observatory Reprints",
"GMD.. Geoscientific Model Development",
"GMDD. Geoscientific Model Development Discussions",
"GEOCE GEOS Circular on Eclipsing Binaries",
"GEOCR GEOS Circular on RR Lyr Type Variables",
"GEOCA GEOS Circular on Small-Amplitude Variables",
"GEOSN GEOS Note Circulaire",
"Geote Geotectonics",
"TrGRC Geothermal Resources Council Transactions",
"Geoth Geothermics",
"Geot. Geotimes",
"Gerb. Gerbertvs, International Academic Publication on History of Medieval Science",
"GBzG. Gerlands Beitraege zur Geophysik",
"GUL.. Geschichte und Lichtwechsel der Veraenderlichen Sterne (Potsdam)",
"GATAN Gesellschaft Aerosolforschung Tagung ueber Aerosole Naturwissenschaft Medizin und Technik Messtechnik und technische Anwendung",
"GMMWJ Gesellschaft angewandte Mathematik und Mechanik Jahrestagung Goettingen West Germany Zeitschrift Flugwissenschaften",
"GaMuM Gesellschaft Angewandte Mathematik und Mechanik Workshop Paris France",
"GMuD. Gesellschaft Mathematik und Datenverarbeitung mbH Multigrid Methods Special Topics Applications",
"GVMK. Gibridnye Vychislitel nye Mashiny i Kompleksy",
"Gidro Gidromekhanika",
"GiGi. Gidroprivod i Gidropnevmoavtomatika",
"GiSan Gigiena i Sanitariia",
"GTPZ. Gigiena Truda i Professional nye Zabolevaniia",
"GAst. Giornale di Astronomia",
"GlMaJ Glasgow Mathematical Journal",
"GPC.. Global and Planetary Change",
"GBioC Global Biogeochemical Cycles",
"GLORe Goethe Link Observatory Reprints",
"GPSW. GPS World",
"GMIP. Graphical Models and Image Processing",
"GrCo. Gravitation and Cosmology",
"GrCoS Gravitation and Cosmology Supplement",
"GrTOn Gravitatsiia i Teoriia Otnositel nosti",
"GCN.. GRB Coordinates Network",
"GGMM. Greenhouse Gas Measurement &amp",
"GriO. Griffith Observer",
"GrAeH Grumman Aerospace Horizons",
"Grund Grundwasser",
"GICi. Gruppo Italiano RV Tauri Circolare",
"HalRe Hale Observatories Reprints",
"HadJ. Hadronic Journal",
"HadJS Hadronic Journal Supplement",
"BSD.. Hamburger Sternwarte Bergedorf",
"HamS. Hamburger Sternwarte Sonderdrucke",
"LS... Hamburger Sternw. Warner &amp",
"HAAG. Handbook of Astronomy Astrophysics and Geophysics",
"HBP.. Handbook of Biological Physics",
"HGE.. Handbook of Geophysical Exploration",
"HPlPh Handbook of Plasma Physics",
"HPCRE Handbook on the Physics and Chemistry of Rare Earths",
"HDA.. Handbuch der Astrophysik",
"HDP.. Handbuch der Physik",
"HarZi Harthaer Beobachtungs-Zirkular",
"HarAC Harvard College Observatory Announcement Card",
"HarAR Harvard College Observatory Annual Report",
"BHarO Harvard College Observatory Bulletin",
"HarCi Harvard College Observatory Circular",
"HarPa Harvard College Observatory Papers",
"HarRe Harvard College Observatory Reprints",
"HarMi Harvard Observatory Mimeograms",
"HarMo Harvard Observatory Monographs",
"HeaPh Health Physics",
"HMT.. Heat and Mass Transfer",
"HTrEn Heat Transfer Engineering",
"HTJR. Heat Transfer Japanese Research",
"HTSR. Heat Transfer Soviet Research",
"Heavn Heavens",
"HWM.. Helgoländer Wissenschaftliche Meeresuntersuchungen",
"HMR.. Helgoland Marine Research",
"AcHCh Helvetica Chimica Acta",
"AcHPh Helvetica Physica Acta",
"AcHPS Helvetica Physica Acta Supplementum",
"HelOB Helwan Institute of Astronomy and Geophysics Bulletins",
"HemD. Hemel en Dampkring",
"HECh. High Energy Chemistry",
"HEDP. High Energy Density Physics",
"HEPNP High Energy Physics and Nuclear Physics",
"HiA.. Highlights of Astronomy",
"HPP.. High Performance Polymers",
"HPR.. High Pressure Research",
"HiTec High Technology",
"HTHP. High Temperatures and High Pressures",
"HTemS High Temperature Science",
"HARSB Histoire de l'Academie Royale des Sciences et des Belles-Lettres de Berlin",
"HSPBS Historical Studies in the Physical and Biological Sciences",
"HGeo. History of Geophysics",
"HGSS. History of Geo- and Space Sciences",
"HisSc History of Science",
"HUFEB Hokkaido University Faculty Engineering Bulletin",
"HUFEM Hokkaido University Faculty Engineering Memoirs",
"Holz. Holzforschung",
"HBB.. Horizons in Biochemistry and Biophysics",
"HWP.. Horizons in World Physics",
"HCHy. Hovering Craft and Hydrofoil",
"HGT.. Human Gene Therapy",
"HvaOB Hvar Observatory Bulletin",
"HvOBS Hvar Observatory Bulletin Supplement",
"HyBio Hydrobiologia",
"HydJ. Hydrogeology Journal",
"HyPr. Hydrological Processes",
"HESS. Hydrology and Earth System Sciences",
"HESSD Hydrology and Earth System Sciences Discussions",
"HyInt Hyperfine Interactions",
"IadEn Iadernaia Energiia",
"IAGBu IAGA Bulletin",
"IaIaF Iakutsk Iakutskii Filial SO AN SSSR",
"BSEEA Iasi Institutul Politehnic Buletinul Sectia Electrotehnica Electronica Automatizari",
"BSMMT Iasi Institutul Politehnic Buletinul Sectia Matematica Mecanica Teoretica Fizica",
"BSMT. Iasi Institutul Politehnic Buletinul Sectia Mecanica Tehnica",
"IAUCB IAU Commission on Close Binary Stars",
"IAUDS IAU Commission on Double Stars",
"IAUIn IAU Commission on Instruments",
"IAUGA IAU General Assembly",
"IAUIB IAU Information Bulletin",
"IAUSS IAU Special Session",
"WFINw IAU Working Group on Wide-Field Imaging, Newsletter",
"IBMJ. IBM Journal of Research and Development",
"ICAOB ICAO Bulletin",
"Icar. Icarus",
"IAESM IEEE Aerospace Electronic Systems Magazine",
"IAWPL IEEE Antennas and Wireless Propagation Letters",
"IAPM. IEEE Antennas Propagation Magazine",
"IASSP IEEE ASSP Magazine",
"ICiSM IEEE Circuits Systems Magazine",
"IComM IEEE Communications Magazine",
"ICSEn IEEE Computational Science and Engineering",
"ICGA. IEEE Computer Graphics Applications",
"ICSM. IEEE Computer Systems Magazine",
"IDTC. IEEE Design Test Computers",
"IEDL. IEEE Electron Device Letters",
"IExp. IEEE Expert",
"IGRSL IEEE Geoscience and Remote Sensing Letters",
"IISys IEEE Intelligent Systems",
"IJOE. IEEE Journal of Oceanic Engineering",
"IJQE. IEEE Journal of Quantum Electronics",
"IJRA. IEEE Journal of Robotics Automation",
"ISTSP IEEE Journal of Selected Topics in Signal Processing",
"IJSSC IEEE Journal of Solid-State Circuits",
"IJSAC IEEE Journal on Selected Areas in Communications",
"ILCSM IEEE LCS Magazine",
"ILTS. IEEE LTS",
"IMGWL IEEE Microwave and Guided Wave Letters",
"IMMag IEEE Microwave Magazine",
"IEEEN IEEE Network",
"IPTL. IEEE Photonics Technology Letters",
"IEEEP IEEE Proceedings",
"ISPL. IEEE Signal Processing Letters",
"ISPM. IEEE Signal Processing Magazine",
"IEEES IEEE Spectrum",
"ISysJ IEEE Systems Journal",
"ITASS IEEE Transactions on Acoustics Speech and Signal Processing",
"ITAES IEEE Transactions on Aerospace Electronic Systems",
"ITAP. IEEE Transactions on Antennas and Propagation",
"ITAS. IEEE Transactions on Applied Superconductivity",
"ITAC. IEEE Transactions on Automatic Control",
"ITBE. IEEE Transactions on Biomedical Engineering",
"ITB.. IEEE Transactions on Broadcasting",
"ITCS. IEEE Transactions on Circuits Systems",
"ITCom IEEE Transactions on Communications",
"ITCHM IEEE Transactions on Components Hybrids and Manufacturing Technology",
"ITCAD IEEE Transactions on Computer Aided Design",
"ITCmp IEEE Transactions on Computers",
"ITDEI IEEE Transactions on Dielectrics and Electrical Insulation",
"ITEdu IEEE Transactions on Education",
"ITEI. IEEE Transactions on Electrical Insulation",
"ITElC IEEE Transactions on Electromagnetic Compatibility",
"ITED. IEEE Transactions on Electron Devices",
"ITEnC IEEE Transactions on Energy Conversion",
"ITEM. IEEE Transactions on Engineering Management",
"ITGRS IEEE Transactions on Geoscience and Remote Sensing",
"ITGE. IEEE Transactions on Geoscience Electronics",
"ITIP. IEEE Transactions on Image Processing",
"ITIE. IEEE Transactions on Industrial Electronics",
"ITIEC IEEE Transactions on Industrial Electronics and Control Instrumentation",
"ITIA. IEEE Transactions on Industry Applications",
"ITIT. IEEE Transactions on Information Theory",
"ITIM. IEEE Transactions on Instrumentation Measurement",
"ITM.. IEEE Transactions on Magnetics",
"ITMI. IEEE Transactions on Medical Imaging",
"ITMTT IEEE Transactions on Microwave Theory Techniques",
"ITME. IEEE Transactions on Military Electronics",
"ITNan IEEE Transactions on Nanotechnology",
"ITNN. IEEE Transactions on Neural Networks",
"ITNS. IEEE Transactions on Nuclear Science",
"ITPHP IEEE Transactions on Parts Hybrids and Packaging",
"ITPAM IEEE Transactions on Pattern Analysis and Machine Intelligence",
"ITPS. IEEE Transactions on Plasma Science",
"ITPAS IEEE Transactions on Power Apparatus Systems",
"ITPD. IEEE Transactions on Power Delivery",
"ITPE. IEEE Transactions on Power Electronics",
"ITR.. IEEE Transactions on Reliability",
"ITRA. IEEE Transactions on Robotics Automation",
"ITSTQ IEEE Transactions on Selected Topics in Quantum Electronics",
"ITSM. IEEE Transactions on Semiconduct M",
"ITSP. IEEE Transactions on Signal Processing",
"ITSE. IEEE Transactions on Software Engineering",
"ITSU. IEEE Transactions on Sonics Ultrasonics",
"ITSMC IEEE Transactions on Systems Man and Cybernetics",
"ITUFF IEEE Transactions on Ultrasonics Ferroelectrics and Frequency Control",
"ITVT. IEEE Transactions on Vehicular Technology",
"JMOA. IEE Journal of Microwaves Optics and Acoustics",
"JSSED IEE Journal of Solid-State Electron Devices",
"ITEIS IEEJ Transactions on Electronics, Information and Systems",
"IJTFM IEEJ Transactions on Fundamentals and Materials",
"IJTIA IEEJ Transactions on Industry Applications",
"IJTPE IEEJ Transactions on Power and Energy",
"IJTSM IEEJ Transactions on Sensors and Micromachines",
"IPEPA IEE Proceedings B: Electric Power Applications",
"IPGTD IEE Proceedings C: Generation Transmission Distribution",
"IPCSV IEE Proceedings: Communications Speech and Vision",
"IPCTA IEE Proceedings D: Control Theory Applications",
"IPCDT IEE Proceedings E: Computers and Digital Techniques",
"IPCRS IEE Proceedings F: Communications Radar and Signal Processing",
"IPRSP IEE Proceedings F: Radar and Signal Processing",
"IPMAP IEE Proceedings H: Microwaves Antennas and Propagation",
"IPMOA IEE Proceedings H: Microwaves Optics and Antennas",
"IPOpt IEE Proceedings J: Optoelectronics",
"IPPSM IEE Proceedings: Physical Science Measurement and Instrumentation Management and Education Reviews",
"IPSSE IEE Proceedings: Solid-State Electron Devices",
"IEERv IEE Reviews",
"IEIEE IEICE Electronics Express",
"ESSFR IEICE ESS Fundamentals Review",
"IEITC IEICE Transactions on Communications",
"IEITE IEICE Transactions on Electronics",
"IEITF IEICE Transactions on Fundamentals of Electronics Communications and Computer Sciences",
"IEITI IEICE Transactions on Information and Systems",
"ITN.. IERS Technical Note",
"IESJ. IES Journal",
"IHWN. IHW Newsletter",
"JApMa IMA Journal of Applied Mathematics",
"IJNA. IMA Journal of Numerical Analysis",
"IVMA. IMA Volumes in Mathematics and its Applications",
"IMEPA IME Proceedings. Part A: Journal of Power and Energy",
"IMEPB IME Proceedings. Part B: Journal of Engineering Manufacture",
"IMEPC IME Proceedings. Part C: Journal of Mechanical Engineering Science",
"IMEPD IME Proceedings. Part D: Journal of Automobile Engineering",
"IMEPE IME Proceedings. Part E: Journal of Process Mechanical Engineering",
"IMEPG IME Proceedings. Part G: Journal of Aerospace Engineering",
"IMEPH IME Proceedings. Part H: Journal of Engineering in Medicine",
"IMEPI IME Proceedings. Part I: Journal of Systems and Control Engineering",
"IMEPK IME Proceedings. Part K: Journal of Multibody Dynamics",
"ICSE. Impact of Computing in Science and Engineering",
"InEPS Indian Academy of Sciences Proceedings: Earth and Planetary Sciences",
"InMS. Indian Academy of Sciences Proceedings Mathematical Sciences",
"InASP Indian Academy of Sciences Proceedings Section",
"InES. Indian Academy of Sciences Proceedings: Section C Engineering Sciences",
"IUMJ. Indiana University Mathematics Journal",
"IIApN Indian Institute of Astrophysics Newsletter",
"InISJ Indian Institute of Science Journal",
"InISA Indian Institute of Science Journal of Aeronomical Society of India",
"ITJSE Indian Institute of Technology Journal on Section Engineering Technology",
"InJAE Indian Journal of Aerospace Engineering Division",
"InJBB Indian Journal of Biochemistry and Biophysics",
"InJET Indian Journal of Electronics Telecommunication Engineering Division",
"InJME Indian Journal of Mechanical Engineering Division",
"IJMHG Indian Journal of Meteorology Hydrology and Geophysics",
"InJPh Indian Journal of Physics",
"InJP. Indian Journal of Physics and Proceedings of the Indian Assocatiation for the Cultivation of Science",
"InJPA Indian Journal of Physics Section A",
"InJPB Indian Journal of Physics Section B",
"IJPAM Indian Journal of Pure and Applied Mathematics",
"IJPAP Indian Journal of Pure and Applied Physics",
"IJRSP Indian Journal of Radio and Space Physics",
"InJHS Indian Journal of the History of Science",
"InJTP Indian Journal of Theoretical Physics",
"INSAP Indian National Science Academy Proceedings Supplement",
"IDAQP Infinite Dimensional Analysis, Quantum Probability and Related Topics",
"IBSH. Informational Bulletin of the Southern Hemisphere",
"IBUAA Informational Bulletin of the Ukrainian Astronomical Association",
"InCo. Information and Computation",
"IBVS. Information Bulletin on Variable Stars",
"InfCo Information Control",
"InfD. Information Display",
"IPM.. Information Processing and Management",
"IPL.. Information Processing Letters",
"ISNL. Information Systems Newsletter",
"IRA.. Infrared Astronomy",
"InfPh Infrared Physics",
"InPhT Infrared Physics and Technology",
"Ingeg Ingegneria",
"IngAr Ingenieur Archiv",
"InCh. Inorganic Chemistry",
"IAL1K Institut d'Astronomie de Lausanne",
"IMA.. Institute for Mathematics and Its Applications",
"InFuJ Institute Fuel Journal",
"JIECE Institute of Electronics Communication Engineers of Japan Transactions Section E English",
"IPASA Institute of Physics Academia Sinica Annual Report",
"ISASS Institute of Space and Astronautical Science Report",
"ITABO Institute of Theoretical Astrophysics, Blindern-Oslo",
"OslR. Institute of Theoretical Astrophysics Blindern Oslo Reports",
"IEAEE Institution Engineers Australia Electrical Engineering Transactions",
"IEEP. Institution of Electrical Engineers Proceedings",
"IEREJ Institution of Electronic Radio Engineers Journal",
"IETE. Institution of Electronics Telecommunication Engineers",
"IAFET Instituto de Astronomia y Fisica del Espacio Buenos Aires",
"MerRe Instituto Venezolano de Astronomia Merida Venezuela",
"IRMBP Institut Royal Meteorologique de Belgique Publications Serie",
"ITAB. Institut Teoreticheskoi Astronomii Byulleten",
"TrITA Institut Teoreticheskoi Astronomii Trudy",
"IET.. Instruments and Experimental Techniques",
"InLoP Instytut Lotnictwa Prace",
"InMPP Instytut Maszyn Przeplywowych Prace",
"IntaC Inta Conie",
"ITSF. Integral Transforms and Special Functions",
"ICAE. Integrated Computer-Aided Engineering",
"InFer Integrated Ferroelectrics",
"Inter Interavia",
"IntSM Interavia Space Markets",
"ISRv. Interdisciplinary Science Reviews",
"IFB.. Interfaces and Free Boundaries",
"IPAUC INTERKOSMOS Prague Astronomicky Ustav Ceskoslovenske Akademie Ved",
"IANT. International Advances in Nondestructive Testing",
"IntAg International Agrophysics",
"IAPPP International Amateur-Professional Photoelectric Photometry Communications",
"IAM.. International Applied Mechanics",
"IAUC. International Astronomical Union Circular",
"ICQ.. International Comet Quarterly",
"ICHMT International Communications in Heat and Mass Transfer",
"IrPH. International Conference Infrared Physics Zurich Switzerland",
"ICML. International Conference on Machine Learning",
"IER.. Internationale Elektronische Rundschau",
"InGeo International Geophysics Series",
"IJCEM International Journal for Computational Methods in Engineering Science and Mechanics",
"IJNAM International Journal for Numerical and Analytical Methods in Geomechanics",
"IJNME International Journal for Numerical Methods in Engineering",
"IJNMF International Journal for Numerical Methods in Fluids",
"IJRPC International Journal for Radiation Physics and Chemistry",
"IJACS International Journal of Adaptive Control and Signal Processing",
"IJAdA International Journal of Adhesion Adhesives",
"IJASS International Journal of Aeronautical and Space Sciences",
"IJAEM International Journal of Analytical and Experimental Modal Analysis",
"IJAEO International Journal of Applied Earth Observation and Geoinformation",
"IJApE International Journal of Electromagnetics and Mechanics",
"IJAIS International Journal of Applied Information Systems",
"IJAM. International Journal of Applied Mechanics",
"IJAsB International Journal of Astrobiology",
"IJAA. International Journal of Astronomy and Astrophysics",
"IJAP. International Journal of Aviation Psychology",
"IJBC. International Journal of Bifurcation and Chaos",
"IJBB. International Journal of Bioclimatology Biometeorology",
"IJBm. International Journal of Biometeorology",
"IJCli International Journal of Climatology",
"IJCES International Journal of Computational Engineering Science",
"IJCFD International Journal of Computational Fluid Dynamics",
"IJCMS International Journal of Computational Materials Science and Engineering",
"IJCA. International Journal of Computer Applications",
"IJCAT International Journal of Computer Applications and Technology",
"IJCMB International Journal of Computer Mathematics Section B",
"IJCV. International Journal of Computer Vision",
"IJC.. International Journal of Control",
"IJDM. International Journal of Damage Mechanics",
"IJDE. International Journal of Digital Earth",
"IJDF. International Journal of Dynamics of Fluids",
"IJEaS International Journal of Earth Sciences",
"IJE.. International Journal of Electronics",
"IJER. International Journal of Energy Research",
"IJEFM International Journal of Engineering and Fluid Mechanics Spring",
"IJES. International Journal of Engineering Science",
"IJFa. International Journal of Fatigue",
"IJFD. International Journal of Fluid Dynamics",
"IJFr. International Journal of Fracture",
"IJFE. International Journal of Fusion Energy",
"IJGS. International Journal of General Systems",
"IJGA. International Journal of Geomagnetism and Aeronomy",
"IJGMM International Journal of Geometric Methods in Modern Physics",
"IJGeo International Journal of Geophysics",
"IJGNP International Journal of Green Nanotechnology Physics and Chemistry",
"IJHFF International Journal of Heat and Fluid Flow",
"IJHMT International Journal of Heat and Mass Transfer",
"IJHSC International Journal of High Speed Computing",
"IJHSE International Journal of High Speed Electronics and Systems",
"IJHM. International Journal of Hybrid Microelectronics Fall",
"IJHE. International Journal of Hydrogen Energy",
"IJHy. International Journal of Hyperthermia",
"IJIDF International Journal of Image and Data Fusion",
"IJIG. International Journal of Image and Graphics",
"IJIST International Journal of Imaging Systems Technology",
"IJIE. International Journal of Impact Engineering",
"IJIMW International Journal of Infrared and Millimeter Waves",
"IJICS International Journal of Intelligent Control and Systems",
"IJMSE International Journal of Mars Science and Exploration",
"IJMSp International Journal of Mass Spectrometry",
"IJMSI International Journal of Mass Spectrometry and Ion Processes",
"IJMES International Journal of Mathematical Education in Science and Technology",
"IJM.. International Journal of Mathematics",
"IJMS. International Journal of Mechanical Sciences",
"IJMW. International Journal of Mine Water",
"IJMM. International Journal of Mini Microcomputers",
"IJMoS International Journal of Modelling and Simulation",
"IJMPA International Journal of Modern Physics A",
"IJMPB International Journal of Modern Physics B",
"IJMPC International Journal of Modern Physics C",
"IJMPS International Journal of Modern Physics Conference Series",
"IJMPD International Journal of Modern Physics D",
"IJMPE International Journal of Modern Physics E",
"IJMF. International Journal of Multiphase Flow",
"IJN.. International Journal of Nanoscience",
"IJNT. International Journal of Nanotechnology",
"IJNS. International Journal of Neural Systems",
"IJNLM International Journal of Non Linear Mechanics",
"IJNOP International Journal of Nonlinear Optical Physics",
"IJNMH International Journal of Numerical Methods for Heat &amp",
"IJOpt International Journal of Optics",
"IJOMS International Journal of Oral and Maxillofacial Surgery",
"IJPRS International Journal of Photogrammetry and Remote Sensing",
"IJPES International Journal of Physical and Engineering Sciences",
"IJP.. International Journal of Plasticity",
"IJPM. International Journal of Polymeric Materials",
"IJPG. International Journal of Population Geography",
"IJPR. International Journal of Production Research",
"IJQC. International Journal of Quantum Chemistry",
"IJRAI International Journal of Radiation Applications and Instrumentation D Nuclear Tracks and Radiation Measurements",
"IJRB. International Journal of Radiation Biology",
"IJRQS International Journal of Reliability, Quality and Safety Engineering",
"IJRS. International Journal of Remote Sensing",
"IJRR. International Journal of Robotics Research",
"IJSC. International Journal of Satellite Communications",
"IJSME International Journal of Science and Mathematics Education",
"IJSEd International Journal of Science Education",
"IJSE. International Journal of Solar Energy",
"IJSS. International Journal of Solids and Structures",
"IJSSD International Journal of Structural Stability and Dynamics",
"IJScA International Journal of Supercomputer Applications",
"IJSyS International Journal of Systems Science",
"IJTP. International Journal of Theoretical Physics",
"IJT.. International Journal of Thermophysics",
"IJTJE International Journal of Turbo Jet Engines",
"IMRv. International Materials Reviews",
"IMeRv International Metals Reviews",
"IREdu International Review of Education",
"IRH.. International Review of Hydrobiology",
"IRNP. International Review of Nuclear Physics",
"IRPC. International Reviews in Physical Chemistry",
"ISBRv International Space Business Review",
"IUGG. International Union of Geodesy and Geophysics General Assembly",
"IPNPR Interplanetary Network Progress Report",
"IMPA. Interscience Monographs in Physics and Astronomy",
"ITPA. Interscience Tracts on Physics and Astronomy",
"InMat Inventiones Mathematicae",
"InvPr Inverse Problems",
"IGeo. Investigations in Geophysics",
"InFiZ Inzhenerno Fizicheskii Zhurnal",
"IonIs Ionosfernye Issledovaniia",
"Iono. Ionosphere",
"Ippa. Ipparchos",
"IrJST Iranian Journal of Science Technology",
"IRETE IRE Transactions on Education",
"IrAJ. Irish Astronomical Journal",
"IrAJS Irish Astronomical Journal Supplement",
"ISAP. ISA Proceedings",
"ISAT. ISA Transactions",
"IHERv Ishikawajima Harima Engineering Review",
"Isis. Isis. Journal of the History of Science Society",
"IPBS. Isotopes in the Physical and Biomedical Sciences",
"IsJT. Israel Journal of Technology",
"IsSRT Israel Space Research and Technology Information Bulletin",
"ISRAA ISRN Astronomy and Astrophysics",
"ISCJS ISRO Satellite Centre Journal of Spacecraft Technology",
"ISSIR ISSI Scientific Reports Series",
"ISSIR ISSI Scientific Reports Series",
"IssZK Issledovanie Zemli Fiz Kosmosa",
"IGAFS Issledovaniia Geomagnetizmu Aeronomii i Fizike Solntsa",
"IsMTD Issledovaniia Mekhanike i Teploobmenu Dvukhfaznykh Sred",
"IssUP Issledovaniia Uprugosti i Plastichnosti",
"ISKZ. Issledovaniya Solntsa i Krasnykh Zvezd",
"IST.. Issues in Science and Technology",
"IsJAP Istanbul University Faculty of Science Journal of Astronomy Physics",
"IsRvC Istanbul University Faculty Science Review Serie C",
"IINA. Istituto Italiano di Navigazione Atti",
"IAIss Istoriko-Astronomicheskie Issledovaniya",
"ITCJ. ITC Journal",
"INTSA Itogi Nauki i Tekhniki Seriia Astronomiia",
"INTSF Itogi Nauki i Tekhniki Seriia Fizika Plazmy",
"INTSI Itogi Nauki i Tekhniki Seriia Issledovanie Kosmicheskogo Prostranstva",
"INTMK Itogi Nauki i Tekhniki Seriia Meteorologiia i Klimatologiia",
"INTSO Itogi Nauki i Tekhniki Seriia Okeanologiia",
"INTSR Itogi Nauki i Tekhniki Seriia Radiotekhnika",
"INTSS Itogi Nauki i Tekhniki Seriia Sovremennye Problemy Matematiki",
"INTSV Itogi Nauki i Tekhniki Seriia Vozdushnyi Transport",
"ITUTJ ITU Telecommunication Journal",
"IUEEN IUE ESA Newsletter",
"IUENN IUE NASA Newsletter",
"IzTad Izvestiia Akademiia Nauk TadzhSSR",
"IzSF. Izvestiia Akademii Nauk Seriya Fizicheskaya",
"IzGla Izvestiia Glavnoi rossiiskoi astronomicheskoi observatorii",
"IzVGA Izvestiia vuzov. Geodeziia Aehrofotosemka",
"IzVF. Izvestiia Vysshaia Uchebn. Zaved., Fizika",
"IzVUZ Izvestiia Vysshaia Uchebn. Zaved., Radiofizika",
"IzAsh Izvestiya Akademii Nauk Turkmenskoj SSR Ashkhabad",
"IzArm Izvestiya Akademiya Nauk Armyanskoi",
"IzAlm Izvestiya Astrofizicheskogo Instituta Alma-Ata",
"IzEhn Izvestiya Astronomicheskoj Engel'gardt obskoj Observatorii Kazan",
"IzAOP Izvestiya Atmospheric and Oceanic Physics",
"IzKie Izvestiya Glavnoj Astronomicheskoj Observatorii Kiev",
"IzPul Izvestiya Glavnoj Astronomicheskoj Observatorii v Pulkove",
"IzMat Izvestiya: Mathematics",
"IzAne Izvestiya na Fizicheskiya Institut s Aneb",
"IzKry Izvestiya Ordena Trudovogo Krasnogo Znameni Krymskoj Astrofizicheskoj Observatorii",
"IzPSE Izvestiya Physics of the Solid Earth",
"IzAvT Izvestiya VUZ Aviatsionnaya Tekhnika",
"IzRad Izvestiya VUZ Radiofizika",
"IzNic Izviestiia Nikolaevskoi glavnoi astronomicheskoi observatorii",
"JWUDF Jahns Wöchentliche Unterhaltungen Für Dilettanten und Freunde der Astronomie, Georgraphie und Witterungskunde",
"JRE.. Jahrbuch der Radioaktivität und Elektronik",
"JASAC Japan Astronomical Study Association Circulars",
"JaJAP Japanese Journal of Applied Physics",
"JJAPL Japanese Journal of Applied Physics Letters B",
"JJAPR Japanese Journal of Applied Physics Regular Papers Short Notes and Review Papers",
"JJAPS Japanese Journal of Applied Physics Supplement",
"JaJAG Japanese Journal of Astronomy and Geophysics",
"JMMPS Japanese Magazine of Mineralogical and Petrological Sciences",
"JaIMJ Japan Institute of Metals Journal",
"JSASS Japan Society of Aeronautical Space Sciences",
"JSAST Japan Society of Aeronautical Space Sciences Transactions",
"JSAPJ Japan Society of Air Pollution Journal",
"JSCMJ Japan Society of Composite Materials Journal",
"JSLEJ Japan Society of Lubrication Engineers Journal",
"JSMSJ Japan Society of Materials Science Journal",
"JSPS. Japan Society of Promotion Science",
"JSMAJ JASMA Japan Society of Microgravity Application Journal",
"JMeOp Jemna Mechanika Optika",
"JenRu Jenaer Rundschau",
"JenRv Jena Review",
"JBAn. Jodrell Bank Annals",
"JBASP Jodrell Bank Ann Ser Pt",
"JBRe. Jodrell Bank Reprints",
"JHATD Johns Hopkins APL Technical Digest",
"JOM.. JOM - Journal of the Minerals, Metals and Materials Society",
"RSNSW Journal and Proceedings of the Royal Society of New South Wales",
"JAco. Journal d'Acoustique",
"JCP.. Journal de Chimie Physique",
"JCPPC Journal de Chimie Physique et de Physico-Chimie Biologique",
"JMec. Journal de Mecanique",
"JMecA Journal de Mecanique Appliquee",
"JMecT Journal de Mecanique Theorique et Appliquee",
"JMTAS Journal de Mecanique Theorique et Appliquee Supplement",
"JPhys Journal de Physique",
"JPhyC Journal de Physique Colloque",
"JPR.. Journal de Physique et le Radium",
"JPhy1 Journal de Physique I",
"JPhy2 Journal de Physique II",
"JPhy3 Journal de Physique III",
"JPhy4 Journal de Physique IV",
"JPhyL Journal de Physique Lettres",
"JPhTA Journal de Physique Theorique et Apliquee",
"JReAt Journal de Recherches Atmospheriques",
"JAF.. Journal des Astronomes Francais",
"JO... Journal des Observateurs",
"JOp.. Journal d'Optique",
"JTP.. Journal for Technology of Plasticity",
"JHA.. Journal for the History of Astronomy",
"JHAS. Journal for the History of Astronomy Supplement",
"JRAM. Journal fur die reine und angewandte Mathematik",
"JNanU Journal Nanjing Univ",
"JNIRE Journal NIRE",
"JAE.. Journal of Acoustic Emission",
"JAMDS Journal of Advanced Mechanical Design, Systems, and Manufacturing",
"JAMES Journal of Advances in Modeling Earth Systems",
"JAerS Journal of Aerosol Science",
"JAerE Journal of Aerospace Engineering",
"JAerP Journal of Aerospace Power",
"JAfES Journal of African Earth Sciences",
"JAER. Journal of Agricultural Engineering Research",
"JAir. Journal of Aircraft",
"JAlg. Journal of Algebra",
"JAlgC Journal of Algebraic Combinatorics",
"JAlgo Journal of Algorithms",
"JAllC Journal of Alloys and Compounds",
"JACS. Journal of American Ceramic Society",
"JAAS. Journal of Analytical Atomic Spectrometry",
"JApCr Journal of Applied Crystallography",
"JApEl Journal of Applied Electrochemistry",
"JAG.. Journal of Applied Geophysics",
"JApMM Journal of Applied Mathematics and Mechanics",
"JAM.. Journal of Applied Mechanics",
"JAMTP Journal of Applied Mechanics and Technical Physics",
"JApMw Journal of Applied Metalworking",
"JApMe Journal of Applied Meteorology",
"JApMC Journal of Applied Meteorology and Climatology",
"JAPE. Journal of Applied Photographic Engineering",
"JAP.. Journal of Applied Physics",
"JAPh. Journal of Applied Physiology",
"JARS. Journal of Applied Remote Sensing",
"JASE. Journal of Applied Science and Engineering Section on Electrical Power and Information Systems",
"JApSc Journal of Applied Sciences",
"JApSp Journal of Applied Spectroscopy",
"JApS. Journal of Applied Statistics",
"JApT. Journal of Approximation Theory",
"JAESc Journal of Asian Earth Sciences",
"JAD.. Journal of Astronomical Data",
"JAHH. Journal of Astronomical History and Heritage",
"JAI.. Journal of Astronomical Instrumentation",
"JAsPh Journal of Astronomy and Physics (Turkey)",
"JASS. Journal of Astronomy and Space Sciences",
"JApA. Journal of Astrophysics and Astronomy",
"JApAS Journal of Astrophysics and Astronomy Supplement",
"JAtOT Journal of Atmospheric and Oceanic Technology",
"JASTP Journal of Atmospheric and Solar-Terrestrial Physics",
"JATP. Journal of Atmospheric and Terrestrial Physics",
"JAtC. Journal of Atmospheric Chemistry",
"JAtS. Journal of Atmospheric Sciences",
"JAMOP Journal of Atomic, Molecular and Optical Physics",
"JAES. Journal of Audio Engineering Society",
"JAuGG Journal of Australian Geology and Geophysics",
"JAuR. Journal of Automated Reasoning",
"JBall Journal of Ballistics",
"JBBM. Journal of Biochemical and Biophysical Methods",
"JBB.. Journal of Bioenergetics and Biomembranes",
"JBC.. Journal of Biological Chemistry",
"JBP.. Journal of Biological Physics",
"JBiom Journal of Biomechanics",
"JBO.. Journal of Biomedical Optics",
"JBNMR Journal of Biomolecular NMR",
"JBBC. Journal of Biophysical and Biochemical Cytology",
"JBiop Journal of Biophysics",
"JBiBi Journal of Biophysique et Biomecanique",
"JBMN. Journal of Biophysique et Medecine Nucleaire",
"JBMR. Journal of Bone and Mineral Research",
"JBR.. Journal of Breath Research",
"JCat. Journal of Catalysis",
"JChEd Journal of Chemical Education",
"JChPh Journal of Chemical Physics",
"JChS. Journal of Chromatographic Science",
"JCh.. Journal of Chromatography",
"JCSC. Journal of Circuits, Systems and Computers",
"JCli. Journal of Climate",
"JCAM. Journal of Climate and Applied Meteorology",
"JClim Journal of Climatology",
"JCS.. Journal of Clinical Microbiology",
"JClP. Journal of Clinical Pharmacology",
"JCS.. Journal of Cluster Science",
"JCScT Journal of College Science Teaching",
"JCIS. Journal of Colloid and Interface Science",
"JCoSc Journal of Colloid Science",
"JCTA. Journal of Combinatorial Theory, Series A",
"JCTB. Journal of Combinatorial Theory, Series B",
"JCom. Journal of Communications",
"CoNet Journal of Communications and Networks",
"JComp Journal of Complexity",
"JCoMa Journal of Composite Materials",
"JCTR. Journal of Composites and Technology Research",
"JCA.. Journal of Computational Acoustics",
"JTCN. Journal of Computational and Theoretical Nanoscience",
"JCoAM Journal of Computational and Applied Mathematics",
"JCoB. Journal of Computational Biology",
"JCoCh Journal of Computational Chemistry",
"JCM.. Journal of Computational Mathematics",
"JCoN. Journal of Computational Neuroscience",
"JCoPh Journal of Computational Physics",
"JCST. Journal of Computational Science and Technology",
"JCMD. Journal of Computer-Aided Materials Design",
"JCAMD Journal of Computer-Aided Molecular Design",
"JCoSS Journal of Computer and System Sciences",
"JCHyd Journal of Contaminant Hydrology",
"JConP Journal of Contemporary Physics (Armenian Academy of Sciences)",
"JCos. Journal of Cosmology",
"JCAP. Journal of Cosmology and Astro-Particle Physics",
"JCrGr Journal of Crystal Growth",
"JDR.. Journal of Dairy Research",
"JDE.. Journal of Differential Equations",
"JDGeo Journal of Differential Geometry",
"JoDI. Journal of Digital Information",
"JDST. Journal of Dispersion Science and Technology",
"JDisT Journal of Display Technology",
"JDSO. Journal of Double Star Observations",
"JDCS. Journal of Dynamical and Control Systems",
"JDDE. Journal of Dynamics and Differential Equations",
"JESS. Journal of Earth System Science",
"JElas Journal of Elasticity",
"JEEEA Journal of Electrical and Electronics Engineering Australia",
"JEE.. Journal of Electrical Engineering",
"JElec Journal of Electroceramics",
"JEAA. Journal of Electromagnetic Analysis and Application",
"JEWA. Journal of Electromagnetic Waves and Applications",
"JECS. Journal of Electronic Circuits and Systems",
"JEI.. Journal of Electronic Imaging",
"JEMat Journal of Electronic Materials",
"JEPub Journal of Electronic Publishing",
"JECTC Journal of Electronics Cooling and Thermal Control",
"JElM. Journal of Electronics Manufacturing",
"JEMT. Journal of Electron Microscopy Technique",
"JESRP Journal of Electron Spectroscopy and Related Phenomena",
"JESEd Journal of Elementary Science Education",
"JEner Journal of Energy",
"JEAS. Journal of Engineering and Applied Sciences",
"JEnMa Journal of Engineering and Mathematics",
"JEngM Journal of Engineering and Mechanics",
"JETh. Journal of Engineering and Thermophysics",
"JEER. Journal of Engineering Education Research",
"JEP.. Journal of Engineering Physics",
"JEPT. Journal of Engineering Physics and Thermophysics",
"JEngS Journal of Engineering Sciences",
"JEEM. Journal of Environmental and Economics Management",
"JECE. Journal of Environmental Conservation Engineering",
"JEnvS Journal of Environmental Sciences",
"JExB. Journal of Experimental Botany",
"JENan Journal of Experimental Nanoscience",
"JFF.. Journal of Fire Flammability",
"JFC.. Journal of Fluid Control",
"JFM.. Journal of Fluid Mechanics",
"JFS.. Journal of Fluids and Structures",
"JFST. Journal of Fluid Science and Technology",
"JFlu. Journal of Fluorescence",
"JFAA. Journal of Fourier Analysis and Applications",
"JFuA. Journal of Functional Analysis",
"JGeod Journal of Geodesy",
"JGeo. Journal of Geodynamics",
"JGS.. Journal of Geographical Systems",
"JGIS. Journal of Geographic Information System",
"JG... Journal of Geology",
"JGG.. Journal of Geomagnetism and Geoelectricity",
"JGGS. Journal of Geomagnetism and Geoelectricity Supplement",
"JGP.. Journal of Geometry and Physics",
"JGR.. Journal of Geophysical Research",
"JGRD. Journal of Geophysical Research (Atmospheres)",
"JGRG. Journal of Geophysical Research (Biogeosciences)",
"JGRF. Journal of Geophysical Research (Earth Surface)",
"JGRC. Journal of Geophysical Research (Oceans)",
"JGRE. Journal of Geophysical Research (Planets)",
"JGRB. Journal of Geophysical Research (Solid Earth)",
"JGRA. Journal of Geophysical Research (Space Physics)",
"JGRS. Journal of Geophysical Research Supplement",
"JGE.. Journal of Geophysics and Engineering",
"JGZG. Journal of Geophysics Zeitschrift Geophysik",
"JGeEd Journal of Geoscience Education",
"JGlac Journal of Glaciology",
"JGO.. Journal of Global Optimization",
"JGrPh Journal of Gravitational Physics",
"JGHyd Journal of Groundwater Hydrology",
"JGuC. Journal of Guidance Control",
"JGCD. Journal of Guidance Control Dynamics",
"JHeu. Journal of Heuristics",
"JHENP Journal of High Energy and Nuclear Physics",
"JHEP. Journal of High Energy Physics",
"JHEPC Journal of High Energy Physics Conference Proceedings",
"JHSN. Journal of High Speed Networks",
"JHTS. Journal of High Temperature Society",
"JHyd. Journal of Hydrology",
"JHyMe Journal of Hydrometeorology",
"JHyn. Journal of Hydronautics",
"JIST. Journal of Imaging Science and Technology",
"JIPM. Journal of Information Processing and Management",
"JInfo Journal of Informetrics",
"JIMW. Journal of Infrared and Millimeter Waves",
"JInst Journal of Instrumentation",
"JIntS Journal of Integer Sequences",
"JIEq. Journal of Integral Equations",
"JIRS. Journal of Intelligent and Robotic Systems",
"JIMSS Journal of Intelligent Material Systems and Structures",
"JIEx. Journal of Ion Exchange",
"JJAEE Journal of Japan Association for Earthquake Engineering",
"JJAHS Journal of Japanese Association of Hydrological Sciences",
"JJSEE Journal of Japanese Society for Engineering Education",
"JSCSE Journal of Japan Society of Civil Engineers, Ser. A1 (Structural Engineering &amp",
"JSCAM Journal of Japan Society of Civil Engineers, Ser. A2 (Applied Mechanics (AM))",
"JSCHE Journal of Japan Society of Civil Engineers, Ser. B1 (Hydraulic Engineering)",
"JSCGE Journal of Japan Society of Civil Engineers, Ser. C (Geosphere Engineering)",
"JSCAI Journal of Japan Society of Civil Engineers, Ser. D1 (Architecture of Infrastructure and Environment)",
"JSCHS Journal of Japan Society of Civil Engineers, Ser. D2 (Historical Studies in Civil Engineering)",
"JSCIP Journal of Japan Society of Civil Engineers, Ser. D3 (Infrastructure Planning and Management)",
"JSCPE Journal of Japan Society of Civil Engineers, Ser. E1 (Pavement Engineering)",
"JSCMC Journal of Japan Society of Civil Engineers, Ser. E2 (Materials and Concrete Structures)",
"JSCTE Journal of Japan Society of Civil Engineers, Ser. F1 (Tunnel Engineering)",
"JSCUS Journal of Japan Society of Civil Engineers, Ser. F2 (Underground Space Research)",
"JSCCE Journal of Japan Society of Civil Engineers, Ser. F3 (Civil Engineering Informatics)",
"JSCCM Journal of Japan Society of Civil Engineers, Ser. F4 (Construction and Management)",
"JSCPP Journal of Japan Society of Civil Engineers, Ser. F5 (Professional Practices in Civil Engineering)",
"JSCSP Journal of Japan Society of Civil Engineers, Ser. F6 (Safety Problem)",
"JSCER Journal of Japan Society of Civil Engineers, Ser. G (Environmental Research)",
"JKTR. Journal of Knot Theory and its Ramifications",
"JKAS. Journal of Korean Astronomical Society",
"JKASS Journal of Korean Astronomical Society Supplement",
"JKPS. Journal of Korean Physical Society",
"JLCMe Journal of Laboratory and Clinical Medicine",
"JLasA Journal of Laser Applications",
"JLCM. Journal of Less Common Metals",
"JLVEn Journal of Light &amp",
"JLwT. Journal of Lightwave Technology",
"JLTP. Journal of Low Temperature Physics",
"JLum. Journal of Luminescence",
"JMSB. Journal of Macromolecular Science, Part B: Physics",
"JMSC. Journal of Macromolecular Science, Part C: Reviews in Macromolecular Chemistry and Physics",
"JMagR Journal of Magnetic Resonance",
"JMMM. Journal of Magnetism and Magnetic Materials",
"JMR.. Journal of Marine Research",
"JMSA. Journal of Marine Science and Application",
"JMS.. Journal of Marine Systems",
"JMarA Journal of Maritime Archaeology",
"JMES. Journal of Materials and Energy Systems",
"JMCh. Journal of Materials Chemistry",
"JMEP. Journal of Materials Engineering and Performance",
"JMPMS Journal of Materials Processing and Manufacturing Science",
"JMatR Journal of Materials Research",
"JMatS Journal of Materials Science",
"JMSME Journal of Materials Science and Materials Electronics",
"JMSL. Journal of Materials Science Letters",
"JMSMM Journal of Materials Science: Materials in Medicine",
"JMSP. Journal of Materials Synthesis and Processing",
"JMAA. Journal of Mathematical Analysis and Applications",
"JMCS. Journal of Mathematical and Computational Science",
"JMPS. Journal of Mathematical and Physical Sciences",
"JMaCh Journal of Mathematical Chemistry",
"JMFM. Journal of Mathematical Fluid Mechanics",
"JMIV. Journal of Mathematical Imaging and Vision",
"JMP.. Journal of Mathematical Physics",
"JMPsy Journal of Mathematical Psychology",
"JMaSc Journal of Mathematical Sciences",
"JMSo. Journal of Mathematical Sociology",
"JMaMe Journal of Mathematics and Mechanics",
"JMaPh Journal of Mathematics and Physics",
"JMecE Journal of Mechanical and Engineering Science",
"JMBM. Journal of Mechanical Behavior and Materials",
"JMSTL Journal of Mechanical Systems for Transportation and Logistics",
"JMPSo Journal of Mechanics Physics of Solids",
"JMNB. Journal of Medecine Nucleaire et Biophysique",
"JMet. Journal of Metals",
"JMemS Journal of Microelectromechanical Systems",
"JMiMi Journal of Micromechanics and Microengineering",
"JMic. Journal of Microscopy",
"JMPeS Journal of Mineralogical and Petrological Sciences",
"JMOp. Journal of Modern Optics",
"JMPh. Journal of Modern Physics",
"JMBio Journal of Molecular Biology",
"JMoEl Journal of Molecular Electronics",
"JMolE Journal of Molecular Evolution",
"JMoSp Journal of Molecular Spectroscopy",
"JMoSt Journal of Molecular Structure",
"JMA.. Journal of Multivariate Analysis",
"JNUNS Journal of Nanjing University (Natural Sciences)",
"JNR.. Journal of Nanoparticle Research",
"JNano Journal of Nanophotonics",
"JNav. Journal of Navigation",
"JNIS. Journal of Near Infrared Spectroscopy",
"JNEng Journal of Neural Engineering",
"JNeur Journal of Neurochemistry",
"JNO.. Journal of Neuro-Oncology",
"JNCS. Journal of Non Crystalline Solids",
"JNE.. Journal of Nondestructive Evaluation",
"JNET. Journal of Non Equilibrium Thermodynamics",
"JNMP. Journal of Nonlinear Mathematical Physics",
"JNLM. Journal of Non Linear Mechanics",
"JNOPM Journal of Nonlinear Optical Physics and Materials",
"JNS.. Journal of NonLinear Science",
"JNuE. Journal of Nuclear Energy",
"JNuM. Journal of Nuclear Materials",
"JNT.. Journal of Number Theory",
"JOUC. Journal of Ocean University of China",
"JOC.. Journal of Optical Communications",
"JON.. Journal of Optical Networking",
"JOptT Journal of Optical Technology",
"JOpt. Journal of Optics",
"JOptA Journal of Optics A: Pure and Applied Optics",
"JOptB Journal of Optics B: Quantum and Semiclassical Optics",
"JOTA. Journal of Optimization Theory Applications",
"JOMS. Journal of Oral and Maxillofacial Surgery",
"JOR.. Journal of Oral Rehabilitation",
"JPal. Journal of Paleontology",
"JPDC. Journal of Parallel and Distributed Computing",
"JPet. Journal of Petrology",
"JPhPh Journal of Pharmacy and Pharmacology",
"JPCRD Journal of Physical and Chemical Reference Data",
"JPCC. Journal of Physical and Colloid Chemistry",
"JPhCh Journal of Physical Chemistry",
"JPCA. Journal of Physical Chemistry A",
"JPCB. Journal of Physical Chemistry B",
"JPO.. Journal of Physical Oceanography",
"JPhSt Journal of Physical Studies",
"JPhA. Journal of Physics A Mathematical General",
"JPCS. Journal of Physics and Chemistry of Solids",
"JPhB. Journal of Physics B Atomic Molecular Physics",
"JPCM. Journal of Physics Condensed Matter",
"JPhCS Journal of Physics Conference Series",
"JPhC. Journal of Physics C Solid State Physics",
"JPhD. Journal of Physics D Applied Physics",
"JPhE. Journal of Physics E Scientific Instruments",
"JPhF. Journal of Physics F Metal Physics",
"JPhG. Journal of Physics G Nuclear Physics",
"JPhGS Journal of Physics G Nuclear Physics Supplement",
"JPE.. Journal of Physics of the Earth",
"JPTEO Journal of Physics Teacher Education Online",
"JPhsg Journal of Physiology",
"JPFR. Journal of Plasma and Fusion Research",
"JPlPh Journal of Plasma Physics",
"JPoSc Journal of Polymer Science",
"JPoSA Journal of Polymer Science A Polymer Chemistry",
"JPoSB Journal of Polymer Science B Polymer Physics",
"JPoSL Journal of Polymer Science: Polymer Letters Edition",
"JPMat Journal of Porous Materials",
"JPES. Journal of Power and Energy Systems",
"JPS.. Journal of Power Sources",
"JPAS. Journal of Practical Applications in Space",
"JPP.. Journal of Propulsion and Power",
"JPT.. Journal of Propulsion Technology",
"JPrCh Journal of Protein Chemistry",
"JPApS Journal of Pure Applied Sciences",
"JQT.. Journal of Quality Technology",
"JQSRT Journal of Quantitative Spectroscopy and Radiative Transfer",
"JQS.. Journal of Quaternary Science",
"JRNC. Journal of Radioanalytical and Nuclear Chemistry",
"JRAC. Journal of Radioanalytical Chemistry",
"JRP.. Journal of Radiological Protection",
"JRSp. Journal of Raman Spectroscopy",
"JRPC. Journal of Reinforced Plastics and Composites",
"JRes. Journal of Research",
"JRPhy Journal of Research in Physics",
"JRScT Journal of Research in Science Teaching",
"JRIST Journal of Research Institute of Science and Technology, College of Science and Technology, Nihon University",
"JRNBS Journal of Research of the National Bureau of Standards",
"JRNBA Journal of Research of the National Bureau of Standards A Physica and Chemsitry",
"JRNBB Journal of Research of the National Bureau of Standards B Mathematical Sciences",
"JRTEd Journal of Research on Technology in Education",
"JResB Journal of Research Section B Mathematical Sciences B",
"JRheo Journal of Rheology",
"JRoS. Journal of Robotic Systems",
"JRLR. Journal of Russian Laser Research",
"JSEdT Journal of Science Education and Technology",
"JSTEd Journal of Science Teacher Education",
"JSCom Journal of Scientific Computing",
"JScI. Journal of Scientific Instruments",
"JSIPI Journal of Scientific Instruments and of Physics in Industry",
"JSR.. Journal of Sea Research",
"JSedR Journal of Sedimentary Research",
"JSeis Journal of Seismology",
"JSemi Journal of Semiconductors",
"JSGeo Journal of Series Geophysics",
"JShR. Journal of Ship Research",
"JSGST Journal of Sol-Gel Science and Technology",
"JSMME Journal of Solid Mechanics and Materials Engineering",
"JSSCh Journal of Solid State Chemistry France",
"JSCh. Journal of Solution Chemistry",
"JSV.. Journal of Sound Vibration",
"JSAES Journal of South American Earth Sciences",
"JSLR. Journal of Soviet Laser Research",
"JSAR. Journal of Space Astronomy Research",
"JSpRo Journal of Spacecraft and Rockets",
"JSpT. Journal of Spacecraft Technology",
"JSpEn Journal of Space Engineering",
"JSWSC Journal of Space Weather and Space Climate",
"JSCS. Journal of Statistical Computation and Simulation",
"JSMTE Journal of Statistical Mechanics: Theory and Experiment",
"JSP.. Journal of Statistical Physics",
"JStA. Journal of Strain Analysis and Engineering Design",
"JSG.. Journal of Structural Geology",
"JSM.. Journal of Structural Mechanics",
"JSup. Journal of Superconductivity",
"JSymC Journal of Symbolic Computation",
"JSDD. Journal of System Design and Dynamics",
"JTePh Journal of Technical Physics",
"JTech Journal of Technology",
"JTeEv Journal of Testing Evaluation",
"JASJa Journal of the Acoustical Society of Japan",
"JAVSO Journal of the American Association of Variable Star Observers (JAAVSO)",
"JAChS Journal of the American Chemical Society",
"JAMS. Journal of the American Mathematical Society",
"JASIS Journal of the American Society for Information Science and Technology",
"JASCE Journal of the American Society of Civil Engineers",
"JAWRA Journal of the American Water Resources Association",
"JALPO Journal of the Association of Lunar and Planetary Observers, the Strolling Astronomer",
"JAnSc Journal of the Astronautical Sciences",
"JASEg Journal of the Astronomical Society of Egypt",
"JASSA Journal of the Astronomical Society of Southern Africa",
"JASV. Journal of the Astronomical Society of Victoria Melbourne",
"JASWA Journal of the Astronomical Society of Western Australia",
"JBAA. Journal of the British Astronomical Association",
"JBAS. Journal of the British Astronomical Society",
"JBIS. Journal of the British Interplanetary Society",
"JCSS. Journal of the Chinese Silicate Society",
"JElS. Journal of the Electrochemical Society",
"FrInJ Journal of The Franklin Institute",
"JGSJ. Journal of the Geodetic Society of Japan",
"JIISB Journal of the Indian Institute of Science Section B Physical and Chemical Series",
"JIEEJ Journal of The Institute of Electrical Engineers of Japan",
"JIMIA Journal of the Institute of Mathematics and Its Applications",
"JIPNT Journal of the Institute of Positioning, Navigation and Timing of Japan",
"JIETE Journal of the Institution of Electronics and Telecommunication Engineers",
"JJSMS Journal of the Japan Society for Marine Surveys and Technology",
"JLMS. Journal of the London Mathematical Society",
"JORS. Journal of the Operational Research Society",
"JOSA. Journal of the Optical Society of America (1917-1983)",
"JOSAA Journal of the Optical Society of America A",
"JOSAB Journal of the Optical Society of America B Optical Physics",
"JTAM. Journal of Theoretical and Applied Mechanics",
"JTBio Journal of Theoretical Biology",
"JPSJ. Journal of the Physical Society of Japan",
"JPSJS Journal of the Physical Society of Japan Supplement",
"JTAC. Journal of Thermal Analysis and Calorimetry",
"JThSc Journal of Thermal Science",
"JJTST Journal of Thermal Science and Technology",
"JTST. Journal of Thermal Spray Technology",
"JThSt Journal of Thermal Stresses",
"JTh.. Journal of Thermodynamics",
"JTHT. Journal of Thermophysics and Heat Transfer",
"JThCM Journal of Thermoplastic Composite Materials",
"JRASA Journal of the Royal Aeronautical Society of London",
"JRASC Journal of the Royal Astronomical Society of Canada",
"JRASN Journal of the Royal Astronomical Society of New Zealand",
"JRCSE Journal of the Royal College of Surgeons of Edinburgh",
"JRSSD Journal of the Royal Statistical Society: Series D (The Statistician)",
"JSRP. Journal of the Society for Radiological Protection",
"JSPST Journal of The Society of Photographic Science and Technology of Japan",
"JSARA Journal of the Southeastern Association for Research in Astronomy",
"JSD.. Journal of the Structural Division, American Society of Civil Engineers",
"JVSJ  Journal of the Vacuum Society of Japan",
"JWasA Journal of the Washington Academy of Sciences",
"JTF.. Journal of Time and Frequency",
"JTurb Journal of Turbulence",
"JVST. Journal of Vacuum Science Technology",
"JVSTA Journal of Vacuum Science Technology A: Vacuum Surfaces and Films",
"JVSTB Journal of Vacuum Science Technology B: Microelectronics and Nanometer Structures",
"JVC.. Journal of Vibration and Control",
"JVE.. Journal of Vibration Engineering",
"JVCIR Journal of Visual Communication and Image Representation",
"JVGR. Journal of Volcanology and Geothermal Research",
"JWMSE Journal of Women and Minorities in Science and Engineering",
"JXST. Journal of X-Ray Science and Technology",
"RpScT JPRS Report Science Technology USSR Space",
"JSMB. JSME Bulletin",
"JSMEJ JSME International Journal",
"JSMEA JSME International Journal Series A",
"JSMEB JSME International Journal Series B",
"JSMEC JSME International Journal Series C",
"JSMET JSME Transactions",
"KKR.. Kagaku Kogaku Ronbunshu",
"MmKMO Kakioka Magnetic Observatory Memoirs",
"KEIJ. Kansei Engineering International Journal",
"GroR. Kapteyn Astronomical Laboratory Groningen Reports",
"KIzKU Kazan Izdatel Kazanskogo Universiteta",
"MeeRe Kenneth Mees Observatory Reprints",
"KernR Kernforschungsanlage Rept Res Results Solid State Nucl Phys",
"KexT. Kexue Tongbao",
"Khago Khagol",
"KharI Kharkov Izdanie IRE AN USSR",
"KTTM. Khimiia i Tekhnologiia Topliv i Masel",
"KhPl. Khimiia Plazmy",
"KVnT. Kibernetika i Vychislitel naia Tekhnika",
"KiInF Kiev Institut Fiziki AN USSR",
"KiInM Kiev Institut Matematiki AN USSR",
"KIPME Kiev Institut Problem Modelirovaniia Energetike AN USSR",
"KIzIM Kiev Izdanie Instituta Matematiki AN USSR",
"KiIND Kiev Izdatel Naukova Dumka",
"KiIzT Kiev Izdatel Tekhnika",
"KIzVS Kiev Izdatel Vishcha Shkola",
"KiePr Kievskij Ordena Lenina Gosudarstvennyj Universitet Shevchenko Astronomicheskaya Observatoriya - Preprint",
"KPCB. Kinematics and Physics of Celestial Bodies",
"KPCBS Kinematics and Physics of Celestial Bodies, Supplement",
"KFNT. Kinematika i Fizika Nebesnykh Tel",
"KFNTS Kinematika i Fizika Nebesnykh Tel Supplement",
"KiCat Kinetics and Catalysis",
"KIzS. Kishinev Izdatel Shtiintsa",
"KPNON Kitt Peak National Observatory Newsletter",
"KVeBB Kleine Veroeffentlichungen der Universitaetssternwarte zu Berlin Babelsberg",
"KlBer Kleinheubacher Berichte",
"KodOB Kodaikanal Observatory Bulletins",
"KodRe Kodaikanal Observatory Reprints",
"KomTs Kometnyj Tsirkulyar",
"KomMe Komety i Meteory",
"KNAB. Koninklijke Nederlandse Akademie van Weteschappen Proceedings Series B Physical Sciences",
"KIMMJ Korean Institute of Metals and Materials Journal",
"KNT.. Kosmicheskaia Nauka i Tekhnika",
"KosIs Kosmicheskie Issledovaniia",
"KosIU Kosmicheskie Issledovaniia Ukraine",
"KosLu Kosmicheskie Luchi",
"KosNT Kosmichna Nauka i Tekhnologiya",
"Kozmo Kozmos",
"KT... K-Theory",
"KSVH. Kungl. Svenska Vetenskapsakademiens Handlingar",
"KvanE Kvantovaia Elektronika Moscow",
"Kyb.. Kybernetes",
"KyoMe Kyoto University Faculty Engineering Memoirs",
"KyITB Kyushu Institute Technology Bulletin",
"KUFEM Kyushu University Faculty Engineering Memoirs",
"KyUAM Kyushu University Research Institute Applied Mechanics Reports",
"KyUSR Kyushu University Research Institute Industrial Science Reports",
"KyUTR Kyushu University Technology Reports",
"LChip Lab on a Chip",
"AerAs L'Aeronautique et L'Astronautique",
"AerMS L'Aerotecnica Missili e Spazio",
"LHBl. La Houille Blanche",
"Meteo La Meteorologie",
"LDD.. Land Degradation &amp",
"LanB. Landolt Börnstein",
"Langm Langmuir",
"LaJ.. Lapidary Journal",
"Rech. La Recherche",
"ReAer La Recherche Aerospatiale",
"ReAeB La Recherche Aerospatiale Bimonthly Bulletin ESA",
"ReSp. La Recherche Spatiale",
"LPB.. Laser and Particle Beams",
"LaEO. Laser Elektro Optik",
"LaFoc Laser Focus",
"LasJ. Laser Journal",
"LaPhy Laser Physics",
"LaPhL Laser Physics Letters",
"LaPhR Laser Physics Review",
"Astrf L'Astrofilo Bolletino Trimestral del Gruppo Astrofili Villaggio Sereno Brescia",
"LAstr L'Astronomie",
"LTerm La Termotecnica",
"LatJP Latvian Journal of Physics and Technical Sciences",
"LatME Latviiskii Matematicheskii Ezhegodnik",
"LawOB Laws Observatory Bulletin, University of Missouri",
"LBLRR LBL Research Review",
"ASPL. Leaflet of the Astronomical Society of the Pacific",
"ASPLS Leaflet of the Astronomical Society of the Pacific (Supplement)",
"LePub Learned Publishing",
"LERec L'Echo des Recherches",
"Ciel. Le Ciel",
"LNEA. Lecture Notes and Essays in Astrophysics",
"LNSP. Lecture Notes and Supplements in Physics",
"LNCS. Lecture Notes in Computer Science",
"LNES. Lecture Notes in Earth Sciences, Berlin Springer Verlag",
"LNEn. Lecture Notes in Engineering, Berlin Springer Verlag",
"LNM.. Lecture Notes in Mathematics, Berlin Springer Verlag",
"LNP.. Lecture Notes in Physics, Berlin Springer Verlag",
"LNPAM Lecture Notes in Pure and Applied Mathematics",
"LeBAN Leningrad Biblioteka Akademii Nauk SSSR",
"LeEne Leningrad Energoizdat",
"LeGid Leningrad Gidrometeoizdat",
"PrAtO Leningrad Gidrometeoizdat Sovremennye Problemy Atmosfernoi Optiki",
"LeIzE Leningrad Izdatel Energiia",
"LeIzG Leningrad Izdatel Gidrometeoizdat",
"LeIzK Leningrad Izdatel Khimiia",
"LeIzU Leningrad Izdatel Leningradskogo Universiteta",
"LeIzM Leningrad Izdatel Mashinostroenie",
"LeIzN Leningrad Izdatel Nauka",
"LIzNe Leningrad Izdatel Nedra",
"IzLen Leningrad, Izdatel'stvo Nauka",
"LeIzS Leningrad Izdatel Sudostroenie",
"LeLen Leningrad Lenizdat",
"LGUPM Leningradskii Gosudarstvennyi Universitet Problemy Matematicheskoi Fiziki",
"VeLen Leningradskii Universitet Vestnik Matematika Mekhanika Astronomiia",
"LeRad Le Radium",
"Leo.. Leonardo",
"LFTR. LEST Foundation, Technical Report",
"LHMT. Letters Heat Mass Transfer",
"LAES. Letters in Applied and Engineering Sciences",
"LMaPh Letters in Mathematical Physics",
"LicOB Lick Observatory Bulletin",
"LFR.. Lietuvos Fizikos Rinkinys",
"LDA.. Lifetime Data Analysis",
"LLabJ Lincoln Laboratory Journal",
"LiCr. Liquid Crystals",
"Litho Lithos",
"LitJP Lithuanian Journal of Physics and Technical Sciences",
"LRR.. Living Reviews in Relativity",
"LRSP. Living Reviews in Solar Physics",
"LockH Lockheed Horizons",
"LOEle L'Onde Electrique",
"LowOB Lowell Observatory Bulletin",
"LTP.. Low Temperature Physics",
"LPIBu LPI Bulletin",
"LPICo LPI Contributions",
"LubEn Lubrication Engineering",
"LR... Luft und Raumfahrt",
"LuRaQ Luft und Raumfahrt Quarter",
"LPSC. Lunar and Planetary Science Conference Proceedings",
"LCEC. Luxembourg Commission European Communities",
"LIVS. Lvov Izdatel Vishcha Shkola",
"LvoTs L'vovskij Ordena Lenina Gosudarstvennyj Universitet Tsirkulyar",
"MaDes Machine Design",
"MLear Machine Learning",
"MmCP. Macromolecular Chemistry and Physics",
"MaMol Macromolecules",
"MadOO Madras Observatory Astronomical Observations",
"MadOb Madras Observatory Observations",
"MagFE Magnetic Fusion Energy",
"MRMed Magnetic Resonance in Medicine",
"MRMPB Magnetic Resonance Materials in Physics Biology and Medicine",
"MRRev Magnetic Resonance Review",
"MHD.. Magnetohydrodynamics",
"MagGi Magnitnaia Gidrodinamika",
"MagIs Magnitosfernye Issledovaniia",
"MTACI Magyar Tudomanyos Akademia Csillagvizsgalo Intezetenek koezlemenyei",
"MAWMN Mainz Akademie Wissenschaften Mathematisch Naturwissenschaftliche Klasse",
"Lapa. Majalah LAPAN",
"MWGBI Mannheim West Germany Bibliographisches Institut AG",
"MaTeJ ManTech Journal",
"MGeo. Manuscr. Geod.",
"ManGe Manuscripta Geodaetica",
"MarRv Marconi Review",
"MarGe Marine Geodesy",
"MarGR Marine Geophysical Research",
"MarPG Marine Petroleum Geology",
"Mars. Mars",
"Mashi Mashinostroenie",
"MsT.. Masters Thesis",
"MaFiz Matematicheskaia Fizika",
"MFiNM Matematicheskaia Fizika i Nelineinaia Mekhanika",
"MatIs Matematicheskie Issledovaniia",
"MMFMP Matematicheskie Metody i Fiziko Mekhanicheskie Polia",
"MISTr Matematicheskii Institut imeni Steklova Trudy",
"MMTET Matematicheskoe Modelirovanie i Teoriia Elektricheskikh Tsepei",
"MatVe Matematichki Vesnik",
"Mater Materialpruefung",
"Mate. Materials",
"MMP.. Materials and Manufacturing Processes",
"MCP.. Materials Chemistry and Physics",
"MaHT. Materials at High Temperatures",
"MatEv Materials Evaluation",
"MatL. Materials Letters",
"MaRBu Materials Research Bulletin",
"MRSSP Materials Research Society Symposia Proceedings",
"MSEng Materials Science and Engineering",
"MSEnA Materials Science and Engineering A",
"MSEnB Materials Science and Engineering B",
"MSEnC Materials Science and Engineering C",
"MSEnR Materials Science and Engineering R Reports",
"MSTec Materials Science and Technology",
"MSF.. Materials Science Forum",
"MatSP Materials Science Poland",
"MatST Materials Science Technology",
"MatTr Materials Transactions JIM",
"MatTe Materiaux et Techniques",
"MComM Mathematical and Computer Modelling",
"MEI.. Mathematical Engineering Industry",
"MaFi. Mathematical Finance",
"MatG. Mathematical Geology",
"MMAS. Mathematical Methods in the Applied Sciences",
"MatM. Mathematical Modelling",
"MMNA. Mathematical Modelling Numerical Analysis",
"M3AS. Mathematical Models and Methods in Applied Sciences",
"MPAG. Mathematical Physics, Analysis and Geometry",
"MPAM. Mathematical Physics and Applied Mathematics",
"MaPEJ Mathematical Physics Electronic Journal",
"MaPhS Mathematical Physics Studies",
"MaPr. Mathematical Proceedings",
"MPCPS Mathematical Proceedings of the Cambridge Philosophical Society",
"MatPr Mathematical Programming",
"MatRv Mathematical Reviews",
"MMS.. Mathematics and Mechanics of Solids",
"MEdRJ Mathematics Education Research Journal",
"MaCom Mathematics of Computation",
"Mat.. Mathematika",
"MatAn Mathematische Annalen",
"MatNa Mathematische Nachrichten",
"MatZe Mathematische Zeitschrift",
"MitAe Max Planck Institut Aeronomie Mitteilungen",
"MPARp Max Planck Institut fur Astrophysik Report",
"Meas. Measurements",
"MeScT Measurement Science and Technology",
"MeScR Measurement Science Review",
"Mecc. Meccanica",
"MecEn Mechanical Engineering",
"MSSP. Mechanical Systems and Signal Processing",
"MPDS. Mechanics and Physics of Discrete Systems",
"MCMS. Mechanics of Composite Materials",
"MSM.. Mechanics of Structures and Machines",
"MTDM. Mechanics of Time-Dependent Materials",
"MeReC Mechanics Research Communications",
"MeTeS Mechanika Teoretyczna i Stosowana",
"MeMaT Mechanism and Machine Theory",
"MeUpp Meddelanden fran Astronomiska Observatorium Uppsala",
"MeLu1 Meddelanden fran Lunds Astronomiska Observatorium Serie I",
"MeLu2 Meddelanden fran Lunds Astronomiska Observatorium Serie II",
"MeAar Meddelser fra Ole Romer Observatoriet Aarhus",
"MeGen Mededelingen Universiteit te Gent Sterrenkundig Instituut",
"MeLeu Mededelingen van het Astronomisch Instituut van de Katholieke Universiteit Leuven",
"MedPh Medical Physics",
"MekGS Mekhanika Giroskopicheskikh Sistem",
"MekKM Mekhanika Kompozitnykh Materialov",
"MekP. Mekhanika Polimerov",
"MekTT Mekhanika Tverdogo Tela",
"MelAR Melbourne Observatory Annual Report",
"MelOO Melbourne Observatory Observations",
"MmEbr Memoires de l'Observatoire de l'Ebre",
"MmARB Memoires of the Academie Royale de Belgique",
"MmMtS Memoires of the Mount Stromlo Observervatory",
"MSRSL Memoires of the Societe Royale des Sciences de Liege",
"MeSRM Memoires Scientifiques de la Revue de Metallurgie",
"MmKyo Memoirs Faculty of Sciences University of Kyoto",
"MmASI Memoirs of the Astronomical Society of India",
"MmBAA Memoirs of the British Astronomical Association",
"MmRAS Memoirs of the Royal Astronomical Society",
"MmSAI Memorie della Societa Astronomica Italiana",
"MSAIS Memorie della Societa Astronomica Italiana Supplementi",
"MmSSI Memorie della Societa Degli Spettroscopisti Italiani",
"MmSS. Memorie della Societa Degli Spettroscopisti Italiani, serie 2",
"MmSGI Memorie della Societa Geologica Italiana",
"MmNap Memorie del R. Osservatorio di Capodimonte in Napoli",
"MeCom Mendeleev Communications",
"Mercu Mercury",
"MeAut Meres es Automatika",
"MeRAu Mesures Regulation Automatisme",
"Metal Metallofizika",
"MTObM Metallovedenie i Termicheskaia Obrabotka Metallov",
"MMTA. Metallurgical and Materials Transactions A",
"MMTB. Metallurgical and Materials Transactions B",
"MTA.. Metallurgical Transactions A",
"MTB.. Metallurgical Transactions B",
"MTPMM Metallurgical Transactions Physical Metallurgy Materials Science",
"MetaM Metamaterials",
"MTRMA Meteor Forschungsergebnisse Reihe B Meteorologie und Aeronomie",
"Metit Meteorites",
"Met.. Meteorite - The International Quarterly of Meteorites and Meteorite Science",
"Metic Meteoritics",
"Metik Meteoritika",
"MetRR Meteornoe Rasprostranenie Radiovoln",
"MetIs Meteornye Issledovaniia",
"MeApp Meteorological Applications",
"MetMa Meteorological Magazine",
"MetMo Meteorological Monographs",
"MSCTN Meteorological Satellite Center Technical Note",
"MeSJJ Meteorological Society of Japan Journal",
"MetZp Meteorologicke Zpravy",
"MeGid Meteorologiia i Gidrologiia",
"MetRu Meteorologische Rundschau",
"MetZe Meteorologische Zeitschrift",
"MAP.. Meteorology and Atmospheric Physics",
"MetAP Meteorology Atmospheric Physics",
"MetHy Meteorology Hydrology JPRS",
"MeRR. Meteor. rasprostr. radiovoln, Kazan",
"MVMP. Methoden und Verfahren der Mathematischen Physik",
"MCME. Methods: A Companion to Methods in Enzymology",
"MApAn Methods and Applications of Analysis",
"MComP Methods in Computational Physics",
"MGG.. Methods in Geochemistry and Geophysics",
"MSB.. Methods in Subnuclear Physics",
"MExP. Methods of Experimental Physics",
"MetVy Metody Vychislenii",
"Metro Metrologia",
"MicEc Microbial Ecology",
"MPFD. Microdevices: Physics and Fabrication Technologies",
"MiEng Microelectronic Engineering",
"MiI.. Microelectronics International",
"MiRe. Microelectronics Reliability",
"MicgQ Microgravity Quarterly",
"MiST. Microgravity Science and Technology",
"MTEng Microscale Thermophysical Engineering",
"MiMic Microscopy and Microanalysis",
"MiOTL Microwave and Optical Technology Letters",
"MiJo. Microwave Journal",
"MicWa Microwaves",
"AcMik Mikrochimica Acta",
"Mikro Mikroelektronika",
"MikSb Mikroelektronika Sbornik",
"MAIMT Milan Associazione Italiana di Meccanica Teorica ed Applicata",
"MSMFR Milano Seminario Matematico e Fisico Rendiconti",
"MiElC Military Electronics Countermeasures",
"MiLa. Mind and Language",
"MinDe Mineralium Deposita",
"Miner Mineralogia",
"MinM. Mineralogical Magazine",
"MinPe Mineralogy and Petrology",
"MinPh Mineral Physics",
"MWE.. Mine Water and The Environment",
"MPBu. Minor Planet Bulletin",
"MPC.. Minor Planet Circulars",
"MPEC. Minor Planet Electronic Circulars",
"IzMin Minsk Izdatel BGU",
"MiINT Minsk Izdatel Nauka i Tekhnika",
"MisSp Missiles Spacecraft",
"MAPSE Mission Analysis Program Solar Electric Propulsion MAPSEP",
"MHITR Mitsubishi Heavy Industries Technical Review",
"MitAG Mitteilungen der Astronomischen Gesellschaft Hamburg",
"MiBon Mitteilungen der Astronomischen Institute der Universitaet Bonn",
"MiBas Mitteilungen der Astronomisch-Meteorologischen Anstalt der Universitaet Basel Astronomische Reihe",
"MiHar Mitteilungen der Bruno-H.-Buergel-Sternwarte Hartha DDR",
"MiHam Mitteilungen der Hamburger Sternwarte in Bergedorf",
"MiKon Mitteilungen der Konkoly Sternwarte Budapest-Szabadsaghegy",
"MiPul Mitteilungen der Nikolai-Hauptsternwarte zu Pulkowo",
"MiBud Mitteilungen der Sternwarte der Ungarischen Akademie der Wissenschaften Budapest",
"MiInn Mitteilungen der Sternwarte Innsbruck",
"MiMun Mitteilungen der Sternwarte Munchen",
"MiSon Mitteilungen der Sternwarte zu Sonneberg",
"MiGra Mitteilungen der Universitaets-Sternwarte Graz",
"MiWie Mitteilungen der Universitaets-Sternwarte Wien",
"MiJen Mitteilungen der Universitaets-Sternwarte zu Jena",
"MiTue Mitteilungen des Astronomischen Instituts der Universitaet Tuebingen",
"MiMue Mitteilungen des Astronomischen Instituts des Universitaet Munster",
"MiPot Mitteilungen des Astrophysikalischen Observatoriums Potsdam",
"MiGIR Mitteilungen Geod. Institut Rheinischen Friedrich-Wilhelms-Universitaets. Bonn",
"MSMSE Modelling Simul. Mater. Sci. Eng.",
"MAG.. Modern Approaches in Geophysics",
"ModGe Modern Geology",
"ModIn Modern Instrumentation",
"MIMPE Modern Instrumentation and Measurements in Physics and Engineering",
"ModPh Modern Physics",
"MPLA. Modern Physics Letters A",
"MPLB. Modern Physics Letters B",
"MJPS. Moldavian Journal of the Physical Sciences",
"MBB.. Molecular Biology and Biophysics",
"MBBB. Molecular Biology Biochemistry and Biophysics",
"MCLC. Molecular Crystals and Liquid Crystals",
"MGM.. Molecular Genetics and Metabolism",
"MolPh Molecular Physics",
"MoPhR Molecular Physics Reports",
"MoSim Molecular Simulation",
"MCBEH Monatliche Correspondenz zur Beforderung der Erd- und Himmels-kunde",
"WisBB Monatsber. Deutsch. Akad Wissenschaftliche Berlin",
"MEEP. Monographs on Environment, Earth and Planets",
"MNSSJ Monthly notes of the Astronomical Society of South Africa",
"MNSSA Monthly Notes of the Astronomical Society of South Africa",
"MNRAS Monthly Notices of the Royal Astronomical Society",
"MWRv. Monthly Weather Review",
"Moon. Moon",
"MorGI Morskie Gidrofizicheskie Issledovaniia",
"MAtom Moscow Atomizdat",
"MoEBA Moscow Energoatomizdat Biblioteka Automatike",
"MEner Moscow Energoizdat",
"MoGid Moscow Gidrometeoizdat",
"MoIKI Moscow Institut Kosmicheskikh Issledovanii AN SSSR",
"MoIPM Moscow Institut Prikladnoi Matematiki AN SSSR",
"MoIzA Moscow Izdatel Atomizdat",
"MoIzE Moscow Izdatel Energiia",
"MIEBA Moscow Izdatel Energiia Biblioteka Avtomatike",
"MIEBR Moscow Izdatel Energiia Biblioteka Radioelektronike",
"MoIzK Moscow Izdatel Khimiia",
"MIzLI Moscow Izdatel Legkaia Industriia",
"MIzMa Moscow Izdatel Mashinostroenie",
"MIzMe Moscow Izdatel Metallurgiia",
"MoIzM Moscow Izdatel Moskovskogo Universiteta",
"MIzMU Moscow Izdatel Moskovskogo Universiteta Pt",
"MoIzN Moscow Izdatel Nauka",
"MINFI Moscow Izdatel Nauka AN SSR Fizicheskii Institut Trudy",
"MINCV Moscow Izdatel Nauka AN SSSR Chteniia imeni Vernadskogo",
"MoINA Moscow Izdatel Nauka AN SSSR Fizicheskii Institut Trudy",
"MINGI Moscow Izdatel Nauka AN SSSR Geologicheskoi Institut Trudy",
"MINMI Moscow Izdatel Nauka AN SSSR Matematicheskii Institut Trudy",
"MoINI Moscow Izdatel Nauka Issledovaniia Geomagnetizmu Aeronomii i Fizike Solntsa",
"MINTF Moscow Izdatel Nauka Teoreticheskaia Fizika",
"MINVS Moscow Izdatel Nauka Vychislitel naia Seismologiia",
"MIzNe Moscow Izdatel Nedra",
"MIzRS Moscow Izdatel Radio Sviaz",
"MIzSR Moscow Izdatel Sovetskoe Radio",
"MISRI Moscow Izdatel Sovetskoe Radio Ionosfernye Issledovaniia",
"MoIzS Moscow Izdatel Sviaz",
"MISST Moscow Izdatel Sviaz Statisticheskaia Teoriia sviazi",
"MoIzT Moscow Izdatel Transport",
"MoIzV Moscow Izdatel VINITI",
"MIzVS Moscow Izdatel Vysshaia Shkola",
"MoIzZ Moscow Izdatel Znanie",
"MIZNZ Moscow Izdatel Znanie Novoe Zhizni Nauke Tekhnike Seriia Fizika",
"MosIZ Moscow IZMIRAN",
"MoMTN Moscow Mezhdunarodnyi Tsentr Nauchnoi i Tekhnicheskoi Informatsii",
"MoMGK Moscow Mezhduvedomstvennyi Geofizicheskii Komitet",
"MUPB. Moscow University Physics Bulletin",
"MoVIN Moscow VINITI",
"MosVo Moscow Voenizdat",
"MosVI Moscow Voennoe Izdatel",
"MoVNT Moscow Vychislitel nyi Tsentr AN SSSR",
"MoVyS Moscow Vysshaia Shkola",
"MoLLP Moshchnye lazery i lazernaia plazma",
"MoEIT Moskovskii Energeticheskii Institut Trudy",
"MGUMN Moskovskii Gosudarstvennyi Universitet Institut Mekhaniki Nauchnye Trudy",
"MGIMO Moskovskii Gosudarstvennyi Universitet Institut Mekhaniki Otchet",
"MVSFA Moskovskii Universitet Vestnik Seriia Fizika Astronomiia",
"MUVSK Moskovskii Universitet Vestnik Seriia Khimiia",
"MVSMM Moskovskii Universitet Vestnik Seriia Matematika Mekhanika",
"MGTVM Moskovskij Gosudarstvennyj Tekhnicheskij Universitet Vestnik Seriya Mashinostroenie",
"MGTVP Moskovskij Gosudarstvennyj Tekhnicheskij Universitet Vestnik Seriya Priborostroenie",
"MotZe Motortechnische Zeitschrift",
"MtSOM Mount Stromlo Observatory Mimeographs",
"MtSRe Mount Stromlo Observatory Reprints",
"MtWAR Mount Wilson and Palomar Observatory Annual Report",
"MtWRe Mount Wilson and Palomar Observatory Reprints",
"MWOAR Mount Wilson Observatory Annual Report",
"MPERp MPE Report",
"MRSBu MRS Bulletin",
"MUSS. Muenchen Universitaets Schriften Serie",
"MROVG Munich R Oldenbourg Verlag GmbH",
"NISZ. Nabliudeniia Iskusstvennykh Sputnikov Zemli",
"NINT. Nablyud. Iskusstvennykh Nebesnykh Tel",
"NAZ.. Nachrichtenblatt der Astronomischen Zentralstelle Heidelberg",
"NVS.. Nachrichtenblatt der Vereinigung der Sternfreunde",
"NacEl Nachrichten Elektronik",
"NGFAW Nachrichtentechnische Gesellschaft Fachtagung ueber Antennen",
"NacZe Nachrichtentechnische Zeitschrift",
"NOGB. Nachr. Olbers-Ges. Bremen",
"NUFEM Nagoya University Faculty Engineering Memoirs",
"NURIA Nagoya University Research Institute of Atmospherics Proceedings",
"NUSEM Nagoya University School Engineering Memoirs",
"NaAIJ Nanjing Aeronautical Institute Journal",
"NUAAJ Nanjing University Aeronautics and Astronautics Journal",
"NanoL Nano Letters",
"Nanos Nanoscale",
"NRL.. Nanoscale Research Letters",
"Nanot Nanotechnology",
"NIUNA Napoli Istituto Universitario Navale Annali",
"NASCL NASA Circular Letter",
"PDSS. NASA Planetary Data System",
"NASRP NASA Reference Publication",
"NASSP NASA Special Publication",
"STIA. NASA STI/Recon Technical Report A",
"STIN. NASA STI/Recon Technical Report N",
"NASTM NASA Technical Memo",
"NBSSP National Bureau of Standards Special Publication",
"NBSTN National Bureau of Standards Technical Note",
"NaGe. National Geographic",
"NISTJ National Institute of Standards and Technology Journal of Research",
"PolRe National Institute Polar Research Memoirs",
"BAth. National Observatory of Athens Greece Bulletin of the Astronomical Institute",
"NRAON National Radio Astronomy Observatory Newsletter",
"NRAOR National Radio Astronomy Observatory Reprints",
"NRAOW National Radio Astronomy Observatory Workshop",
"NUDTJ National University Defense Technology Journal",
"NHESS Natural Hazards and Earth System Sciences",
"NatH. Natural History",
"NatSc Natural Science",
"Natur Nature",
"NatBi Nature Biotechnology",
"NatCh Nature Chemistry",
"NatCC Nature Climate Change",
"NatCo Nature Communications",
"NatGe Nature Geoscience",
"NatMa Nature Materials",
"NatNa Nature Nanotechnology",
"NaPho Nature Photonics",
"NPhS. Nature Physical Science",
"NatPh Nature Physics",
"NatSR Nature Scientific Reports",
"NW... Naturwissenschaften",
"NInfo Nauchnye Informatsii",
"NRRv. Naval Research Reviews",
"Navig Navigation",
"NavAu Navigation Australia",
"NavPa Navigation Paris",
"NVVSR Nederlandse Vereiniging voor Weer en Sterrenkunde Werkgroep veranderlijke Sterren Reports",
"NCNS. Network: Computation in Neural Systems",
"NSpEc Networks and Spatial Economics",
"AnBog Neue Annalen der Koeniglichen Sternwarte in Bogenhausen bei Muenchen",
"NJMM. Neues Jahrbuch Mineralogie Monatshefte",
"NeCom Neural Computation",
"NN... Neural Networks",
"NeuL. Neuroscience Letters",
"NPNDS Neutron Physics and Nuclear Data in Science and Technology",
"NewA. New Astronomy",
"NewAR New Astronomy Reviews",
"NJCh. New Journal of Chemistry",
"NJPh. New Journal of Physics",
"NewSc New Scientist",
"ASNYN News Letter of the Astronomical Society of New York",
"ICHIN Newsletters of the Interdivisional Commission on History of the IAGA",
"NTN.. New Technology News",
"NZJGG New Zealand Journal Geology and Geophysics",
"NZJS. New Zealand Journal of Science",
"NKG.. Nihon Kessho Gakkaishi",
"NOHIC Nizamiah JAPAL Rangapur Observatories Hyderabad India Contributions",
"NizRe Nizamiah Observatory Reprints",
"NCE.. Noise Control Engineering Journal",
"NTE.. Nondestructive Testing and Evaluation",
"NDTI. Nondestructive Testing and Evaluation International",
"NTCo. Nondestructive Testing Communications",
"NPPSB Nonequilibrium Problems in the Physical Sciences and Biology",
"NATM. Nonlinear Analysis Theory Methods Applications",
"Nonli Nonlinearity",
"NlOpt Nonlinear Optics",
"NPGeo Nonlinear Processes in Geophysics",
"NSAP. Nonlinear, Statistical and Applied Physics",
"NTA.. Nonlinear Theory and Its Applications, IEICE",
"NATi. Nordisk Astronomisk Tidsskrift",
"SApMM North Holland Series Applied Mathematical Mechanics",
"NHCWP North Hollywood Calif Western Periodicals Co",
"NPUJ. Northwestern Polytechnical University Journal",
"NoDef Not Defined",
"NoPar Notes et Informations",
"NROpt Nouvelle Revue d'Optique",
"NROA. Nouvelle Revue d'Optique Appliquee",
"UGC.. Nova Acta Regiae Soc. Sci. Upsaliensis Ser. V",
"NTvA. Novaya tekhn. v astron.",
"NoIGG Novosibirsk Institut Geologii i Geofiziki SO AN SSSR",
"NovIG Novosibirsk Institut Gidrodinamiki SO AN SSSR Dinamika Sploshnoi Sredy",
"NoIzN Novosibirsk Izdatel Nauka",
"NSSDC NSSDC Publication",
"NTTRv NTT Review",
"NDS.. Nuclear Data Sheets",
"NDT.. Nuclear Data Tables",
"NuEnD Nuclear Engineering and Design",
"NucFu Nuclear Fusion",
"NucFS Nuclear Fusion Special Supplement",
"NuGeo Nuclear Geophysics",
"NucIM Nuclear Instruments and Methods",
"NIMPR Nuclear Instruments and Methods in Physics Research",
"NIMPA Nuclear Instruments and Methods in Physics Research A",
"NIMPB Nuclear Instruments and Methods in Physics Research B",
"NucPh Nuclear Physics",
"NuPhA Nuclear Physics A",
"NuPhB Nuclear Physics B",
"NuPhS Nuclear Physics B Proceedings Supplements",
"NSE.. Nuclear Science Engineering",
"NucTe Nuclear Technology",
"NucTF Nuclear Technology Fusion",
"NAR.. Nucleic Acids Research",
"NuAlg Numerical Algorithms",
"NFAO. Numerical Functional Analysis and Optimization",
"NumHT Numerical Heat Transfer",
"NHTA. Numerical Heat Transfer Part A - Applications",
"NHTB. Numerical Heat Transfer Part B - Fundamentals",
"NuMat Numerische Mathematik",
"NCimA Nuovo Cimento A Serie",
"NCimB Nuovo Cimento B Serie",
"NCimC Nuovo Cimento C Geophysics Space Physics C",
"NCimD Nuovo Cimento D Serie",
"NCimL Nuovo Cimento Lettere",
"NCimR Nuovo Cimento Rivista Serie",
"NCimS Nuovo Cimento Serie",
"OCSC. OAA Compututer Section Circular",
"OSUC. Observationes Astronomicas Insitutas in Specula Universitatis Caesareae Dorpatensis",
"OVS.. Observation of Variable Stars",
"Obser Observation pi",
"OAORP Observations astronomiques faites a l'Observatoire royal de Paris",
"USNOO Observations made at the U.S. Naval Observatory",
"OOVRO Observations Owens Valley Radio Observatory",
"Bes1K Observatoire de Besancon",
"OBN1K Observatoire de Besancon - CNES",
"Gen1K Observatoire de Geneve",
"OSFOT Observatoire de la Société Astronomique de France Observations et Travaux",
"LyoRe Observatoire de Lyon Reprints",
"Meu1K Observatoire de Meudon",
"Nic1K Observatoire de Nice",
"CORB. Observatoire Royal de Belgique Communications Serie B",
"LPlaC Observatorio Astronomico de La Plata Circular",
"LPlaS Observatorio Astronomico de La Plata Separata Astronomica",
"RosOB Observatorio Astronomico Municipal de Rosario Argentia  Boletin",
"RioB. Observatorio Nacional Publicacoes do Servico Astronomico Rio de Janeiro",
"HelR. Observatory and Astrophysics Laboratory University of Helsinki Report",
"PLPla Observatory Astronomical La Plata Series Astronomies",
"ObVyS Obzory Vysokotemperaturnoi Sverkhprovodimosti",
"ONRAS Occasional Notes of the Royal Astronomical Society",
"ORROE Occasional Reports of the Royal Observatory Edinburgh",
"OccN. Occultation Newsletter, International Occultation Timing Association (IOTA)",
"OcDyn Ocean Dynamics",
"OcEng Ocean Engineering",
"OcMod Ocean Modelling",
"OSJaJ Oceanographical Society of Japan Journal",
"AcOC. Oceanologica Acta",
"Ocgy. Oceanology",
"OcPhE Ocean Physics and Engineering",
"OcSci Ocean Science",
"OcScD Ocean Science Discussions",
"OSJ.. Ocean Science Journal",
"Ocean Oceanus Summer",
"OAP.. Odessa Astronomical Publications",
"BOOde Odesskij Gosudarstvennyi Universitet im. I. I. Mechnikova Byulletin Astronomicheskoj Observatorii",
"IzOde Odesskij Gosudarstvennyi Universitet im. I. I. Mechnikova Izvestiya Astronomicheskoj Observatorii",
"OAWMN Oesterreichische Akademie Wissenschaften Mathematisch naturwissenschaftliche Klasse Sitzungsberichte Abteilung",
"Oikos Oikos",
"Okean Okeanologiia",
"ONCP. Old and New Concepts of Physics",
"OCzAS Ondrejov Czechoslovakia Czechoslovak Academy Sciences CAS Astronomical Institute Publications",
"ONERA ONERA TP",
"OEJV. Open European Journal on Variable Stars",
"OJA.. Open Journal of Acoustics",
"OJAS. Open Journal of Applied Sciences",
"OJBp. Open Journal of Biophysics",
"OJFD. Open Journal of Fluid Dynamics",
"OJGeo Open Journal of Geology",
"OJMic Open Journal of Microphysics",
"OLear Open Learning",
"OSID. Open Systems and Information Dynamics",
"AcOpt Optica Acta",
"OQE.. Optical and Quantum Electronics",
"OptEn Optical Engineering",
"OptFT Optical Fiber Technology",
"OptMa Optical Materials",
"OptPE Optical Physics and Engineering",
"OptQE Optical Quantum Electronics",
"OptRv Optical Review",
"OpSCN Optical Sciences Center Newsletter",
"OSAJI Optical Society of America Journal Optics and Image Science",
"OptPN Optics &amp",
"OptLE Optics and Lasers in Engineering",
"OPJ.. Optics and Photonics Journal",
"OptSp Optics and Spectroscopy",
"OptCo Optics Communications",
"OExpr Optics Express",
"OptLT Optics Laser Technology",
"OptL. Optics Letters",
"OptN. Optics News",
"Optik Optik",
"OpAt. Optika Atmosfery",
"OpAtO Optika Atmosfery i Okeana",
"OpSp. Optika i Spektroskopiia",
"OpMeP Optiko Mekhanicheskaia Promyshlennost",
"OCAM. Optimal Control Applications and Methods",
"OptEL Optoelectronics Letters",
"OERv. Opto-Electronics Review",
"OpPuT Optoelektronika i Poluprovodnikovaia Tekhnika",
"OrGeo Organic Geochemistry",
"OrLi. Origins of Life",
"OLEB. Origins of Life and Evolution of the Biosphere",
"Ori.. Orione",
"Orion Orion: Zeitschrift für Amateur-Astronomie",
"IGS.. Orlando FL Academic Press Inc International Geophysics Series",
"OrNav Ortung und Navigation",
"BuENS Osaka Prefecture University Bulletin Series Engineering Natural Sciences",
"OsUTR Osaka University Technology Reports",
"Osir. Osiris",
"NapCo Osservatorio Astronomico di Capodimonte Napoli Contributi Astronomici",
"TerCo Osservatorio Astronomico di Collurania Teramo Contributi",
"TerMm Osservatorio Astronomico di Collurania Teramo Memorie ed Osservazioni",
"TerNC Osservatorio Astronomico di Collurania Teramo Note e Comunicazioni",
"PadCR Osservatorio Astronomico di Padova Comunicazioni e Rassegne",
"RomCo Osservatorio Astronomico di Roma su Monte Mario Contributi Scientifici",
"TriP. Osservatorio Astronomico di Trieste Pubblicazioni",
"TreP. Osservatorio Privato Specola Ariel Treviso Italia Pubblicazione",
"MmArc Osservazioni e memorie dell'Osservatorio astrofisico di Arcetri",
"MmArS Osservazioni e memorie dell'Osservatorio astrofisico di Arcetri - Appendici",
"OsCar Osteoarthritis and Cartilage",
"OtObI Otbor i Obrabotka Informatsii",
"OtPI. Otbor i Peredacha Informatsii",
"OISNP Oxford Pergamon Press International Series on Natural Philosophy",
"OISTS Oxford Pergamon Press International Tables Selected Constants",
"OxfOO Oxford University Observatory Observations",
"OxM.. Oxidation of Metals",
"OzSE. Ozone: Science &amp",
"Palb. Paleobiology",
"PalOc Paleoceanography",
"PMetR Papers in Meteorological Research",
"PPh.. Papers in Physics",
"PMG.. Papers Meteorology Geophysics",
"PGC.. Papers on Global Change IGBP",
"ParC. Parallel Computing",
"Paras Parasitology",
"ParAc Particle Accelerators",
"PPhI. Particle Physics Insights",
"PaReL Pattern Recognition Letters",
"PerMS Perceptual Motor Skills",
"PZ... Peremennye Zvezdy",
"PZP.. Peremennye Zvezdy Prilozhenie",
"PMHu. Periodica Mathematica Hungarica",
"PPEE. Periodica Polytechnica Electrical Engineering",
"PPME. Periodica Polytechnica Mechanical Engineering",
"PPTE. Periodica Polytechnica Transportation Engineering",
"PerCo Perkins Observatory Contributions",
"PMO.. Perth Meridien Observations",
"PTMJ. Phase Transitions: A Multinational Journal",
"PhDT. Ph.D. Thesis",
"PhiJR Philips Journal Research",
"PhiRR Philips Research Reports",
"PhiTR Philips Technical Review",
"PMag. Philosophical Magazine",
"PMagL Philosophical Magazine Letters",
"PMagA Philosophical Magazine, Part A",
"PMagB Philosophical Magazine, Part B",
"PFP.. Philosophy and Foundations of Physics",
"Phoen Phoenix Mitteilungsblatt fuer Veraenderlichenbeobachter",
"PcPb. Photochemistry and Photobiology",
"Pg... Photogrammetria",
"PgE.. Photogrammetric Engineering",
"PgERS Photogrammetric Engineering and Remote Sensing",
"PhInt Photo Interpretation",
"PhNan Photonics and Nanostructures",
"PhSen Photonic Sensors",
"PhoSp Photonics Spectra",
"PsynR Photosynthesis Research",
"Psyn. Photosynthetica",
"PhyOJ Physcs Online Journal",
"Phy.. Physica",
"PhyA. Physica A Statistical Mechanics and its Applications",
"PhyBC Physica B+C",
"PhyB. Physica B Condensed Matter",
"PhyC. Physica C Superconductivity",
"PhyD. Physica D Nonlinear Phenomena",
"PhyE. Physica E Low-Dimensional Systems and Nanostructures",
"PEFPN Physica Energiae Fortis et Physica Nuclearis",
"PhAco Physical Acoustics",
"PhBio Physical Biology",
"PCESR Physical Chemical and Earth Sciences Research Reports",
"PCCP. Physical Chemistry Chemical Physics (Incorporating Faraday Transactions)",
"PCSE. Physical Chemistry: Science and Engineering",
"PhGeo Physical Geography",
"PPHTS Physical Properties of High Temperature Superconductors",
"PhyR. Physical Research",
"PhRv. Physical Review",
"PhRvA Physical Review A",
"PhRvB Physical Review B",
"PhRvC Physical Review C",
"PhRvD Physical Review D",
"PhRvE Physical Review E",
"PhRvL Physical Review Letters",
"PhRvI Physical Review Series I",
"PhRvS Physical Review Special Topics Accelerators and Beams",
"PRSTP Physical Review Special Topics Physics Education",
"PhRvX Physical Review X",
"PSD.. Physical Sciences Data",
"PSCEC Physical Sciences Series of the Commission of European Communities",
"PhyNr Physica Norvegica",
"PhyS. Physica Scripta",
"PhySB Physica Scripta B",
"PhST. Physica Scripta Volume T",
"PSSAR Physica Status Solidi Applied Research",
"PSSBR Physica Status Solidi B Basic Research",
"PSSCR Physica Status Solidi C Current Topics",
"PSSRR Physica Status Solidi Rapid Research Letters",
"PhySS Physica Status Solids",
"PhyL. Physic Letters",
"PhChH PhysicoChemical Hydrodynamics",
"Physi Physics",
"PCS.. Physics and Chemistry in Space",
"PhChE Physics and Chemistry of Earth",
"PCL.. Physics and Chemistry of Liquids",
"PCMLD Physics and Chemistry of Materials with Low-Dimensional Structures",
"PCMLA Physics and Chemistry of Materials with Low-Dimensional Structures Series A",
"PCMLB Physics and Chemistry of Materials with Low-Dimensional Structures Series B",
"PCMLC Physics and Chemistry of Materials with Low-Dimensional Structures Series C",
"PCM.. Physics and Chemistry of Minerals",
"PCE.. Physics and Chemistry of the Earth",
"PCEA. Physics and Chemistry of the Earth A",
"PCEB. Physics and Chemistry of the Earth B",
"PCEC. Physics and Chemistry of the Earth C",
"PCED. Physics and Chemistry of the Earth Delta",
"PEEI. Physics and Evolution of the Earth's Interior",
"PhApp Physics and its Applications",
"PTPPB Physics and Technology of Particle and Photon Beams",
"PhB.. Physics Bulletin",
"DokPh Physics - Doklady",
"PhyEd Physics Education",
"PhyEs Physics Essays",
"PCHEI Physics in Collision: High-Energy ee/ep/pp Interactions",
"PMB.. Physics in Medicine and Biology",
"PhP.. Physics in Perspective",
"PhTec Physics in Technology",
"PhyIn Physics International",
"PhLF. Physics Laser Fusion",
"PhL.. Physics Letters",
"PhLA. Physics Letters A",
"PhLB. Physics Letters B",
"PhLC. Physics Letters Section C Physics Reports C",
"PhyNY Physics New York",
"PhyN. Physics Notes",
"PAN.. Physics of Atomic Nuclei",
"PAM.. Physics of Atoms and Molecules",
"PhFl. Physics of Fluids",
"PhFlB Physics of Fluids B",
"PhLRv Physics of Life Reviews",
"PLDS. Physics of Low-Dimensional Structures",
"PhMet Physics of Metals",
"PMM.. Physics of Metals and Metallography",
"PPN.. Physics of Particles and Nuclei",
"PPNL. Physics of Particles and Nuclei Letters",
"PhPl. Physics of Plasmas",
"PhQE. Physics of Quantum Electronics",
"PSL.. Physics of Solids and Liquids",
"PEPI. Physics of the Earth and Planetary Interiors",
"PhSS. Physics of the Solid State",
"PTF.. Physics of Thin Films",
"PWP.. Physics of Wave Phenomena",
"PhR.. Physics Reports",
"PRI.. Physics Research International",
"PhT.. Physics Today",
"PhyU. Physics Uspekhi",
"PhyW. Physics World",
"PCTM. Physikalisch-Chemische Trenn- und Messmethoden",
"PhyBl Physikalische Blötter",
"PhyG. Physikalische Gesellschaft",
"PhyGZ Physikalische Gesellschaft Zürich",
"PhyZ. Physikalische Zeitschrift",
"PKM.. Physik der Kondensierten Materie",
"PhuZ. Physik in unserer Zeit",
"PhyCP Physiological Chemistry and Physics",
"PhyM. Physiological Measurement",
"PhylS Physiologist Supplement",
"PAZh. Pis ma Astronomicheskii Zhurnal",
"PZETF Pis ma Zhurnal Eksperimental noi i Teoreticheskoi Fiziki",
"PZhTF Pis ma Zhurnal Tekhnischeskoi Fiziki",
"PlAst Planetary Astronomy",
"PlR.. Planetary Report",
"PlSci Planetary Science",
"PSRD. Planetary Science Research Discoveries",
"PCPhy Plant and Cell Physiology",
"PFR.. Plasma and Fusion Research",
"PCPP. Plasma Chemistry and Plasma Processing",
"PlPh. Plasma Physics",
"PPCF. Plasma Physics and Controlled Fusion",
"PlPhR Plasma Physics Reports",
"PlPo. Plasmas and Polymers",
"PlST. Plasma Science and Technology",
"PSST. Plasma Sources Science Technology",
"PRFVT Plastiques Renforces Fibres de Verre Textile",
"PLoSB PLoS Biology",
"PLoSC PLoS Clinical Trials",
"PLSCB PLoS Computational Biology",
"PLoSG PLoS Genetics",
"PLoSM PLoS Medicine",
"PLoSN PLoS Neglected Tropical Diseases",
"PLoSO PLoS ONE",
"PLoSP PLoS Pathogens",
"PMCPA PMC Physics A",
"PMCPB PMC Physics B",
"PMCPC PMC Physics C",
"PMTF. PMTF Zhurnal Prikladnoi Mekhaniki i Tekhnicheskoi Fiziki",
"nraop National Radio Astronomy Observatory Press Release",
"PnGid Pnevmatika i Gidravlika",
"noaop NOAO Proposal",
"PolSc Polar Science",
"PolSi Poliarnye Siianiia",
"PSSNN Poliarnye Siianiia i Svechenie Nochnogo Neba",
"PASAM Polish Academy of Science Arch Mech",
"PASAS Polish Academy of Science Artificial Satellites",
"PASIG Polish Academy of Sciences Institute of Geophysics Publications",
"PASTA Polish Academy of Sciences Theory Aggregation Coagulation",
"PJMPE Polish Journal of Medical Physics And Engineering",
"PCZNN Politechnika Czestochowska Zeszyty Naukowe Nauki Techniczne Mechanika",
"PGZNM Politechnika Gdanska Zeszyty Naukowe Mechanika",
"PSZNM Politechnika Slaska Zeszyty Naukowe Mechanika",
"PolAt Pollution Atmospherique",
"CraR. Polskie Towarzyslwo Milosnikow Astronomii",
"PolTM Poluprovodnikovaia Tekhnika i Mikroelektronika",
"PolPP Poluprovodnikovye Pribory i ikh Primenenie",
"Poly. Polymer",
"PoCom Polymer Composites",
"PolPh Polymer Physics",
"PPTEn Polymer-Plastics Technology and Engineering",
"PomAK Pomiary Automatyka Kontrola",
"PATi. Popular Astronomisk Tidsskrift",
"PA... Popular Astronomy",
"PorMe Poroshkovaia Metallurgiia",
"PoAn. Postepy Astronautyki",
"PoAst Postepy Astronomii Krakow",
"PSci. Pour la Science",
"PDiff Powder Diffraction",
"PUAMA Poznan Uniwersytet im Adama Mickiewicza Seria Akustyka",
"PUAMF Poznan Uniwersytet im Adama Mickiewicza Seria Fizyka",
"PrAst Practical Astronomy",
"NaiRe Pradesh  State Observatory Naini Tal Insia Reprints",
"PraAc Prague Academia",
"Prama Pramana",
"PreR. Precambrian Research",
"Prib. Priborostroenie",
"PriTE Pribory i Tekhnika Eksperimenta",
"PriMM Prikladnaia Matematika i Mekhanika",
"PriMP Prikladnaia Matematika i Programmirovanie",
"PriM. Prikladnaia Mekhanika",
"PPPLR Princeton Plasma Physics Laboratory Report",
"Prir. Priroda",
"Priv. Private Communication",
"PrEM. Probabilistic Engineering Mechanics",
"PrAiA Problemy Arktiki i Antarktiki",
"PrBio Problemy Bioniki",
"PrDRV Problemy Difraktsii i Rasprostraneniia Voln",
"PrFA. Problemy Fiziki Atmosfery",
"PrFKL Problemy Iadernoi Fiziki i Kosmicheskikh Luchei",
"PrKFi Problemy Kosmicheskoi Fiziki",
"PrMas Problemy Mashinostroeniia",
"PrPro Problemy Prochnosti",
"PrSP. Problemy Sluchainogo Poiska",
"PrTE. Problemy Tekhnicheskoi Elektrodinamiki",
"PrTGE Problemy Teorii Gravitatsii i Elementarnykh Chastits",
"PrTPT Problemy Teploenergetiki i Prikladnoi Teplofiziki",
"PJA.. Proceeding of the Japan Academy",
"PJAA. Proceeding of the Japan Academy, Series A",
"PJAB. Proceeding of the Japan Academy, Series B",
"PBioS Proceedings: Biological Sciences",
"PMPES Proceedings: Mathematical, Physical and Engineering Sciences",
"PAMS. Proceedings of the American Mathematical Society",
"PAPhS Proceedings of the American Philosophical Society",
"PASAu Proceedings of the Astronomical Society of Australia",
"PCAS. Proceedings of the California Academy of Sciences",
"PCPS. Proceedings of the Cambridge Philosophical Society",
"PEMS. Proceedings of the Edinburgh Mathematical Society",
"PIASE Proceedings of the Indian Academy of Science, Earth and Planetary Sciences",
"PINSA Proceedings of the Indian National Science Academy Part A",
"PINSB Proceedings of the Indian National Science Academy Part B",
"PIGP. Proceedings of the Institute of General Physics, Adademy of the Sciences of Russia",
"PILOM Proceedings of the International Latitude Observatory at Mizusawa",
"PIRE. Proceedings of the IRE",
"PNAS. Proceedings of the National Academy of Sciences",
"PNAS. Proceedings of the National Academy of Sciences USA",
"PNAS. Proceedings of the National Academy of Sciences of the USA",
"PNSC. Proceedings of the National Science Council",
"PNSBP Proceedings of the National Society of Black Physicists",
"PPS.. Proceedings of the Physical Society",
"PPSA. Proceedings of the Physical Society A",
"PPSB. Proceedings of the Physical Society B",
"PPSL. Proceedings of the Physical Society of London",
"PRIAN Proceedings of the Research Institute of Atmospherics, Nagoya University",
"PRIAA Proceedings of the Royal Irish Academy Section A",
"PRNAS Proceedings of the Royal Netherlands Academy of Arts and Sciences",
"PSEBM Proceedings of the Society for Experimental Biology and Medicine",
"PrVP. Proceedings of Vibration Problems",
"PELIS Program: electronic library &amp",
"PrAeS Progress in Aerospace Sciences",
"PrAA. Progress in Astronautics and Aeronautics",
"PrA.. Progress in Astronomy",
"PABei Progress in Astronomy",
"PBB.. Progress in Biochemistry and Biophysics",
"PBBC. Progress in Biophysics and Biophysical Chemistry",
"PBMB. Progress in Biophysics and Molecular Biology",
"PrECS Progress in Energy and Combustion Science",
"PLTP. Progress in Low Temperature Physics",
"PrMS. Progress in Materials Science",
"PMatP Progress in Mathematical Physics",
"PMRP. Progress in Medical Radiation Physics",
"PMetP Progress in Metal Physics",
"PNSci Progress in Natural Science",
"PrOce Progress in Oceanography",
"POrCo Progress in Organic Coatings",
"PrPNP Progress in Particle and Nuclear Physics",
"PPcPp Progress in Photochemistry and Photophysics",
"PPGeo Progress in Physical Geography",
"PrPh. Progress in Physics",
"PQE.. Progress in Quantum Electronics",
"PrSS. Progress In Surface Science",
"PTCP. Progress in Theoretical Chemistry and Physics",
"PTEP. Progress of Theoretical and Experimental Physics",
"PThPh Progress of Theoretical Physics",
"PThPS Progress of Theoretical Physics Supplement",
"ProTe Promyshlennaia Teplotekhnika",
"PrEx. Propellants and Explosives",
"PrExP Propellants and Explosives Pyrotechnics",
"PMMin Proper Motion Survey, University of Minnesota",
"rxte pRXTE Proposal",
"sptz pSpitzer Proposal",
"suba pSubaru Proposal",
"PUFir Pubblicazioni della R. Universita degli studi di Firenze",
"PSAIL Pubblicazioni della Stazione Astronomica Internazionale di Latitudine",
"POMil Pubblicazioni dell'Osservatorio Astronomico di Milano-Merate",
"POPad Pubblicazioni dell'Osservatorio Astronomico di Padova",
"POPal Pubblicazioni dell'Osservatorio Astronomico di Palermo",
"POTor Pubblicazioni Varie Fuori Serie dell'Osservatorio Astronomico di Torino",
"PKCat Publ. House Czech. Acad. Sci.",
"PMad. Publicacion Facultad de Ciencias Madrid",
"POClu Publicatiile Observatorului Astronomical Universitatii din Cluj",
"POPar Publication de l'Observatoire de Paris Notes et Informations",
"POStr Publication de l'Observatoire de Strasbourg",
"PUSK. Publication der Koeniglichen Sternwarte in Kiel",
"PULei Publicationen der K. Universitoats-Sternwarte zu Leipzig",
"PCARS Publication of COMU Astrophysics Research Center",
"PKAS. Publication of Korean Astronomical Society",
"PPCAS Publication of the Pomona College Astronomical Society",
"PIAGL Publications de l'Institut d'Astronomie et de Geophysique Georges Lemaitre",
"POBeo Publications de l'Observatoire Astronomique de Beograd",
"POBor Publications de l'Observatoire de l'Universite de Bordeaux",
"POTou Publications de l'Observatoire de Toulouse",
"PLAGL Publications du Laboratoire d'Astronomie et de Geodesie de l'Universite de Louvain",
"PDHO. Publications of Debrecen Heliophysical Observatory",
"POBol Publications of dell'Osservatorio Astronomie de Bologna",
"PLawO Publications of Laws Observatory, University of Missouri",
"PLicO Publications of Lick Observatory",
"POMic Publications of Michigan Observatory",
"PCat. Publications of Osservatorio Astrofisico di Catania",
"PASK. Publications of the Academy of Science Kasakstan Sect. Astrobotanics",
"PAllO Publications of the Allegheny Observatory of the University of Pittsburgh",
"PAASA Publications of the Astronomical and Astrophysical Society of America",
"PAICU Publications of the Astronomical Institute of the Charles University",
"PAICz Publications of the Astronomical Institute of the Czechoslovak Academy of Sciences",
"PUAms Publications of the Astronomical Institute of the University of Amsterdam",
"PBrn. Publications of the Astronomical Institute of the University of Borneo",
"POHel Publications of the Astronomical Observatory Helsinki",
"PAOS. Publications of the Astronomical Observatory of Sarajevo",
"POMin Publications of the Astronomical Observatory University of Minnesota",
"PASA. Publications of the Astronomical Society of Australia",
"PASJ. Publications of the Astronomical Society of Japan",
"PASP. Publications of the Astronomical Society of the Pacific",
"PASPS Publications of the Astronomical Society of the Pacific Supplement",
"PASRB Publications of the Astronomical Society Rudjer Boskovic",
"PADEU Publications of the Astronomy Department of the Eotvos Lorand University",
"PAIB. Publications of the Astronomy Institute of Bonn",
"PAB.. Publications of The Astrophysics Branch Ottawa",
"PBeiO Publications of the Beijing Astronomical Observatory",
"PBosO Publications of the Bosscha Observatory Lembang Indonesia",
"PCinO Publications of the Cincinnati Observatory",
"PCooO Publications of the Cook Observatory",
"PDDO. Publications of the David Dunlap Observatory",
"PDAUC Publications of the Department of Astronomy University of Chile",
"PDAO. Publications of the Dominion Astrophysical Observatory Victoria",
"PDO.. Publications of the Dominion Observatory Ottawa",
"PDreO Publications of the Dresden Observatory",
"PFAO. Publications of the Flower Astronomical Observatory",
"PGLO. Publications of the Goethe Link Observatory",
"PGooO Publications of the Goodsell Observatory, Carleton College",
"ILOMP Publications of the International Latitude Observatory at Mizusawa",
"PIstO Publications of the Istanbul University Observatory",
"PGro. Publications of the Kapteyn Astronomical Laboratory Groningen",
"PKirO Publications of the Kirkwood Observatory of Indiana University",
"PAth. Publications of the Laborotory of Astronomy University of Athens",
"PMcCO Publications of the Leander McCormick Observatory",
"PManO Publications of the Manila Observatory",
"PMunO Publications of the Munich Observatory",
"PNAOC Publications of the National Astronomical Observatories of China",
"PNAOJ Publications of the National Astronomical Observatory of Japan",
"POLyo Publications of the Observatoire de Lyon",
"PGenA Publications of the Observatoire Geneve Series A",
"PGenB Publications of the Observatoire Geneve Series B",
"POHP. Publications of the Observatoire Haute-Provence",
"POANC Publications of the Observatorie Astronomie Nacional Cerro Calan",
"POIst Publications of the Observatory Astronomie University Istambul",
"POslO Publications of the Oslo Observatory",
"POVRO Publications of the Owens Valley Observatory",
"PPMtO Publications of the Purple Mountain Observatory",
"PRCO. Publications of the Riverview College Observatory",
"PROE. Publications of the Royal Observatory of Edinburgh",
"PSAO. Publications of the Shaanxi Astronomical Observatory",
"PShaO Publications of the Shaanxi Astronomy Observatory",
"PSprO Publications of the Sproul Observatory",
"PSSAI Publications of the Sternberg State Astronomical Institute",
"PTarO Publications of the Tartu Astrofizica Observatory",
"PTasO Publications of the Tashkent Astronomical Observatory",
"PUPFA Publications of the University of Pennsylvania Flower Astronomical Observatory",
"PUSNO Publications of the U.S. Naval Observatory Second Series",
"PVVO. Publications of the Van Vleck Observatory",
"PVasO Publications of the Vassar College Observatory",
"PWasO Publications of the Washburn Observatory",
"PYerO Publications of the Yerkes Observatory",
"PYunO Publications of the Yunnan Observatory",
"PWHHO Publications of West Hendon House Observatory, Sunderland",
"PSCDS Publication Speciale du Centre de Donnees Stellaires",
"POxf. Publications University of Oxford Department of Astrophysics",
"PUS.. Public Understanding of Science",
"PKUJ. Publikationen der Kaiserlichen Universitaets-Sternwarte Jurjew",
"PAIKH Publikationen des Astrophysikalischen Instituts Koenigstuhl-Heidelberg",
"POPot Publikationen des Astrophysikalischen Observatoriums zu Potsdam",
"PCopO Publikationer og mindre Meddeler fra Kobenhavns Observatorium",
"PGAOI Pulkovo Glavnaia Astronomicheskaia Observatoriia Izvestiia",
"PApCh Pure &amp",
"PApGe Pure and Applied Geophysics",
"PApPh Pure and Applied Physics",
"PApOp Pure Applied Optics",
"QUnJ. Qinghua University Journal",
"xmm.. XMM-Newton Press Release",
"xmm.. XMM-Newton Proposal",
"QREI. Quality Reliability Engineering International",
"QuFin Quantitative Finance",
"QuSOp Quantum and Semiclassical Optics",
"QuEle Quantum Electronics",
"QuIP. Quantum Information Processing",
"QuOpt Quantum Optics",
"QBSA. Quarterly Bulletin on Solar Activity",
"QJMAM Quarterly Journal of Mechanics and Applied Mathematics",
"QJRAS Quarterly Journal of the Royal Astronomical Society",
"QJRMS Quarterly Journal of the Royal Meteorological Society",
"QApMa Quarterly of Applied Mathematics",
"QRBio Quarterly Reviews of Biophysics",
"QuInt Quaternary International",
"QuRes Quaternary Research",
"QSRv. Quaternary Science Reviews",
"Quest Quest",
"RadRe Radcliffe Observatory Pretoria South Africa Reprints",
"Rad.. Radiant, Journal of the Dutch Meteor Society",
"REB.. Radiation and Environmental Biophysics",
"RadEf Radiation Effects",
"REDS. Radiation Effects and Defects in Solids",
"RaPC. Radiation Physics and Chemistry",
"RaRe. Radiation Research",
"RaEE. Radio and Electronic Engineer",
"Radel Radioehlektronika",
"REEP. Radio Engineering and Electronic Physics",
"RaF.. Radiofizika",
"RaSol Radioizluchenie Solntsa",
"RPRA. Radio Physics and Radio Astronomy",
"RaRLJ Radio Research Laboratory, Journal",
"RaRLR Radio Research Laboratory, Review",
"RaSc. Radio Science",
"RaScB Radio Science Bulletin",
"RaScS Radio Science Supplement",
"RaT.. Radioteknika",
"RaEl. Radiotekhnika i Elektronika",
"RERE. Radiotekhnika i Elektronika Radio Engineering Electronic Physics",
"RatK. Radiotekhnika Kharkov",
"RTRE. Radiotekhnika Tecommunications Radio Engineering Radio Engineering",
"RaPro Raschety Prochnost",
"RF... Raumfahrtforschung",
"RCAEn RCA Engineer",
"RCARv RCA Review",
"RTI.. Real-Time Imaging",
"RDCMP Recent Development in Condensed Matter Physics",
"RRDAP Recent Research Development in Applied Physics",
"RRDBC Recent Research Development in Biophysical Chemistry",
"RRDBB Recent Research Development in Biophysics and Biochemistry",
"RRDCP Recent Research Development in Chemical Physics",
"RRDPC Recent Research Development in Physical Chemistry",
"RRDP. Recent Research Development in Physics",
"RRDPF Recent Research Development in Physics of Fluids",
"RRDSP Recent Research Development in Statistical Physics",
"ReAA. Recherches Aeronautiques et Aerospatiales",
"RAOU. Recherches Astronomiques de l'Observatoire d'Utrecht",
"RZh.. Referationyj Zhurnal",
"RJEHM Regional Journal of Energy Heat and Mass Transfer",
"RCD.. Regular and Chaotic Dynamics",
"RemS. Remote Sensing",
"RSEMS Remote Sensing Electro Magnetic Spectrum",
"RSEnv Remote Sensing of Environment",
"RSQ.. Remote Sensing Quarterly",
"Renor Renormalization",
"RISRJ Report Ionosphere Space Research Japan",
"HarOR Report of the Committee of the Overseers of Harvard College appointed to visit the Observatory",
"RNAOJ Report of the National Astronomical Observatory of Japan",
"RSPUT Report Series of the Department of Physics and Science, University of Turku",
"YalRY Reports for the year presented by the Board of Managers of the Observatory of Yale University to the President and Fellows",
"ROLun Reports of the Lund Observatory",
"RpMP. Reports on Mathematical Physics",
"RPPh. Reports on Progress in Physics",
"RTAMS Representation Theory of the American Mathematical Society",
"BeiRe Reprints Beijing Astronomical Observatory Academia Sinica",
"ROCi. Republic Observatory Johannesburg Circular",
"ChPAS Republic of China National Science Council Proceedings Applied Sciences",
"RBSEJ Research Based Science Education Journal",
"RAA.. Research in Astronomy and Astrophysics",
"ReNEv Research in Nondestructive Evaluation",
"RSTEd Research in Science and Technological Education",
"RScEd Research in Science Education",
"RJPh. Research Journal of Physics",
"RLEMR Research Laboratory Engineering Materials Report",
"RLPME Research Laboratory Precision Machinery Electronics Bulletin",
"RLOpt Research Letters in Optics",
"RLPhy Research Letters in Physics",
"RMA.. Research Measurement Approach",
"RNOST Research News &amp",
"RPFSU Research Papers Faculty of Materials Science and Technology Slovak University of Technology",
"RRP.. Research Reports in Physics",
"RTP.. Research Trends in Physics",
"RNAO. Resultados del Observatorio Nacional Argentino",
"ROCor Resultados del Observatorio Nacional Argentino en Cordoba",
"ResPh Results in Physics",
"RAROC Results of Astronomical Observations made at the Royal Observatory, Cape of Good Hope",
"RMROC Results of Meridian Observations made at the Royal Observatory, Cape of Good Hope",
"RDR.. Review of Derivatives Research",
"RvPCJ Review of Physical Chemistry of Japan",
"RvPT. Review of Physics in Technology",
"RScI. Review of Scientific Instruments",
"RvAqS Reviews in Aquatic Sciences",
"RvMaP Reviews in Mathematical Physics",
"RvMA. Reviews in Modern Astronomy",
"RvGeo Reviews of Geophysics",
"RvGSP Reviews of Geophysics and Space Physics",
"RvGeS Reviews of Geophysics Supplement",
"RvMin Reviews of Mineralogy",
"RvMP. Reviews of Modern Physics",
"RvMPS Reviews of Modern Physics Supplement",
"RvOp. Reviews of Optics",
"RvPP. Reviews of Plasma Physics",
"RvRRL Reviews of the Radio Research Laboratory",
"RvA.. Revista Astronomica Organo de la Asociacion Argengina Amigos de la Astronomia Buenos Aires",
"RBrFi Revista Brasileira de Fisica",
"RvCF. Revista Colombiana de Fisica",
"IORP. Revista do observatorio : publicacao mensal do Imperial Observatorio do Rio de Janeiro",
"RMxAA Revista Mexicana de Astronomia y Astrofisica",
"RMxF. Revista Mexicana de Fisica",
"RMxFE Revista Mexicana de Fisica E",
"RMxFS Revista Mexicana de Fisica Supplement",
"RvMad Revista Real Acad. Ciencias Exact. Fis. Nat. Madrid",
"RTrTe Revista Transporturilor si Telecomunicatiilor",
"AerRv Revue Aerospatiale",
"RvAc. Revue d'Acoustique",
"RvGPG Revue de Geographie Physique et de Geologie Dynamique",
"RvGDG Revue de Geologie Dynamique et de Geographie Physique",
"RvPA. Revue de Physique Appliquee",
"RvPD. Revue du Palais de la Decouverte",
"RvFEQ Revue Francaise de l'Electricite Quarter",
"RFrM. Revue Francaise de Mecanique",
"RFrMQ Revue Francaise de Mecanique Quarter",
"RRMPA Revue Roumaine de Mathematiques Pures et Appliquees",
"RvRP. Revue Roumaine de Physique",
"RvRST Revue Roumaine des Sciences Techniques Serie de Mecanique Appliquee",
"RST.. Revue Scientifique et Technique CECLES CERS",
"RvT.. Revue Technique Thomson CSF",
"RNISZ Rezul taty Nabliudenii Iskusstvennykh Sputnikov Zemli",
"RWTHA Rheinisch Westfaelische Technische Hochschule Aerodynamisches Institut Abhandlungen",
"AcRhe Rheologica Acta",
"RA... Ricerche Astronomiche",
"RIzZi Riga Izdatel Zinatne",
"Rise. Rise Hvezd",
"RRA.. River Research and Applications",
"RIG.. Rivista Italiana di Geofisica",
"RIGSA Rivista Italiana di Geofisica e Scienze Affini",
"RvTS. Rivista Tecnica Selenia",
"Robot Robotica",
"RMRE. Rock Mechanics and Rock Engineering",
"RMFMR Rock Mechanics Felsmechanik Mecanique des Roches",
"Roczn Rocznik Astronomiczny Observatorjum Krakowskiego Krakow",
"RoAJ. Romanian Astronomical Journal",
"RoJPh Romanian Journal of Physics",
"RoRPh Romanian Reports in Physics",
"RoIE. Rossiiskaia Akademiia Nauk Izvestiia Energetika",
"RoIMZ Rossiiskaia Akademiia Nauk Izvestiia Mekhanika Zhidkosti i Gaza",
"RoISF Rossiiskaia Akademiia Nauk Izvestiia Seriia Fizicheskaia",
"RoDok Rossijskaya Akademiya Nauk Doklady",
"RoIMT Rossijskaya Akademiya Nauk Izvestiya Mekhanika Tverdogo Tela",
"RoIzF Rossijskaya Akademiya Nauk Izvestiya Seriya Fizicheskaya",
"RWPWZ Rostock Wilhelm Pieck Universitaet Wissenschaftliche Zeitschrift Mathematisch Naturwissenschaftliche Reihe",
"PVSS. Royal Astronomical Society of New Zealand Publications of Variable Star Section",
"VSSCi Royal Astronomical Society of New Zealand Variable Star Section Circulars",
"VSSRe Royal Astronomical Society of New Zealand Variable Star Section Reprints",
"VSSSC Royal Astronomical Society of New Zealand Variable Star Section Special Circulars",
"RGOB. Royal Greenwich Observatory Bulletin",
"RGOO. Royal Greenwich Observatory Observations",
"ROAn. Royal Observatory Annals",
"CapMi Royal Observatory Cape Mimeogram",
"CoRSE Royal Society Edinburgh Communications Physical Sciences",
"RSCT. Royal Society of Canada Transactions",
"RSEPS Royal Society of Edinburgh Proceedings Section",
"RSET. Royal Society of Edinburgh Transactions",
"RSPTA Royal Society of London Philosophical Transactions Series A",
"RSPTB Royal Society of London Philosophical Transactions Series B",
"RSPT. Royal Society of London Philosophical Transactions Series I",
"RSPSA Royal Society of London Proceedings Series A",
"RSPSB Royal Society of London Proceedings Series B",
"RSPS. Royal Society of London Proceedings Series I",
"RoIn. Rozprawy Inzynierskie",
"RoIET Rozprawy Inzynierskie Engineering Transactions",
"asc.. Space Telescope ASC Instrument Science Report",
"nicm. Space Telescope NICMOS Instrument Science Report",
"stis. Space Telescope STIS Instrument Science Report",
"wfc.. Space Telescope WFC Instrument Science Report",
"wfpc. Space Telescope WFPC2 Instrument Science Report",
"Ruimt Ruimtevaart",
"RuCRv Russian Chemical Reviews",
"RuGG. Russian Geology and Geophysics",
"RJET. Russian Journal of Engineering Thermophysics",
"RJMP. Russian Journal of Mathematical Physics",
"RJPC. Russian Journal Physical Chemistry",
"RJPCA Russian Journal Physical Chemistry A",
"RJTAM Russian Journal Theoretical and Applied Mechanics",
"RuMaS Russian Mathematical Surveys",
"RuMet Russian Metallurgy",
"RuPhJ Russian Physics Journal",
"RALR. Rutherford Appleton Laboratory Report",
"Sadha Sadhana",
"STVF. Samoletostroenie Tekhnika Vozdushnogo Flota",
"SAMPJ SAMPE Journal",
"SAMPQ SAMPE Quarterly",
"UISTS San Diego CA Univelt Inc Science Technology Series",
"MaMeA Sankt Peterburgskii Universitet Vestnik Seriia Matematika Mekhanika Astronomiia",
"SAOSR SAO Special Report",
"asd.. Astrophysics Software Database",
"ascl. Astrophysics Source Code Library",
"SatCo Satellite Communications",
"SBARM SBARMO Bulletin",
"SbMat Sbornik: Mathematics",
"SJMet Scandinavian Journal of Metallurgy",
"SUVSR Scandinavian Union of Amateur Astronomers Variable Star Section",
"ScReE Scholarly Research Exchange",
"SNG.. Schweizerische Naturforschende Gesellschaft",
"Sci.. Science",
"SCSA. Science and Culture Series: Astrophysics",
"SCSP. Science and Culture Series: Physics",
"SECM. Science and Engineering of Composite Materials",
"STAdM Science and Technology of Advanced Materials",
"SCSMP Science China Series Mathematics Physics Astronomy Technological Sciences",
"SciDi Science Dimension",
"SciEd Science Education",
"ScEdR Science Education Research",
"SFCh. Science Foundation in China",
"ScChA Science in China A: Mathematics",
"ScChB Science in China B: Chemistry",
"ScChC Science in China C: Life Sciences",
"ScChD Science in China D: Earth Sciences",
"ScChE Science in China E: Technological Sciences",
"ScChF Science in China F: Information Sciences",
"ScChG Science in China G: Physics and Astronomy",
"SISN. Science Information Systems Newsletter",
"SciN. Science News",
"ScTEn Science of the Total Environment",
"ScPr. Science Progress",
"Scis. Sciences",
"SciB. Scientia (Bologna)",
"SciSn Scientia Sinica",
"SSPMA Scientia Sinica Physica, Mechanica &amp",
"SSSMP Scientia Sinica Series Mathematical Physical Technical Sciences",
"SciAm Scientific American",
"SMS.. Scientific Modeling and Simulation SMNS",
"Scim. Scientometrics",
"SRToh Sci. Rep. Tohoku Univ. Eighth Ser.",
"SFSN. Scripta Faculty Science Nat. Ujep Brunensis Physica",
"ScM.. Scripta Metallurgica",
"ScMM. Scripta Metallurgica et Materialia",
"SedG. Sedimentary Geology",
"Sedim Sedimentology",
"SeiKa Seikei-Kakou",
"BSSA. Seismological Society America Bulletin",
"SEGeo Seismology and Exploration Geophysics",
"STSSP Selected Topics in Solid State Physics",
"Semic Semiconductors",
"SeScT Semiconductor Science Technology",
"SeSTS Semiconductor Science Technology Supplement",
"TrKra Seminar Kraevym Zadacham Trudy",
"SCB.. Seminars in Cancer Biology",
"SDia. Seminars in Dialysis",
"GEOCS Semi-Regular Variables",
"SenAR Sendai Astronomiaj Raportoj",
"SenIm Sensing and Imaging",
"SPTS. Sensor Physics and Technology Series",
"SeRv. Sensor Review",
"SeAc. Sensors and Actuators",
"SeAcA Sensors and Actuators A Physical",
"SeAcB Sensors and Actuators B Chemical",
"SAERI Seoul Korea Atomic Energy Research Institute",
"SanS. Separata Universidad de Chile Departamento de Astronomia Santiago",
"SerAJ Serbian Astronomical Journal",
"AnShO Shanghai Observatory Annals",
"SV... Shock and Vibration",
"SVD.. Shock Vibration Digest",
"SVICB Shock Vibration Information Center Shock Vibration Bulletin",
"SVICP Shock Vibration Information Center Shock Vibration Computer Programs",
"SVICD Shock Vibration Information Center Shock Vibration Digest",
"SVICI Shock Vibration Information Center Shock Vibration Inform Digest",
"ShWav Shock Waves",
"SJAM. SIAM Journal of Applied Mathematics",
"SJCO. SIAM Journal of Control Optimization",
"SJMA. SIAM Journal of Mathematical Analysis",
"SJADS SIAM Journal on Applied Dynamical Systems",
"SJNA. SIAM Journal on Numerical Analysis",
"SIAMR SIAM Review",
"SiMaJ Siberian Mathematical Journal",
"SiFTZ Sibirskii Fiziko Tekhnicheskii Zhurnal",
"JCMSI SICE Journal of Control, Measurement, and System Integration",
"SidM. Sidereal Messenger",
"SIDPQ SID Proceedings Quarter",
"SiFoE Siemens Forschungs und Entwicklungsberichte",
"SIGMA SIGMA",
"Sig.. Signal",
"SigPr Signal Processing",
"Simul Simulation",
"SiMol Single Molecules",
"SZPA. SIRIUS. Zeitschrift fuer Populaere Astronomie",
"Situ. Situ",
"SkInq Skeptical Inquirer",
"SRT.. Skin Research and Technology",
"SkyN. Sky News",
"SlaOb Slaboproudy Obzor",
"SJCE. Slovak Journal of Civil Engineering",
"SBE.. Small Business Economics",
"SMaS. Smart Material Structures",
"Smith Smithsonian",
"SCoA. Smithsonian Contributions to Astrophysics",
"SCoK. Smithsonian Contributions to Knowledge",
"SmCES Smithsonian Contributions to the Earth Sciences",
"SSS.. Social Studies of Science",
"MSAIQ Societa Astronomica Italiana Memorie Quarter",
"SFPTB Societe Francaise de Photogrammetrie et de Teledetection Bulletin",
"SASS. Society for Astronomical Sciences Annual Symposium",
"SEEJ. Society of Environmental Engineers Journal",
"SIAM. Society of Industrial and Applied Mathematics",
"SIBAN Sofia Izdatel Bolgarskoi Akademii Nauk",
"SMat. Soft Matter",
"SSSAJ Soil Science Society of America Journal",
"SoCe. Solar Cells",
"SoEn. Solar Energy",
"SoEnM Solar Energy Materials",
"SoPh. Solar Physics",
"SoSyR Solar System Research",
"STERJ Solar Terrestrial and Environmental Research Japan",
"SolE. Solid Earth",
"SolED Solid Earth Discussions",
"SMArc Solid Mechanics Archives",
"SSCom Solid State Communications",
"SSEle Solid State Electronics",
"SSIon Solid State Ionics",
"SSNMR Solid State Nuclear Magnetic Resonance",
"SSPAR Solid State Physics Advances in Research and Applications",
"SSPAS Solid State Physics Advances in Research and Applications Supplement",
"SSSci Solid State Sciences",
"SSTec Solid State Technology",
"BSolD Solnechnye Dann. Bull. Akad. Nauk SSSR",
"SoKie Sonderdrucke der Sternwarte Kiel",
"SoMue Sonderdrucke Universitaet Muenster Astronomisches Institut",
"Sonne Sonne",
"SoShe Soobshchenie Shemakhinskoj Astrofizicheskoj Observatorii",
"SoByu Soobshcheniya Byurakanskoj Observatorii Akademiya Nauk Armyanskoj SSR Erevan",
"SoSht Soobshcheniya Gosudarstvennogo Astronomicheskogo Instituta",
"SoSAO Soobshcheniya Spetsial'noj Astrofizicheskoj Observatorii",
"SMTS. Soprotivlenie Materialov i Teoriia Sooruzhenii",
"SSHMP Sources and Studies in the History of Mathematics and Physical Sciences",
"SHMPS Sources in the History of Mathematics and Physical Sciences",
"SAAOC South African Astronomical Observatory Circular",
"SAAOR South African Astronomical Observatory Republic",
"SAJPh South African Journal of Physics",
"SAJSc South African Journal of Science",
"SouSt Southern Stars",
"IBSAE Sovetskaia Antarkticheskaia Ekspeditsiia Informatsionnyi Byulleten",
"SovAe Soviet Aeronomii",
"SvApM Soviet Applied Mechanics",
"SvA.. Soviet Astronomy",
"SvAL. Soviet Astronomy Letters",
"JETP. Soviet Journal of Experimental and Theoretical Physics",
"JETPL Soviet Journal of Experimental and Theoretical Physics Letters",
"SvJNP Soviet Journal of Nuclear Physics",
"SvJOT Soviet Journal of Optical Technology",
"SvJPP Soviet Journal of Plasma Physics",
"SvJQE Soviet Journal of Quantum Electronics",
"SvPAC Soviet Physics Acoustics",
"SvPhA Soviet Physics Astronomy",
"SvPC. Soviet Physics Crystallography",
"SPhD. Soviet Physics Doklady",
"SvPhJ Soviet Physics Journal",
"SvPS. Soviet Physics Semiconductors",
"SvPSS Soviet Physics Solid State",
"SPTP. Soviet Physics Technical Physics",
"SvPhU Soviet Physics Uspekhi",
"SvRP. Soviet Radiophysics",
"SSRvA Soviet Scientific Reviews A Physics Reviews",
"SSRvC Soviet Scientific Reviews C Mathematical Physics Reviews",
"SSRvD Soviet Scientific Reviews D Physicochemical Biology Reviews",
"SSRvE Soviet Scientific Reviews E Astrophysics and Space Physics Reviews",
"SvTRv Soviet Technology Reviews",
"Space Space",
"SSPRv Space and Solar Power Review",
"SpCoB Space Communication Broadcasting",
"SpCom Space Communications",
"SpEd. Space Education",
"SpFl. Spaceflight",
"SLSci Space Life Sciences",
"SpMar Space Markets",
"SpMME Space Medicine Medical Engineering",
"SpPol Space Policy",
"SpPow Space Power",
"SPRMD Space Power - Resources, Manufacturing and  Development",
"SpRBu Space Research Bulgaria",
"SpReT Space Research Today",
"SSI.. Space Science Instrumentation",
"SSRv. Space Science Reviews",
"SpT.. Space Technology",
"STICA Space Technology Industrial and Commercial Applications",
"STECF Space Telescope European Coordinating Facility Newsletter",
"Spvw. Spaceview",
"SpWea Space Weather",
"SpWd. Space World",
"SpWdU Space World U",
"SpWdW Space World W",
"SpWdY Space World Y",
"Spark Spark, the AAS Education Newsletter",
"VatAR Specola Astronomica Vaticana Annual Reports",
"AtlSV Specola Astronomica Vaticana Atlas Stellarum Variabilium",
"VatCo Specola Astronomica Vaticana Comunicazione",
"VatMA Specola Astronomica Vaticana Miscellanea Astronomica",
"VatPS Specola Astronomica Vaticana Pubblicazioni Serie Seconda",
"VatRS Specola Astronomica Vaticana Ricerche Spettroscopiche",
"VatRA Specola Astronomica Vaticana Richerche Astronomiche",
"AcSpe Spectrochimica Acta",
"AcSpA Spectrochimica Acta Part A: Molecular Spectroscopy",
"SpecL Spectroscopy Letters",
"SRMO. Specula Regia Monachiensi Observationes astronomicae",
"SScT. Speculations in Science and Technology",
"Spika Spika",
"SpEng Sports Engineering",
"SSSSc Springer Series in Surface Sciences",
"STMP. Springer Tracts in Modern Physics",
"SSCP. Springer Verlag Springer Series on Chemical Physics",
"SSEp. Springer Verlag Springer Series on Electrophysics",
"SSGSR Springer Verlag Springer Series on Group Geophysics Space Research",
"SSOS. Springer Verlag Springer Series on Optical Sciences",
"SVPCS Springer Verlag Springer Series on Physics Chemistry Space",
"SSSSS Springer Verlag Springer Series on Solid State Sciences",
"SSSyn Springer Verlag Springer Series on Synergetics",
"SSWP. Springer Verlag Springer Series on Wave Phenomena",
"SprRe Sproul Observatory Reprints",
"SrLJP Sri Lankan Journal of Physics",
"SANUG Srpska Akademiia Nauka i Umetnosti Glas Odeljenje Tekhnichkikh Nauka",
"SRXPh SRX Physics",
"StarD StarDate Magazine",
"StSky Star Sky",
"StMet Statistical Methodology",
"StaSc Statistical Science",
"StCom Statistics and Computing",
"StReL Staub Reinhaltung Luft",
"SMSPS Stephan Mueller Special Publication Series",
"Sterz Sternzeit Mitteilungen der Astrnomischen Vereinigungen Aachen",
"IEWS. Stevenage Herts England Peter Peregrinus Ltd IEE Electromagnetic Waves Series",
"SteRe Steward Observatory Reprints",
"TriTr STLE Tribology Transactions",
"SAA.. Stochastic Analysis and Applications",
"SHH.. Stochastic Hydrology and Hydraulics",
"SSRp. Stochastics and Stochastics Reports",
"StoAn Stockholms Observatoriums Annaler",
"StoMe Stockholms Observatoriums Meddelande",
"StoOR Stockholms Observatoriums Reports",
"Strab Strabismus",
"Strai Strain",
"SGC.. Stratigraphy and Geological Correlation",
"Stroj Strojarstvo",
"StAst Strolling Astronomer",
"StrOp Structural Optimization",
"SASn. Studia Astronomica Sinica",
"StBio Studia Biophysica",
"StGG. Studia Geophysica et Geodaetica",
"StuMa Studia Mathematica",
"SSTor Studia Societatis Scientiarum Torunensis Sectio F Astronomia",
"StAM. Studies in Applied Mathematics",
"SCMP. Studies in Condensed Matter Physics",
"SGORS Studies in Geophysical Optics and Remote Sensing",
"StGeo Studies in Geophysics",
"StHEP Studies in High Energy Physics",
"StHCG Studies in High Energy Physics Cosmology and Gravitation",
"StMaP Studies in Mathematical Physics",
"StPTC Studies in Physical and Theoretical Chemistry",
"SScEd Studies in Science Education",
"StHPM Studies in the History and Philosophy of Modern Physics",
"StHMP Studies in the History of Mathematics and the Physical Sciences",
"Sttur Studies in turbulence",
"SCA.. Studii si Cercetari de Astronomie Bucuresti",
"StCeF Studii si Cercetari de Fizica",
"StCeM Studii si Cercetari Matematice",
"StCMA Studii si Cercetary de Mecanica Aplicata",
"SSTA. Subsurface Sensing Technologies and Applications",
"SunGe Sun and Geosphere",
"Sunwo Sunworld",
"SuScT Superconductor Science Technology",
"SuMi. Superlattices and Microstructures",
"JPhSu Supplement au Journal de Physique",
"AnMuS Supplementband zu den Annalen der Munchener Sternwarte",
"SAnAp Supplements aux Annales d'Astrophysique",
"SuCT. Surface and Coatings Technology",
"SurIA Surface and Interface Analysis",
"SRL.. Surface Review and Letters",
"SurSc Surface Science",
"SurSL Surface Science Letter",
"SurSR Surface Science Reports",
"SurSS Surface Science Spectra",
"SGeo. Surveys in Geophysics",
"SHEP. Surveys in High Energy Physics",
"SvPro Svarochnoe Proizvodstvo",
"SvUNT Sverdlovsk Ural skii Nauchnyi Tsentr AN SSSR",
"SydOP Sydney Observatory Papers",
"SynMe Synthetic Metals",
"SAMS. Systems Analysis Modelling Simulation",
"SyTec Systems Technology",
"TMPGO Tagung ueber Mathematische Probleme Geodaesie Oberwolfach West Germany Bulleting Geodesique",
"TANEs Tartu Akademiia Nauk Estonskoi SSR",
"TarPr Tartu Astrofizicheskoj Observatorii Preprint",
"TarOT Tartu Astrofuusika Observatoorium Teated",
"IzTas Tashkent Izdatel Fan",
"IzGeo Tbilisi Georgian SSR Izdatel Metsniereba",
"TIzSS Tbilisi Izdatel Sabchota Sakartvelo",
"TecN. Technical News",
"TePhL Technical Physics Letters",
"TeLoA Technika Lotnicza i Astronautyczna",
"TBBM. Techniques of Biochemical and Biophysical Morphology",
"TPhy. Techniques of Physics",
"TMKF. Technische Mitteilungen Krupp Forschungsberichte",
"TUnGG Technische Univ Geodesy Global Geodyn",
"ToIzL Technisch oekonomische Informationen zivilen Luftfahrt",
"Tech. Technology",
"TeCu. Technology and Culture",
"TecRv Technology Review",
"Tecto Tectonics",
"Tectp Tectonophysics",
"TekEl Tekhnicheskaia Elektrodinamika",
"TJAu. Telecommunication Journal of Australia",
"TDAPR Telecommunications and Data Acquisition Progress Report",
"TMOPR Telecommunications and Mission Operations Progress Report",
"TRET. Telecommunications and Radio Engineering Telecommunications",
"TelIn Telematics Informatics",
"Telet Telettra S",
"Tell. Tellus",
"TellA Tellus Series A",
"TellB Tellus Series B Chemical and Physical Meteorology B",
"TSDMO Tellus Series Dynamic Meteorology and Oceanography",
"TeoEl Teoreticheskaia Elektrotekhnika",
"TeoPM Teoreticheskaia i Prikladnaia Mekhanika",
"TFFAP Teoriia Funktsii Funktsional nyi Analiz i ikh Prilozheniia",
"TeoVP Teoriia Veroiatnostei i ee Primeneniia",
"Teplo Teploenergetika",
"Tepsg Teplofizicheskie svoistva gazov",
"TepT. Teplofizika i Teplotekhnika",
"TepVT Teplofizika Vysokikh Temperatur",
"TFizG Teploobmen i Fizicheskaia Gazodinamika",
"TNEK. Teplovye Napriazheniia Elementakh Konstruktsii",
"TeMAE Terrestrial Magnetism and Atmospheric Electricity (Journal of Geophysical Research)",
"TeMag Terrestrial Magnetism (Journal of Geophysical Research)",
"Tesla TESLA Electronics",
"TTPhy Teubner Texte zur Physik",
"TexMi Textures and Microstructures",
"Ana.. The Analyst",
"Agrph The Astrograph",
"Astr. The Astronomer",
"ATel. The Astronomer's Telegram",
"AJ... The Astronomical Journal",
"AJS.. The Astronomical Journal Supplement",
"AstRv The Astronomical Review",
"ApJ.. The Astrophysical Journal",
"ApJL. The Astrophysical Journal Letters",
"ApJS. The Astrophysical Journal Supplement Series",
"BJHS. The British Journal for the History of Science",
"BJPS. The British Journal for the Philosophy of Science",
"BuSSA The Bulletin of the Seismological Society of America",
"ComRv The Communication Review",
"CompJ The Computer Journal",
"TCD.. The Cryosphere Discussions",
"EMBO. The EMBO Journal",
"JAS.. The Journal of Agricultural Science",
"JChTh The Journal of Chemical Thermodynamics",
"JFin. The Journal of Finance",
"MatMo The Mathematical Monthly",
"Msngr The Messenger",
"Neuro The Neuroscientist",
"INGN. The Newsletter of the Isaac Newton Group of Telescopes",
"Obs.. The Observatory",
"OAcJ. The Open Acoustics Journal",
"OAeEJ The Open Aerospace Engineering Journal",
"OAPJ. The Open Applied Physics Journal",
"OAJ.. The Open Astronomy Journal",
"OASJ. The Open Atmospheric Science Journal",
"OCPJ. The Open Chemical Physics Journal",
"OCMPJ The Open Condensed Matter Physics Journal",
"OGC.. The Open Geology Journal",
"OHJ.. The Open Hydrology Journal",
"OMEJ. The Open Mechanical Engineering Journal",
"OMJ.. The Open Mechanics Journal",
"OMnJ. The Open Mineralogy Journal",
"OMPJ. The Open Mineral Processing Journal",
"ONJ.. The Open Nanoscience Journal",
"ONPPJ The Open Nuclear &amp",
"ONMJ. The Open Numerical Methods Journal",
"OOcJ. The Open Oceanagraphy Journalurnal",
"OOEJ. The Open Ocean Engineering Journal",
"OOJ.. The Open Optics Journal",
"OPalJ The Open Paleontology Journal",
"OPCJ. The Open Physical Chemistry Journal",
"OPPJ. The Open Plasma Physics Journal",
"ORSJ. The Open Remote Sensing Journal",
"OREJ. The Open Renewable Energy Journal",
"OSPJ. The Open Signal Processing Journal",
"OSpeJ The Open Spectroscopy Journal",
"OSuJ. The Open Superconductors Journal",
"OSSJ. The Open Surface Science Journal",
"AcTC. Theoretica Chimica Acta",
"ThApC Theoretical and Applied Climatology",
"ThAFM Theoretical and Applied Fracture Mechanics",
"TAM.. Theoretical and Applied Mechanics",
"ThCFD Theoretical and Computational Fluid Dynamics",
"TMP.. Theoretical and Mathematical Physics",
"ThAst Theoretical Astrophysics",
"TPAG. Theory and Practice of Applied Geophysics",
"PhTea The Physics Teacher",
"PlJ.. The Plant Journal",
"QJMat The Quarterly Journal of Mathematics",
"QJPAM The Quarterly Journal of Pure and Applied Mathematics",
"RamJ. The Ramaujan Journal",
"RvES. The Review of Economic Studies",
"ThEng Thermal Engineering",
"TSE.. Thermal Science and Engineering",
"SJCLI The Scandinavian Journal of Clinical and Laboratory Investigation",
"SciMo The Scientific Monthly",
"TSF.. Thin Solid Films",
"TETB. Thyssen Edelstahl Technische Berichte",
"TrTIM Tiflis Izdatel Metsniereba Akademiia Nauk Gruzinskoi SSR Institut Geofiziki Trudy",
"TrGru Tiflis Izdatel Metsniereba Akademiia Nauk Gruzinskoi SSR Matematicheskii Institut Trudy",
"IzTif Tiflis Izdatel Tbilisskogo Universiteta",
"CorTi Tirada Aparte Universidad Nacional de Cordoba Argentina Observatorio Astronomico",
"TiEng Tissue Engineering",
"TNKS. Tochnost i Nadezhnost Kiberneticheskikh Sistem",
"TSRSG Tohoku University Science Reports Series Geophysics",
"TokAB Tokyo Astronomical Bulletin",
"TokRe Tokyo Astronomical Observatory Reprints",
"TUFER Tokyo Denki University Faculty of Engineering Research Reports",
"TAEMm Tokyo Metropolitan College Aeronautical Engineering Memoirs",
"TUFEJ Tokyo University Faculty of Engineering Journal Series",
"TUISR Tokyo University Institute Industrial Science Report",
"TUASB Tokyo University Institute of Space and Aeronautical Science Bulletin",
"TUASR Tokyo University Institute of Space and Aeronautical Science Report",
"TIOA. Tomsk Institut Optiki Atmosfery CO AN SSSR",
"TApPh Topics in Applied Physics",
"TAASS Topics in Astrophysics, Astrononmy, and Space Science",
"ToCat Topics in Catalysis",
"TCPh. Topics in Current Physics",
"TPhCh Topics in Physical Chemistry",
"ToASC Torino Accademia delle Scienze Classe di Scienze Fisiche Matematiche e Naturali Atti",
"TosRv Toshiba Review",
"TouCE Toulouse Cepadues Editions",
"TrSpT Transactions of Space Technology Japan",
"TAGU. Transactions of the American Geophysical Union",
"TAMS. Transactions of the American Mathematical Society",
"TAPS. Transactions of the American Philosophical Society",
"TOYal Transactions of the Astronomical Observatory of Yale University",
"TCaPS Transactions of the Cambridge Philosophical Society",
"TIMC. Transactions of the Institute of Measurement and Control",
"TISCI Transactions of the Institute of Systems, Control and Information Engineers",
"IAUTA Transactions of the International Astronomical Union, Series A",
"IAUTB Transactions of the International Astronomical Union, Series B",
"TIUCS Transactions of the International Union for Cooperation in Solar Research",
"TJSAI Transactions of the Japanese Society for Artificial Intelligence",
"TATJ. Transactions of the Japanese Society for Artificial Intelligence, Aerospace Technology Japan",
"TJSIE Transactions of The Japanese Society of Irrigation, Drainage and Rural Engineering",
"TRACE Transactions of the Japan Society of Refrigerating and Air Conditioning Engineers",
"TLHSQ Transactions of the Literary and Historical Society of Quebec",
"TrOS. Transactions of the Optical Society",
"TSICE Transactions of the Society of Instrument and Control Engineers",
"TPM.. Transport in Porous Media",
"TTSP. Transport Theory and Statistical Physics",
"TvOC. Transvaal Observatory Circular",
"TSSLW Travaux de la Societe des Sciences et des Letters de Wroclaw",
"TOMar Travaux de l'Observatoire de Marseille",
"TraGe Travaux Geophysiques",
"TrGeo Treatise on Geochemistry",
"TTP.. Trends in Theoretical Physics",
"TriL. Tribology Letters",
"TrLit Trudy Akademiia Nauk Litovskoi",
"TrSSR Trudy Akademiia Nauk SSSR Fizicheskii Institut",
"TrAlm Trudy Astrofizicheskogo Instituta Alma-Ata",
"TrRig Trudy Astrofiz. Lab. Riga",
"TrLen Trudy Astronomicheskoj Observatorii Leningrad",
"TrPul Trudy Glavnoj Astronomicheskoj Observatorii v Pulkovo",
"TrSht Trudy Gosudarstvennogo Astronomicheskogo Instituta",
"TrDus Trudy Instituta Astrofiziki Dushanbe",
"TrSta Trudy Instituta Astrofiziki Stalinabad",
"TrKaz Trudy Kazanskaia Gorodkoj Astronomicheskoj Observatorii",
"TrMMO Trudy Moskovskoe Matematicheskoe Obshchestvo",
"TrPet Trudy Seminar imeni G Petrovskogo",
"TrTas Trudy Tashkentskoj Astronomicheskoj Observatorii",
"TrTsA TsAGI Trudy",
"ZaTsA TsAGI Uchenye Zapiski",
"TrTsI TsIAM Trudy",
"TsHUJ Tsing Hua University Journal",
"TITas Tsirkulyar Astronomicheskogo Instituta Akademiya Nauk Uzbekskoj SSR",
"TsLvo Tsirkulyar Astronomicheskoj Observatorii Lvov",
"TsShe Tsirkulyar Shemakhinskoj Astrofizicheskoj Observatorii",
"TsSta Tsirkulyar Stalinabadskoj Astronomicheskoj Observatorii",
"TsTas Tsirkulyar Tashkentskoj Astronomicheskoj Observatorii",
"TsVse Tsirkulyar Vses. astron.-geod. o-va",
"TsPul Tsirkulyary Glavnoj Astronomicheskoj Observatorii i Pulkove",
"TUAID Tuebingen Universitaet Astronomisches Institut Diplomarbeit",
"TJJPT Tuijin Jishu Journal of Propulsion Technology",
"TurTe Turbulentnye techeniia",
"TJPh. Turkish Journal of Physics",
"UkJPO Ukrainian Journal of Physical Optics",
"UkFiZ Ukrainskii Fizicheskii Zhurnal",
"UkMaZ Ukrainskii Matematicheskii Zhurnal",
"Ultmi Ultramicroscopy",
"UltIm Ultrasonic Imaging",
"Ultra Ultrasonics",
"Umsch Umschau",
"USOC. Unified System Orbit Computation USOC",
"UMIB. Unione Matematica Italiana Bollettino",
"UNPSA United Nations Programme on Space Applications",
"UniCl Universe Classroom",
"UNAer Universita di Napoli Aeritalia S",
"UCAFR Universitas Comeniana Acta Facultatis Rerum Naturalium Physica",
"UMt1K Universite de Montpellier",
"UECBu University Electro Communications Bulletin",
"UnECR University Electro Communications Reports",
"StARe University Observatory St. Andrews Scotland Reprints",
"HawRe University of Hawaii Reprints",
"ADUrb University of Illinois Astronomy Department Urbana Illinois",
"MicRe University of Michigan Observatory Reprints",
"XXFD. University of Minnesota 1969 (XXFD)",
"LP... University of Minnesota Minneapolis",
"OklRe University of Oklahoma Observatory Reprints",
"MAUTx University of Texas Monographs in Astronomy",
"PAUTx University of Texas Publications in Astronomy",
"Unpub Unpublished",
"UAPET Updates in Applied Physics and Electrical Technology",
"UppAn Uppsala Astronomical Observatory Annals",
"UppOR Uppsala Astronomical Observatory Reports",
"USM.. Upravliaiushchie Sistemy i Mashiny",
"UrBar Urania (Bracelona)",
"Urani Urania (Krakow)",
"UrMad Urania (Madrid)",
"UGSJR U S Geological Survey Journal Research",
"USNOC U.S. Naval Observatory Circulars",
"USNOR U.S. Naval Observatory Reports",
"UsFiN Uspekhi Fizicheskikh Nauk",
"UMAM. Uspekhi Mekhaniki Advances Mechanics",
"RpCCA USSR Report Cybernetics Computers Automation Technology JPRS UCC",
"RpESc USSR Report Earth Sciences JPRS UES",
"RpSpR USSR Report Space",
"RpBAM USSR Report Space Biology Aerospace Medicine JPRS USB",
"RpEEE USSR Rept Electron Elec Eng JPRS UEE",
"RpEn. USSR Rept Energy JPRS UEN",
"RpEE. USSR Rept Eng Equipment JPRS UEQ",
"RLSBB USSR Rept Life Sci Biomed Behavioral Sci JPRS",
"RMTME USSR Rept Machine Tools Metalworking Equipment JPRS UMM",
"RpMSM USSR Rept Mater Sci Met JPRS",
"RpPhM USSR Rept Phys Math JPRS UPM",
"RSBAM USSR Rept Space Biol Aerospace Med Jun JPRS",
"RpSBA USSR Rept Space Biol Aerospace Med Sep",
"RpTr. USSR Rept Transportation JPRS UTR",
"UtMat Utilitas Mathematica",
"UtrOv Utrechtse Sterrekundige Overdrukken",
"Vacuu Vacuum",
"VVORe Van Vleck Observatory Reprints",
"VSOLB Variable Star Observers League in Japan - Bulletin",
"Vasio Vasiona",
"VatOP Vatican Observatory Publications",
"VDIF. VDI Forschungsheft",
"VDIZ. VDI Z",
"VDIZF VDI Zeitschriften Fortschritt Berichte Reihe Stroemungstechnik",
"VSD.. Vehicle System Dynamics",
"VKAWA Verhandelingen der Koninklijke Akademie van Wetenschappen te Amsterdam",
"Verme Vermessungstechnik",
"VeWFS Veroeffentlichung der Wilhelm Foerster Sterwarte",
"ViHei Veroeffentlichungen der Badischen Landes-Sternwarte zu Heidelberg",
"VeHei Veroeffentlichungen der Badischen Sternwarte zu Heidelberg",
"VeGG. Veroeffentlichungen der Geod. Geophys",
"VeKar Veroeffentlichungen der Grossherzoglichen Sternwarte zu Karlsruhe",
"VeBam Veroeffentlichungen der Remeis-Sternwarte zu Bamberg",
"VeBab Veroeffentlichungen der Sternwarte Babelsberg",
"VeMun Veroeffentlichungen der Sternwarte Munchen",
"VeSon Veroeffentlichungen der Sternwarte Sonneberg",
"VeKie Veroeffentlichungen der Universitaets-Sternwarte Kiel",
"VeKoe Veroeffentlichungen der Universitaets-Sternwarte Koenigsberg Pr.",
"VeBB. Veroeffentlichungen der Universitaetssternwarte zu Berlin-Babelsberg",
"VeGoe Veroeffentlichungen der Universitaets-Sternwarte zu Goettingen",
"VeJen Veroeffentlichungen der Universitaets-Sternwarte zu Jena",
"VeLei Veroeffentlichungen der Universitaetssternwarte zu Leipzig",
"VeBoc Veroeffentlichungen des Astronomischen Instituts der Ruhr-Universitaet Bochum",
"VeARI Veroeffentlichungen des Astronomischen Rechen-Instituts Heidelberg",
"VeABD Veroeffentlichungen des Astronomischen Rechen-Instituts zu Berlin-Dahlem",
"VeBon Veroeffentlichungen des Astronomisches Institute der Universitaet Bonn",
"VeFra Veroeffentlichungen des Astronomisches Institute der Universitaet Frankfurt",
"VeBKI Veroeffentlichungen des Bayerische Kommission Int. Erdmessung",
"VeKAB Veroeffentlichungen des Koeniglichen Astronomischen Rechen-Instituts zu Berlin",
"VeZPE Veroffentlichungen des Zentralinstituts Physik der Erde",
"VMKAN Verslagen en Mededeelingen der Kon. Academie van Wetenschappen, Afd. Natuurkunde",
"VeLdn Verslag van den staat der Sterrewacht te Leiden",
"Vert. Vertica",
"Vertf Vertiflite",
"Vesmi Vesmir",
"VKha. Vestnik Khar'kovskogo Universiteta",
"VeKha Vestnik Khar'kov Universitet",
"VKie. Vestnik Kievskogo Universiteta Seriya Astronomii",
"VeLGU Vestnik LGU",
"VeMos Vestnik Moskovskogo Universiteta Seriya 3 Fizika Astronomiya",
"VISBD Vibration Inst Shock Vibration Digest",
"VIAEA Vienna International Atomic Energy Agency",
"VAG.. Vierteljahresschrift der Astronomischen Gesellschaft",
"VMed. Vierteljahrschrift für Gerichtliche Medizin und Öffentliches Sanitätswesen",
"VNG.. Vierteljahrsschrift der Naturforschenden Gesellschaft in Zürich",
"VilCo Villanova University Observatory Contributions",
"VilOB Vilnius Astronomijos Observatorijos Biuletenis",
"IzVil Vilnius Izdatel Mokslas",
"VJS.. Virginia Journal of Science",
"VisKi Visnik Kiiv. Univ., Fiz.-Mat. Nauki, Astron",
"ViGeo Vissha Geodeziia",
"VA... Vistas in Astronomy",
"VTJ.. Vitro Technical Journal",
"yCat. VizieR Online Data Catalog",
"yCatp VizieR Online Data Catalog",
"VADVS VKI Advanced Design of Ventilation Systems",
"VICFD VKI An Introduction to Computational Fluid Dynamics",
"VIMT. VKI An Introduction to Modeling Turbulence",
"VAFC. VKI Axial Flow Compressors",
"VBLT. VKI Boundary Layers in Turbomachines",
"VCCPP VKI Combined Cycles for Power Plants",
"VCFD. VKI Computational Fluid Dynamics",
"VCFDI VKI Computational Fluid Dynamics for Industrial Flows",
"VCGFV VKI Computer Graphics Flow Visualization and Computational Fluid Dynamics",
"VGTET VKI Gas Turbine Engine Transient Behaviour",
"VIHE. VKI Industrial Heat Exchangers",
"VKILV VKI Laser Velocimetry",
"VKIMT VKI Measurement and Techniques",
"VMTA. VKI Measurement Techniques in Aerodynamics",
"VMHT. VKI Methodology Hypersonic Testing",
"VMATP VKI Modeling and Applications of Transport Phenomena in Porous Media",
"VADMT VKI New Approaches in the Description and Modeling of Turbulence",
"VNGG. VKI Numerical Grid Generation",
"VNMFT VKI Numerical Methods for Flows in Turbomachinery",
"VPIDV VKI Particle Image Displacement Velocimetry",
"VKIRT VKI Radial Turbines",
"VKISP VKI Spacecraft Propulsion",
"VTSF. VKI Turbulent Shear Flows",
"VVRD. VKI Vibration Rotor Dynamics",
"VLSID VLSI Design",
"VAC.. Voies Aviation Civile Fall Winter",
"VANTS Voprosy Atomnoi Nauki i Tekhniki Seriia Fizika Plazmy i Problemy Upravliaemykh Termoiadernykh Reaktsii",
"VopDP Voprosy Dinamiki i Prochnosti",
"VETT. Voprosy Elektroniki Tverdogo Tela",
"VopGA Voprosy Gidrodinamiki Atmosfery",
"VopK. Voprosy Kibernetiki",
"VMOIP Voprosy Metrologicheskogo Obespecheniia Izmereniia Parametrov Tekhnologicheskikh Lazerov",
"VoTAS Voprosy Teorii Atomnykh Stolknovenii",
"VopTP Voprosy Teorii Plazmy",
"VTSAU Voprosy Teorii Sistem Avtomaticheskogo Upravleniia",
"VossZ Vossische Zeitung",
"IzYak Vsesoiuznaia Konferentsiia Kosmicheskim Lucham Yakutsk USSR Akademiia Nauk SSSR Izvestiia Seriia Fizicheskaia",
"IzYer Vsesoiuznaia Konferentsiia Kosmicheskim Lucham Yerevan Armenian SSR Aademiia Nauk SSSR Izvestiia Seriia Fizicheskaia",
"RaUkr Vsesoiuznyi Simpozium Difraktsii i Rasprostraneniiu Voln Lvov Ukrainian SSR Radiofizika",
"VnPM. Vychislitel naia i Prikladnaia Matematika",
"VnMP. Vychislitel nye Metody i Programmirovanie",
"VyGeo Vyssha Geodeziia",
"WarRe Warsaw University Reprints",
"WasOA Washburn Observatory Astrophysics",
"GMS.. Washington DC American Geophysical Union Geophysical Monograph Series",
"WRR.. Water Resources Research",
"WavEl Wave Electronics",
"WaMot Wave Motion",
"WRCM. Waves in Random and Complex Media",
"WRM.. Waves in Random Media",
"Wear. Wear",
"WearB Wear B",
"Wthr. Weather",
"WtFor Weather and Forecasting",
"WeiEn Weight Engineering",
"WeldJ Welding Journal",
"Werk. Werkgroepnieuws",
"JIMO. WGN, Journal of the International Meteor Organization",
"WilOO Williamstown Observatory Observations",
"WiEn. Wind Energy",
"WiEng Wind Engineering",
"WisBT Wissenschaftliche Berichte AEG Telefunken",
"WisZe Wissenschaftliche Zeitschrift",
"WSAAA Workshop Series of the Asociacion Argentina de Astronomia",
"WCRp. World Climate Report",
"WJCMP World Journal of Condensed Matter Physics",
"WJM.. World Journal of Mechanics",
"WJNSE World Journal of Nano Science and Engineering",
"WJNST World Journal of Nuclear Science and Technology",
"WroRe Wroclaw Astronomical Observatory Reprints",
"Wuli. Wuli",
"YaFiz Yadernaya Fizika",
"YalOY Yale University Observatory Reports for the Year",
"YUFEM Yamaguchi University Faculty of Engineering Memoirs",
"YUTR. Yamaguchi University Technology Reports",
"YamC. Yamamoto Circular",
"ZaDN. Zagadnienia Drgan Nieliniowych",
"JAMP. ZAMP Journal of Applied Mathematics and Physics",
"ZaLab Zavodskaia Laboratoriia",
"ZaMM. Zeitschrift Angewandte Mathematik und Mechanik",
"ZaMP. Zeitschrift Angewandte Mathematik und Physik",
"ZFHDG Zeitschrift der Fachsektion Hydrogeologie in der Deutschen Geologischen Gesellschaft",
"ZeIE. Zeitschrift elektrische Informations und Energietechnik",
"ZAGeo Zeitschrift fur Angewandte Geographie",
"ZAPhy Zeitschrift fur Angewandte Physik",
"ZAAC. Zeitschrift fur Anorganische und Allgemeine Chemie",
"ZA... Zeitschrift fur Astrophysik",
"ZEVGA Zeitschrift fur Eisenbahnwesen und Verkehrstechnik Glasers Annalen",
"ZEAPC Zeitschrift für Elektrochemie und Angewandte Physikalische Chemie",
"ZFlu. Zeitschrift fur Flugwissenschaften",
"ZFlWe Zeitschrift fur Flugwissenschaften und Weltraumforschung",
"ZGm.. Zeitschrift fur Geomorphologie",
"ZGmS. Zeitschrift fur Geomorphologie Supplement",
"ZGeo. Zeitschrift fur Geophysik",
"ZGlGl Zeitschrift fur Gletscherkunde und Glazialgeologie",
"ZK... Zeitschrift fur Kristallographie",
"ZKMP. Zeitschrift fur Kristallographie Mineralogie und Petrographie",
"ZKS.. Zeitschrift fur Kristallographie Supplements",
"ZMP.. Zeitschrift für Mathematik und Physik",
"ZMetl Zeitschrift fur Metallkunde",
"ZeMet Zeitschrift fur Meteorologie",
"ZPhy. Zeitschrift fur Physik",
"ZPhyA Zeitschrift fur Physik A Hadrons and Nuclei",
"ZPC.. Zeitschrift fur Physikalische Chemie",
"ZPCF. Zeitschrift fur Physikalische Chemie Frankfurt",
"ZPCL. Zeitschrift fur Physikalische Chemie Leipzig",
"ZPCNF Zeitschrift fur Physikalische Chemie Neue Folge",
"ZPCW. Zeitschrift fur Physikalische Chemie Wiesbaden",
"ZPhyB Zeitschrift fur Physik B Condensed Matter",
"ZPhyC Zeitschrift fur Physik C Particles and Fields",
"ZPhyD Zeitschrift fur Physik D Atoms Molecules Clusters",
"ZNatA Zeitschrift Naturforschung Teil A",
"ZNatB Zeitschrift Naturforschung Teil B",
"ZePAN Zeitschrift Physik Atomic Nuclei",
"ZVer. Zeitschrift Vermessungswes.",
"ZWer. Zeitschrift Werkstofftechnik",
"ZemVs Zemlia i Vselennaia",
"Zenit Zenit",
"MiTau Zentralinstitut fuer Astrophysik Mitteilungen des Karl-Schwarzschild-Observatoriums Tautenburg",
"MitVS Zentralinstitut fuer Astrophysik Sternwarte Sonneberg Mitteilungen ueber Veraenderliche Sterne",
"ZhPmR ZhETF Pis ma Redaktsiiu",
"ZhETF Zhurnal Eksperimental noi i Teoreticheskoi Fiziki",
"ZhFK. Zhurnal Fizicheskoi Khimii",
"ZNPFK Zhurnal Nauchnoi i Prikladnoi Fotografii i Kinematografii",
"ZhPhy Zhurnal Physik",
"ZhPS. Zhurnal Prikladnoi Spektroskopii",
"ZhTFi Zhurnal Tekhnicheskoi Fiziki",
"ZVMMF Zhurnal Vychislitel noi Matematiki i Matematicheskoi Fiziki",
"ZiZa. Ziran Zazhi",
"Zprav Zpravodaj VZLU",
"ZvDeb Zvaigsnota Debess",
};
static const int njournals = sizeof( journals ) / sizeof( journals[0] );
